@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the chat dialog.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import Qt, pyqtSlot, pyqtSignal, QDateTime, QPoint, QFileInfo
 from PyQt5.QtGui import QColor
@@ -402,8 +401,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         self.editorCommand.emit(hashStr, fileName, message)
         
         from QScintilla.Editor import Editor
-        if message.startswith(Editor.StartEditToken + Editor.Separator) or \
-           message.startswith(Editor.EndEditToken + Editor.Separator):
+        if (message.startswith(Editor.StartEditToken + Editor.Separator) or
+                message.startswith(Editor.EndEditToken + Editor.Separator)):
             vm = e5App().getObject("ViewManager")
             aw = vm.activeWindow()
             if aw:
@@ -495,29 +494,24 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         Private slot to initialize the chat edit context menu.
         """
         self.__chatMenu = QMenu(self)
-        self.__copyChatAct = \
-            self.__chatMenu.addAction(
-                UI.PixmapCache.getIcon("editCopy.png"),
-                self.tr("Copy"), self.__copyChat)
+        self.__copyChatAct = self.__chatMenu.addAction(
+            UI.PixmapCache.getIcon("editCopy.png"),
+            self.tr("Copy"), self.__copyChat)
         self.__chatMenu.addSeparator()
-        self.__cutAllChatAct = \
-            self.__chatMenu.addAction(
-                UI.PixmapCache.getIcon("editCut.png"),
-                self.tr("Cut all"), self.__cutAllChat)
-        self.__copyAllChatAct = \
-            self.__chatMenu.addAction(
-                UI.PixmapCache.getIcon("editCopy.png"),
-                self.tr("Copy all"), self.__copyAllChat)
+        self.__cutAllChatAct = self.__chatMenu.addAction(
+            UI.PixmapCache.getIcon("editCut.png"),
+            self.tr("Cut all"), self.__cutAllChat)
+        self.__copyAllChatAct = self.__chatMenu.addAction(
+            UI.PixmapCache.getIcon("editCopy.png"),
+            self.tr("Copy all"), self.__copyAllChat)
         self.__chatMenu.addSeparator()
-        self.__clearChatAct = \
-            self.__chatMenu.addAction(
-                UI.PixmapCache.getIcon("editDelete.png"),
-                self.tr("Clear"), self.__clearChat)
+        self.__clearChatAct = self.__chatMenu.addAction(
+            UI.PixmapCache.getIcon("editDelete.png"),
+            self.tr("Clear"), self.__clearChat)
         self.__chatMenu.addSeparator()
-        self.__saveChatAct = \
-            self.__chatMenu.addAction(
-                UI.PixmapCache.getIcon("fileSave.png"),
-                self.tr("Save"), self.__saveChat)
+        self.__saveChatAct = self.__chatMenu.addAction(
+            UI.PixmapCache.getIcon("fileSave.png"),
+            self.tr("Save"), self.__saveChat)
         
         self.on_chatEdit_copyAvailable(False)
     
@@ -622,18 +616,15 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         Private slot to initialize the users list context menu.
         """
         self.__usersMenu = QMenu(self)
-        self.__kickUserAct = \
-            self.__usersMenu.addAction(
-                UI.PixmapCache.getIcon("chatKickUser.png"),
-                self.tr("Kick User"), self.__kickUser)
-        self.__banUserAct = \
-            self.__usersMenu.addAction(
-                UI.PixmapCache.getIcon("chatBanUser.png"),
-                self.tr("Ban User"), self.__banUser)
-        self.__banKickUserAct = \
-            self.__usersMenu.addAction(
-                UI.PixmapCache.getIcon("chatBanKickUser.png"),
-                self.tr("Ban and Kick User"), self.__banKickUser)
+        self.__kickUserAct = self.__usersMenu.addAction(
+            UI.PixmapCache.getIcon("chatKickUser.png"),
+            self.tr("Kick User"), self.__kickUser)
+        self.__banUserAct = self.__usersMenu.addAction(
+            UI.PixmapCache.getIcon("chatBanUser.png"),
+            self.tr("Ban User"), self.__banUser)
+        self.__banKickUserAct = self.__usersMenu.addAction(
+            UI.PixmapCache.getIcon("chatBanKickUser.png"),
+            self.tr("Ban and Kick User"), self.__banKickUser)
     
     @pyqtSlot(QPoint)
     def on_usersList_customContextMenuRequested(self, pos):
