@@ -1,17 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a class representing a peer connection.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 from PyQt5.QtCore import pyqtSignal, QTimer, QTime, QByteArray
 from PyQt5.QtNetwork import QTcpSocket, QHostInfo
@@ -183,8 +178,8 @@ class Connection(QTcpSocket):
                 return
             
             try:
-                user, serverPort = \
-                    str(self.__buffer, encoding="utf-8").split(":")
+                user, serverPort = (
+                    str(self.__buffer, encoding="utf-8").split(":"))
             except ValueError:
                 self.abort()
                 return
@@ -216,8 +211,8 @@ class Connection(QTcpSocket):
                 self.abort()
                 return
             
-            if self.__serverPort != self.peerPort() and \
-               not Preferences.getCooperation("AutoAcceptConnections"):
+            if (self.__serverPort != self.peerPort() and
+                    not Preferences.getCooperation("AutoAcceptConnections")):
                 # don't ask for reverse connections or
                 # if we shall accept automatically
                 res = E5MessageBox.yesNo(
@@ -305,9 +300,9 @@ class Connection(QTcpSocket):
         
         @return data length (integer)
         """
-        if self.bytesAvailable() <= 0 or \
-           self.__readDataIntoBuffer() <= 0 or \
-           not self.__buffer.endsWith(SeparatorToken_b):
+        if (self.bytesAvailable() <= 0 or
+            self.__readDataIntoBuffer() <= 0 or
+                not self.__buffer.endsWith(SeparatorToken_b)):
             return 0
         
         self.__buffer.chop(len(SeparatorToken_b))
@@ -351,8 +346,8 @@ class Connection(QTcpSocket):
             return False
         
         self.__buffer.clear()
-        self.__numBytesForCurrentDataType = \
-            self.__dataLengthForCurrentDataType()
+        self.__numBytesForCurrentDataType = (
+            self.__dataLengthForCurrentDataType())
         return True
     
     def __hasEnoughData(self):
@@ -366,11 +361,11 @@ class Connection(QTcpSocket):
             self.__transferTimerId = 0
         
         if self.__numBytesForCurrentDataType <= 0:
-            self.__numBytesForCurrentDataType = \
-                self.__dataLengthForCurrentDataType()
+            self.__numBytesForCurrentDataType = (
+                self.__dataLengthForCurrentDataType())
         
-        if self.bytesAvailable() < self.__numBytesForCurrentDataType or \
-           self.__numBytesForCurrentDataType <= 0:
+        if (self.bytesAvailable() < self.__numBytesForCurrentDataType or
+                self.__numBytesForCurrentDataType <= 0):
             self.__transferTimerId = self.startTimer(TransferTimeout)
             return False
         
@@ -404,8 +399,8 @@ class Connection(QTcpSocket):
                 participantsList = msg.split(SeparatorToken)
             self.participants.emit(participantsList[:])
         elif self.__currentDataType == Connection.Editor:
-            hashStr, fn, msg = \
-                str(self.__buffer, encoding="utf-8").split(SeparatorToken)
+            hashStr, fn, msg = (
+                str(self.__buffer, encoding="utf-8").split(SeparatorToken))
             self.editorCommand.emit(hashStr, fn, msg)
         
         self.__currentDataType = Connection.Undefined
