@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 #
@@ -14,11 +14,9 @@ Module implementing a simple Python code metrics analyzer.
 @exception ValueError the tokenize module is too old
 """
 
-from __future__ import unicode_literals
 
 import os
 import io
-import sys
 import keyword
 import token
 import tokenize
@@ -68,10 +66,7 @@ class Parser(object):
         
         source = io.BytesIO(text.encode("utf-8"))
         try:
-            if sys.version_info[0] == 2:
-                gen = tokenize.generate_tokens(source.readline)
-            else:
-                gen = tokenize.tokenize(source.readline)
+            gen = tokenize.tokenize(source.readline)
             for toktype, toktext, start, end, line in gen:
                 (srow, scol) = start
                 (erow, ecol) = end
@@ -171,7 +166,7 @@ class SourceStat(object):
         @param key the key to be incremented
         @param value the increment (int)
         """
-        for counterId, level, row in self.active:
+        for counterId, _level, _row in self.active:
             counters = self.counters.setdefault(counterId, {})
             counters[key] = counters.setdefault(key, 0) + value
 
