@@ -1,26 +1,26 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a code metrics dialog.
 """
 
-from __future__ import unicode_literals
 
 import os
 import fnmatch
 
 from PyQt5.QtCore import pyqtSlot, Qt, QLocale
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
-    QTreeWidgetItem, QApplication
+from PyQt5.QtWidgets import (
+    QDialog, QDialogButtonBox, QMenu, QHeaderView, QTreeWidgetItem,
+    QApplication
+)
 
 from .Ui_CodeMetricsDialog import Ui_CodeMetricsDialog
 from . import CodeMetrics
 
 import Utilities
-from Globals import qVersionTuple
 
 
 class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
@@ -236,14 +236,8 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
-        if qVersionTuple() >= (5, 0, 0):
-            self.resultList.header().setSectionResizeMode(
-                QHeaderView.Interactive)
-            self.summaryList.header().setSectionResizeMode(
-                QHeaderView.Interactive)
-        else:
-            self.resultList.header().setResizeMode(QHeaderView.Interactive)
-            self.summaryList.header().setResizeMode(QHeaderView.Interactive)
+        self.resultList.header().setSectionResizeMode(QHeaderView.Interactive)
+        self.summaryList.header().setSectionResizeMode(QHeaderView.Interactive)
         
     def on_buttonBox_clicked(self, button):
         """
@@ -264,8 +258,8 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         fileList = self.__fileList[:]
         
         filterString = self.excludeFilesEdit.text()
-        if "ExcludeFiles" not in self.__data or \
-           filterString != self.__data["ExcludeFiles"]:
+        if ("ExcludeFiles" not in self.__data or
+                filterString != self.__data["ExcludeFiles"]):
             self.__data["ExcludeFiles"] = filterString
             self.__project.setData("OTHERTOOLSPARMS", "CodeMetrics",
                                    self.__data)
