@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -169,8 +169,6 @@ class Breakpoint:
                         # continue
                     else:
                         return (b, True)
-                # else:
-                #   continue
             except Exception:
                 # if eval fails, most conservative
                 # thing is to stop on breakpoint
@@ -278,6 +276,8 @@ class Watch:
         for b in Watch.watches:
             if b.cond == cond:
                 return b
+        
+        return None
 
     @staticmethod
     def effectiveWatch(frame):
