@@ -612,8 +612,8 @@ class DebugClientBase(object):
                 code = self.compile_command(self.buffer, self.readstream.name)
             except (OverflowError, SyntaxError, ValueError):
                 # Report the exception
-                sys.last_type, sys.last_value, sys.last_traceback = \
-                    sys.exc_info()
+                sys.last_type, sys.last_value, sys.last_traceback = (
+                    sys.exc_info())
                 self.sendJsonCommand("ClientOutput", {
                     "text": "".join(traceback.format_exception_only(
                         sys.last_type, sys.last_value))
@@ -648,11 +648,11 @@ class DebugClientBase(object):
                                         cf = cf.f_back
                                         frmnr -= 1
                                     _globals = cf.f_globals
-                                    _locals = \
+                                    _locals = (
                                         self.currentThread.getFrameLocals(
-                                            self.framenr)
-                            # reset sys.stdout to our redirector
-                            # (unconditionally)
+                                            self.framenr))
+                            ## reset sys.stdout to our redirector
+                            ## (unconditionally)
                             if "sys" in _globals:
                                 __stdout = _globals["sys"].stdout
                                 _globals["sys"].stdout = self.writestream
@@ -811,6 +811,8 @@ class DebugClientBase(object):
             if not discoveryStart:
                 discoveryStart = params["workdir"]
             
+            top_level_dir = params["workdir"]
+
             os.chdir(params["discoverystart"])
             
             # set the system exception handling function to ensure, that
@@ -821,9 +823,10 @@ class DebugClientBase(object):
             try:
                 import unittest
                 testLoader = unittest.TestLoader()
-                test = testLoader.discover(discoveryStart)
-                if hasattr(testLoader, "errors") and \
-                   bool(testLoader.errors):
+                test = testLoader.discover(
+                    discoveryStart, top_level_dir=top_level_dir)
+                if (hasattr(testLoader, "errors") and
+                        bool(testLoader.errors)):
                     self.sendJsonCommand("ResponseUTDiscover", {
                         "testCasesList": [],
                         "exception": "DiscoveryError",
@@ -850,8 +853,10 @@ class DebugClientBase(object):
                 sys.path = params["syspath"] + sys.path
             sys.path.insert(
                 0, os.path.dirname(os.path.abspath(params["filename"])))
+            top_level_dir = None
             if params["workdir"]:
                 os.chdir(params["workdir"])
+                top_level_dir = params["workdir"]
             else:
                 os.chdir(sys.path[0])
             
@@ -871,7 +876,8 @@ class DebugClientBase(object):
                         self.test = testLoader.loadTestsFromNames(
                             params["testcases"])
                     else:
-                        self.test = testLoader.discover(discoveryStart)
+                        self.test = testLoader.discover(
+                            discoveryStart, top_level_dir=top_level_dir)
                 else:
                     if params["filename"]:
                         utModule = imp.load_source(
@@ -972,9 +978,9 @@ class DebugClientBase(object):
                 testCases.extend(self.__assembleTestCasesList(test, start))
             else:
                 testId = test.id()
-                if "ModuleImportFailure" not in testId and \
-                   "LoadTestsFailure" not in testId and \
-                   "_FailedTest" not in testId:
+                if ("ModuleImportFailure" not in testId and
+                    "LoadTestsFailure" not in testId and
+                        "_FailedTest" not in testId):
                     filename = os.path.join(
                         start,
                         test.__module__.replace(".", os.sep) + ".py")
