@@ -1,23 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Breakpoint viewer widget.
 """
 
-from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, Qt, QItemSelectionModel, \
-    QSortFilterProxyModel, QFileInfo
-from PyQt5.QtWidgets import QTreeView, QAbstractItemView, QHeaderView, QMenu, \
-    QDialog
+from PyQt5.QtCore import (
+    pyqtSignal, Qt, QItemSelectionModel, QSortFilterProxyModel, QFileInfo
+)
+from PyQt5.QtWidgets import (
+    QTreeView, QAbstractItemView, QHeaderView, QMenu, QDialog
+)
 
 from E5Gui.E5Application import e5App
 
-from Globals import qVersionTuple, recentNameBreakpointFiles, \
-    recentNameBreakpointConditions
+from Globals import recentNameBreakpointFiles, recentNameBreakpointConditions
 
 import Preferences
 
@@ -80,10 +80,7 @@ class BreakPointViewer(QTreeView):
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        if qVersionTuple() >= (5, 0, 0):
-            header.setSectionsClickable(True)
-        else:
-            header.setClickable(True)
+        header.setSectionsClickable(True)
         
         self.setSortingEnabled(True)
         
@@ -172,15 +169,15 @@ class BreakPointViewer(QTreeView):
         self.backMenuActions = {}
         self.backMenu = QMenu()
         self.backMenu.addAction(self.tr("Add"), self.__addBreak)
-        self.backMenuActions["EnableAll"] = \
-            self.backMenu.addAction(self.tr("Enable all"),
-                                    self.__enableAllBreaks)
-        self.backMenuActions["DisableAll"] = \
-            self.backMenu.addAction(self.tr("Disable all"),
-                                    self.__disableAllBreaks)
-        self.backMenuActions["DeleteAll"] = \
-            self.backMenu.addAction(self.tr("Delete all"),
-                                    self.__deleteAllBreaks)
+        self.backMenuActions["EnableAll"] = self.backMenu.addAction(
+            self.tr("Enable all"),
+            self.__enableAllBreaks)
+        self.backMenuActions["DisableAll"] = self.backMenu.addAction(
+            self.tr("Disable all"),
+            self.__disableAllBreaks)
+        self.backMenuActions["DeleteAll"] = self.backMenu.addAction(
+            self.tr("Delete all"),
+            self.__deleteAllBreaks)
         self.backMenu.aboutToShow.connect(self.__showBackMenu)
         self.backMenu.addSeparator()
         self.backMenu.addAction(self.tr("Configure..."), self.__configure)
@@ -494,9 +491,8 @@ class BreakPointViewer(QTreeView):
         self.condHistory = []
         rs = Preferences.Prefs.rsettings.value(recentNameBreakpointConditions)
         if rs is not None:
-            self.condHistory = \
-                Preferences.toList(rs)[
-                    :Preferences.getDebugger("RecentNumber")]
+            self.condHistory = Preferences.toList(rs)[
+                :Preferences.getDebugger("RecentNumber")]
     
     def __saveRecent(self):
         """
