@@ -7,7 +7,6 @@
 Module defining the different Python types and their display strings.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import QT_TRANSLATE_NOOP
 
@@ -48,7 +47,7 @@ ConfigVarTypeDispStrings = {
     'ellipsis': QT_TRANSLATE_NOOP('Variable Types', 'Ellipsis'),
     'traceback': QT_TRANSLATE_NOOP('Variable Types', 'Traceback'),
     'frame': QT_TRANSLATE_NOOP('Variable Types', 'Frame'),
-    'other': QT_TRANSLATE_NOOP('Variable Types', 'Other'),
+    'bytes': QT_TRANSLATE_NOOP('Variable Types', 'Bytes'),
 }
 
 
@@ -84,6 +83,7 @@ ConfigVarTypeFilters = {
     'ellipsis': 28,
     'traceback': 29,
     'frame': 30,
-    'other': 31,
+    'other': 31,  # Not used anymore but keep to avoid reassignment
     'frozenset': 32,
+    'bytes': 33,
 }
