@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,8 +15,8 @@ HasCompleter = 0x0010
 HasUnittest = 0x0020
 HasShell = 0x0040
 
-HasAll = HasDebugger | HasInterpreter | HasProfiler | \
-    HasCoverage | HasCompleter | HasUnittest | HasShell
+HasAll = (HasDebugger | HasInterpreter | HasProfiler |
+          HasCoverage | HasCompleter | HasUnittest | HasShell)
 
 #
 # eflag: noqa = M702
