@@ -7,7 +7,6 @@
 Module implementing the debugger UI.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -17,8 +16,9 @@ from PyQt5.QtWidgets import QMenu, QToolBar, QApplication, QDialog
 
 from UI.Info import Program
 
-from .DebugClientCapabilities import HasDebugger, HasInterpreter, \
-    HasProfiler, HasCoverage
+from .DebugClientCapabilities import (
+    HasDebugger, HasInterpreter, HasProfiler, HasCoverage
+)
 import Preferences
 import Utilities
 import UI.PixmapCache
@@ -116,8 +116,8 @@ class DebugUI(QObject):
             self.__continue, self.__step, self.__stepOver, self.__stepOut,
             self.__stepQuit, self.__runToCursor, self.__moveInstructionPointer
         ]
-        self.localsVarFilter, self.globalsVarFilter = \
-            Preferences.getVarFilters()
+        self.localsVarFilter, self.globalsVarFilter = (
+            Preferences.getVarFilters())
         self.debugViewer.setVariablesFilter(
             self.globalsVarFilter, self.localsVarFilter)
         
@@ -563,8 +563,7 @@ class DebugUI(QObject):
         act = E5Action(
             self.tr('Clear Breakpoints'),
             self.tr('Clear Breakpoints'),
-            QKeySequence(
-                self.tr("Ctrl+Shift+C", "Debug|Clear Breakpoints")), 0,
+            0, 0,
             self.dbgSetBpActGrp, 'dbg_clear_breakpoint')
         act.setStatusTip(self.tr('Clear Breakpoints'))
         act.setWhatsThis(self.tr(
@@ -595,7 +594,7 @@ class DebugUI(QObject):
         """
         dmenu = QMenu(self.tr('&Debug'), self.parent())
         dmenu.setTearOffEnabled(True)
-        smenu = QMenu(self.tr('&Start'), self.parent())
+        smenu = QMenu(self.tr('Sta&rt'), self.parent())
         smenu.setTearOffEnabled(True)
         self.breakpointsMenu = QMenu(self.tr('&Breakpoints'), dmenu)
         
@@ -986,8 +985,10 @@ class DebugUI(QObject):
             self.runProjectAct.setEnabled(self.projectOpen)
             self.profileProjectAct.setEnabled(self.projectOpen)
             self.coverageProjectAct.setEnabled(self.projectOpen)
-            if self.lastDebuggedFile is not None and \
-                    (self.editorOpen or self.projectOpen):
+            if (
+                self.lastDebuggedFile is not None and
+                (self.editorOpen or self.projectOpen)
+            ):
                 self.restartAct.setEnabled(True)
             else:
                 self.restartAct.setEnabled(False)
@@ -1029,8 +1030,10 @@ class DebugUI(QObject):
         self.__resetUI()
         
         if not quiet:
-            if not Preferences.getDebugger("SuppressClientExit") or \
-               status != 0:
+            if (
+                not Preferences.getDebugger("SuppressClientExit") or
+                status != 0
+            ):
                 if message:
                     info = self.tr("<p>Message: {0}</p>").format(
                         Utilities.html_uencode(message))
@@ -1139,11 +1142,14 @@ class DebugUI(QObject):
                         ' See the shell window for details.'))
             return
         
-        if (self.exceptions and
-            exceptionType not in self.excIgnoreList and
-            (not len(self.excList) or
-             (len(self.excList) and exceptionType in self.excList)))\
-           or exceptionType.startswith('unhandled'):
+        if (
+            (self.exceptions and
+             exceptionType not in self.excIgnoreList and
+             (not len(self.excList) or
+              (len(self.excList) and exceptionType in self.excList)
+              )
+             ) or exceptionType.startswith('unhandled')
+        ):
             res = None
             if stackTrace:
                 try:
@@ -1392,20 +1398,20 @@ class DebugUI(QObject):
             
             # check for duplicates
             idx = self.__model.getWatchPointIndex(cond, special)
-            duplicate = idx.isValid() and \
-                idx.internalPointer() != index.internalPointer()
+            duplicate = (idx.isValid() and
+                         idx.internalPointer() != index.internalPointer())
             if duplicate:
                 if not special:
-                    msg = self.tr("""<p>A watch expression '<b>{0}</b>'"""
-                                  """ already exists.</p>""")\
-                        .format(Utilities.html_encode(cond))
+                    msg = self.tr(
+                        """<p>A watch expression '<b>{0}</b>'"""
+                        """ already exists.</p>"""
+                    ).format(Utilities.html_encode(cond))
                 else:
                     msg = self.tr(
                         """<p>A watch expression '<b>{0}</b>'"""
                         """ for the variable <b>{1}</b> already"""
-                        """ exists.</p>""")\
-                        .format(special,
-                                Utilities.html_encode(cond))
+                        """ exists.</p>"""
+                    ).format(special, Utilities.html_encode(cond))
                 E5MessageBox.warning(
                     self.ui,
                     self.tr("Watch expression already exists"),
@@ -1580,8 +1586,10 @@ class DebugUI(QObject):
                             " current project. Aborting"))
                     return
                     
-                if Preferences.getDebugger("Autosave") and \
-                   not self.project.saveAllScripts(reportSyntaxErrors=True):
+                if (
+                    Preferences.getDebugger("Autosave") and
+                    not self.project.saveAllScripts(reportSyntaxErrors=True)
+                ):
                     doNotStart = True
                 
                 # save the info for later use
@@ -1596,10 +1604,11 @@ class DebugUI(QObject):
                 if editor is None:
                     return
                 
-                if not self.viewmanager.checkDirty(
-                        editor,
-                        Preferences.getDebugger("Autosave")) or \
-                        editor.getFileName() is None:
+                if (
+                    not self.viewmanager.checkDirty(
+                        editor, Preferences.getDebugger("Autosave")) or
+                    editor.getFileName() is None
+                ):
                     return
                     
                 fn = editor.getFileName()
@@ -1712,8 +1721,10 @@ class DebugUI(QObject):
                             " current project. Aborting"))
                     return
                     
-                if Preferences.getDebugger("Autosave") and \
-                   not self.project.saveAllScripts(reportSyntaxErrors=True):
+                if (
+                    Preferences.getDebugger("Autosave") and
+                    not self.project.saveAllScripts(reportSyntaxErrors=True)
+                ):
                     doNotStart = True
                 
                 # save the info for later use
@@ -1728,10 +1739,11 @@ class DebugUI(QObject):
                 if editor is None:
                     return
                 
-                if not self.viewmanager.checkDirty(
-                        editor,
-                        Preferences.getDebugger("Autosave")) or \
-                        editor.getFileName() is None:
+                if (
+                    not self.viewmanager.checkDirty(
+                        editor, Preferences.getDebugger("Autosave")) or
+                    editor.getFileName() is None
+                ):
                     return
                     
                 fn = editor.getFileName()
@@ -1846,8 +1858,10 @@ class DebugUI(QObject):
                             " current project. Aborting"))
                     return
                     
-                if Preferences.getDebugger("Autosave") and \
-                   not self.project.saveAllScripts(reportSyntaxErrors=True):
+                if (
+                    Preferences.getDebugger("Autosave") and
+                    not self.project.saveAllScripts(reportSyntaxErrors=True)
+                ):
                     doNotStart = True
                 
                 # save the info for later use
@@ -1862,10 +1876,12 @@ class DebugUI(QObject):
                 if editor is None:
                     return
                 
-                if not self.viewmanager.checkDirty(
+                if (
+                    not self.viewmanager.checkDirty(
                         editor,
-                        Preferences.getDebugger("Autosave")) or \
-                        editor.getFileName() is None:
+                        Preferences.getDebugger("Autosave")) or
+                    editor.getFileName() is None
+                ):
                     return
                     
                 fn = editor.getFileName()
@@ -1968,8 +1984,8 @@ class DebugUI(QObject):
         if dlg.exec_() == QDialog.Accepted:
             (lastUsedVenvName, argv, wd, env, exceptions, clearShell,
              console) = dlg.getData()
-            tracePython, autoContinue, forkAutomatically, forkIntoChild = \
-                dlg.getDebugData()
+            tracePython, autoContinue, forkAutomatically, forkIntoChild = (
+                dlg.getDebugData())
             
             if debugProject:
                 fn = self.project.getMainScript(True)
@@ -1982,8 +1998,10 @@ class DebugUI(QObject):
                             " current project. No debugging possible."))
                     return
                     
-                if Preferences.getDebugger("Autosave") and \
-                   not self.project.saveAllScripts(reportSyntaxErrors=True):
+                if (
+                    Preferences.getDebugger("Autosave") and
+                    not self.project.saveAllScripts(reportSyntaxErrors=True)
+                ):
                     doNotStart = True
                 
                 # save the info for later use
@@ -1999,10 +2017,11 @@ class DebugUI(QObject):
                 if editor is None:
                     return
                 
-                if not self.viewmanager.checkDirty(
-                        editor,
-                        Preferences.getDebugger("Autosave")) or \
-                        editor.getFileName() is None:
+                if (
+                    not self.viewmanager.checkDirty(
+                        editor, Preferences.getDebugger("Autosave")) or
+                    editor.getFileName() is None
+                ):
                     return
                     
                 fn = editor.getFileName()
@@ -2068,8 +2087,10 @@ class DebugUI(QObject):
                     forkChild=forkIntoChild, clientType=self.clientType,
                     enableCallTrace=enableCallTrace)
                 
-                if self.debugServer.isClientProcessUp() and \
-                   self.debugServer.getClientType() == self.clientType:
+                if (
+                    self.debugServer.isClientProcessUp() and
+                    self.debugServer.getClientType() == self.clientType
+                ):
                     # Signal that we have started a debugging session
                     self.debuggingStarted.emit(fn)
                     
@@ -2096,14 +2117,18 @@ class DebugUI(QObject):
         # first save any changes
         if self.lastStartAction in [1, 3, 5, 7, 9]:
             editor = self.viewmanager.getOpenEditor(self.lastDebuggedFile)
-            if editor and \
-               not self.viewmanager.checkDirty(
-                    editor, Preferences.getDebugger("Autosave")):
+            if (
+                editor and
+                not self.viewmanager.checkDirty(
+                    editor, Preferences.getDebugger("Autosave"))
+            ):
                 return
             forProject = False
         elif self.lastStartAction in [2, 4, 6, 8, 10]:
-            if Preferences.getDebugger("Autosave") and \
-               not self.project.saveAllScripts(reportSyntaxErrors=True):
+            if (
+                Preferences.getDebugger("Autosave") and
+                not self.project.saveAllScripts(reportSyntaxErrors=True)
+            ):
                 doNotStart = True
             self.__compileChangedProjectFiles()
             forProject = True
