@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,14 +20,14 @@ The views avaliable are:
 </ul>
 """
 
-from __future__ import unicode_literals
 
 import os
 
 from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLineEdit, \
-    QSizePolicy, QPushButton, QComboBox, QLabel, QTreeWidget, \
-    QTreeWidgetItem, QHeaderView
+from PyQt5.QtWidgets import (
+    QWidget, QVBoxLayout, QHBoxLayout, QLineEdit, QSizePolicy, QPushButton,
+    QComboBox, QLabel, QTreeWidget, QTreeWidgetItem, QHeaderView
+)
 
 import UI.PixmapCache
 import Preferences
@@ -45,25 +45,17 @@ class DebugViewer(QWidget):
     the exception logger. Additionally a list of all threads is shown.
     
     @signal sourceFile(string, int) emitted to open a source file at a line
+    @signal preferencesChanged() emitted to react on changed preferences
     """
     sourceFile = pyqtSignal(str, int)
+    preferencesChanged = pyqtSignal()
     
-    def __init__(self, debugServer, docked, vm, parent=None,
-                 embeddedShell=True, embeddedBrowser=True):
+    def __init__(self, debugServer, parent=None):
         """
         Constructor
         
         @param debugServer reference to the debug server object (DebugServer)
-        @param docked flag indicating a dock window
-        @param vm reference to the viewmanager object
         @param parent parent widget (QWidget)
-        @param embeddedShell flag indicating whether the shell should be
-            included. This flag is set to False by those layouts, that have
-            the interpreter shell in a separate window.
-        @param embeddedBrowser flag indicating whether the file browser should
-            be included. This flag is set to False by those layouts, that
-            have the file browser in a separate window or embedded
-            in the project browser instead.
         """
         super(DebugViewer, self).__init__(parent)
         
@@ -79,27 +71,6 @@ class DebugViewer(QWidget):
         self.__tabWidget = E5TabWidget()
         self.__mainLayout.addWidget(self.__tabWidget)
         
-        self.embeddedShell = embeddedShell
-        if embeddedShell:
-            from QScintilla.Shell import ShellAssembly
-            # add the interpreter shell
-            self.shellAssembly = ShellAssembly(debugServer, vm, False)
-            self.shell = self.shellAssembly.shell()
-            index = self.__tabWidget.addTab(
-                self.shellAssembly,
-                UI.PixmapCache.getIcon("shell.png"), '')
-            self.__tabWidget.setTabToolTip(index, self.shell.windowTitle())
-        
-        self.embeddedBrowser = embeddedBrowser
-        if embeddedBrowser:
-            from UI.Browser import Browser
-            # add the browser
-            self.browser = Browser()
-            index = self.__tabWidget.addTab(
-                self.browser,
-                UI.PixmapCache.getIcon("browser.png"), '')
-            self.__tabWidget.setTabToolTip(index, self.browser.windowTitle())
-        
         from .VariablesViewer import VariablesViewer
         # add the global variables viewer
         self.glvWidget = QWidget()
@@ -197,6 +168,10 @@ class DebugViewer(QWidget):
         self.setLocalsFilterButton.clicked.connect(self.setLocalsFilter)
         self.localsFilterEdit.returnPressed.connect(self.setLocalsFilter)
         
+        self.preferencesChanged.connect(self.handlePreferencesChanged)
+        self.preferencesChanged.connect(self.globalsViewer.preferencesChanged)
+        self.preferencesChanged.connect(self.localsViewer.preferencesChanged)
+        
         from .CallStackViewer import CallStackViewer
         # add the call stack viewer
         self.callStackViewer = CallStackViewer(self.debugServer)
@@ -249,13 +224,7 @@ class DebugViewer(QWidget):
         self.__tabWidget.setTabToolTip(
             index, self.exceptionLogger.windowTitle())
         
-        if self.embeddedShell:
-            self.__tabWidget.setCurrentWidget(self.shellAssembly)
-        else:
-            if self.embeddedBrowser:
-                self.__tabWidget.setCurrentWidget(self.browser)
-            else:
-                self.__tabWidget.setCurrentWidget(self.glvWidget)
+        self.__tabWidget.setCurrentWidget(self.glvWidget)
         
         # add the threads viewer
         self.__mainLayout.addWidget(QLabel(self.tr("Threads:")))
@@ -273,7 +242,6 @@ class DebugViewer(QWidget):
         self.__mainLayout.setStretchFactor(self.__tabWidget, 5)
         self.__mainLayout.setStretchFactor(self.__threadList, 1)
         
-        self.currPage = None
         self.currentStack = None
         self.framenr = 0
         
@@ -282,7 +250,7 @@ class DebugViewer(QWidget):
         self.__autoViewSource = Preferences.getDebugger("AutoViewSourceCode")
         self.sourceButton.setVisible(not self.__autoViewSource)
         
-    def preferencesChanged(self):
+    def handlePreferencesChanged(self):
         """
         Public slot to handle the preferencesChanged signal.
         """
@@ -311,23 +279,9 @@ class DebugViewer(QWidget):
         self.currentStack = None
         self.stackComboBox.clear()
         self.__threadList.clear()
-        if self.embeddedShell:
-            self.__tabWidget.setCurrentWidget(self.shellAssembly)
-        else:
-            if self.embeddedBrowser:
-                self.__tabWidget.setCurrentWidget(self.browser)
-            else:
-                self.__tabWidget.setCurrentWidget(self.glvWidget)
+        self.__tabWidget.setCurrentWidget(self.glvWidget)
         self.breakpointViewer.handleResetUI()
         
-    def handleRawInput(self):
-        """
-        Public slot to handle the switch to the shell in raw input mode.
-        """
-        if self.embeddedShell:
-            self.saveCurrentPage()
-            self.__tabWidget.setCurrentWidget(self.shellAssembly)
-        
     def initCallStackViewer(self, projectMode):
         """
         Public method to initialize the call stack viewer.
@@ -397,19 +351,6 @@ class DebugViewer(QWidget):
         else:
             self.__tabWidget.setCurrentWidget(self.lvWidget)
         
-    def saveCurrentPage(self):
-        """
-        Public slot to save the current page.
-        """
-        self.currPage = self.__tabWidget.currentWidget()
-        
-    def restoreCurrentPage(self):
-        """
-        Public slot to restore the previously saved page.
-        """
-        if self.currPage is not None:
-            self.__tabWidget.setCurrentWidget(self.currPage)
-            
     def handleClientStack(self, stack):
         """
         Public slot to show the call stack of the program being debugged.
@@ -456,7 +397,8 @@ class DebugViewer(QWidget):
         @param frmnr frame number (0 is the current frame) (int)
         """
         self.framenr = frmnr
-        self.debugServer.remoteClientVariables(0, self.localsFilter, frmnr)
+        if self.debugServer.isDebugging():
+            self.debugServer.remoteClientVariables(0, self.localsFilter, frmnr)
         
         if self.__autoViewSource:
             self.__showSource()
@@ -465,19 +407,21 @@ class DebugViewer(QWidget):
         """
         Public slot to set the global variable filter.
         """
-        filterStr = self.globalsFilterEdit.text()
-        self.debugServer.remoteClientSetFilter(1, filterStr)
-        self.debugServer.remoteClientVariables(2, self.globalsFilter)
+        if self.debugServer.isDebugging():
+            filterStr = self.globalsFilterEdit.text()
+            self.debugServer.remoteClientSetFilter(1, filterStr)
+            self.debugServer.remoteClientVariables(2, self.globalsFilter)
         
     def setLocalsFilter(self):
         """
         Public slot to set the local variable filter.
         """
-        filterStr = self.localsFilterEdit.text()
-        self.debugServer.remoteClientSetFilter(0, filterStr)
-        if self.currentStack:
-            self.debugServer.remoteClientVariables(
-                0, self.localsFilter, self.framenr)
+        if self.debugServer.isDebugging():
+            filterStr = self.localsFilterEdit.text()
+            self.debugServer.remoteClientSetFilter(0, filterStr)
+            if self.currentStack:
+                self.debugServer.remoteClientVariables(
+                    0, self.localsFilter, self.framenr)
         
     def handleDebuggingStarted(self):
         """
