@@ -7,14 +7,14 @@
 Module implementing the Python3 debugger interface for the debug server.
 """
 
-from __future__ import unicode_literals
 
 import sys
 import os
 import logging
 
-from PyQt5.QtCore import QObject, QTextCodec, QProcess, QProcessEnvironment, \
-    QTimer
+from PyQt5.QtCore import (
+    QObject, QTextCodec, QProcess, QProcessEnvironment, QTimer
+)
 from PyQt5.QtWidgets import QInputDialog
 
 from E5Gui.E5Application import e5App
@@ -73,11 +73,11 @@ class DebuggerInterfacePython(QObject):
         if passive:
             # set translation function
             if Preferences.getDebugger("PathTranslation"):
-                self.translateRemote = \
-                    Preferences.getDebugger("PathTranslationRemote")
+                self.translateRemote = Preferences.getDebugger(
+                    "PathTranslationRemote")
                 self.translateRemoteWindows = "\\" in self.translateRemote
-                self.translateLocal = \
-                    Preferences.getDebugger("PathTranslationLocal")
+                self.translateLocal = Preferences.getDebugger(
+                    "PathTranslationLocal")
                 self.translateLocalWindows = "\\" in self.translateLocal
                 self.translate = self.__remoteTranslation
             else:
@@ -178,8 +178,8 @@ class DebuggerInterfacePython(QObject):
         venvManager = e5App().getObject("VirtualEnvManager")
         interpreter = venvManager.getVirtualenvInterpreter(venvName)
         execPath = venvManager.getVirtualenvExecPath(venvName)
-        if interpreter == "" and \
-           int(self.__variant[-1]) == sys.version_info[0]:
+        if (interpreter == "" and
+                int(self.__variant[-1]) == sys.version_info[0]):
             # use the interpreter used to run eric for identical variants
             interpreter = sys.executable.replace("w.exe", ".exe")
         if interpreter == "":
@@ -211,12 +211,12 @@ class DebuggerInterfacePython(QObject):
         
         if self.__variant == "Python2":
             redirect = str(Preferences.getDebugger("PythonRedirect"))
-            noencoding = Preferences.getDebugger("PythonNoEncoding") and \
-                '--no-encoding' or ''
+            noencoding = (Preferences.getDebugger("PythonNoEncoding") and
+                          '--no-encoding' or '')
         else:
             redirect = str(Preferences.getDebugger("Python3Redirect"))
-            noencoding = Preferences.getDebugger("Python3NoEncoding") and \
-                '--no-encoding' or ''
+            noencoding = (Preferences.getDebugger("Python3NoEncoding") and
+                          '--no-encoding' or '')
         
         if Preferences.getDebugger("RemoteDbgEnabled"):
             ipaddr = self.debugServer.getHostAddress(False)
@@ -225,10 +225,18 @@ class DebuggerInterfacePython(QObject):
             if rhost == "":
                 rhost = "localhost"
             if rexec:
-                args = Utilities.parseOptionString(rexec) + \
-                    [rhost, interpreter, debugClient,
-                        noencoding, str(port), redirect, ipaddr]
-                args[0] = Utilities.getExecutablePath(args[0])
+                args = Utilities.parseOptionString(rexec) + [
+                    rhost, interpreter, debugClient, noencoding, str(port),
+                    redirect, ipaddr]
+                if Utilities.isWindowsPlatform():
+                    if not os.path.splitext(args[0])[1]:
+                        for ext in [".exe", ".com", ".cmd", ".bat"]:
+                            prog = Utilities.getExecutablePath(args[0] + ext)
+                            if prog:
+                                args[0] = prog
+                                break
+                else:
+                    args[0] = Utilities.getExecutablePath(args[0])
                 process = self.__startProcess(args[0], args[1:],
                                               workingDir=workingDir)
                 if process is None:
@@ -241,11 +249,11 @@ class DebuggerInterfacePython(QObject):
                 
                 # set translation function
                 if Preferences.getDebugger("PathTranslation"):
-                    self.translateRemote = \
-                        Preferences.getDebugger("PathTranslationRemote")
+                    self.translateRemote = Preferences.getDebugger(
+                        "PathTranslationRemote")
                     self.translateRemoteWindows = "\\" in self.translateRemote
-                    self.translateLocal = \
-                        Preferences.getDebugger("PathTranslationLocal")
+                    self.translateLocal = Preferences.getDebugger(
+                        "PathTranslationLocal")
                     self.translate = self.__remoteTranslation
                     self.translateLocalWindows = "\\" in self.translateLocal
                 else:
@@ -283,9 +291,9 @@ class DebuggerInterfacePython(QObject):
         if runInConsole or Preferences.getDebugger("ConsoleDbgEnabled"):
             ccmd = Preferences.getDebugger("ConsoleDbgCommand")
             if ccmd:
-                args = Utilities.parseOptionString(ccmd) + \
-                    [interpreter, os.path.abspath(debugClient),
-                        noencoding, str(port), '0', ipaddr]
+                args = Utilities.parseOptionString(ccmd) + [
+                    interpreter, os.path.abspath(debugClient), noencoding,
+                    str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
                 process = self.__startProcess(args[0], args[1:], clientEnv,
                                               workingDir=workingDir)
@@ -352,15 +360,15 @@ class DebuggerInterfacePython(QObject):
                 venvName = Preferences.getDebugger("Python3VirtualEnv")
         
         redirect = str(project.getDebugProperty("REDIRECT"))
-        noencoding = \
-            project.getDebugProperty("NOENCODING") and '--no-encoding' or ''
+        noencoding = (
+            project.getDebugProperty("NOENCODING") and '--no-encoding' or '')
         
         venvManager = e5App().getObject("VirtualEnvManager")
         interpreter = venvManager.getVirtualenvInterpreter(venvName)
         execPath = venvManager.getVirtualenvExecPath(venvName)
-        if interpreter == "" and \
-           project.getProjectLanguage().startswith("Python") and \
-           sys.version_info[0] == int(project.getProjectLanguage()[-1]):
+        if (interpreter == "" and
+            project.getProjectLanguage().startswith("Python") and
+                sys.version_info[0] == int(project.getProjectLanguage()[-1])):
             interpreter = sys.executable.replace("w.exe", ".exe")
         if interpreter == "":
             E5MessageBox.critical(
@@ -378,10 +386,18 @@ class DebuggerInterfacePython(QObject):
             if rhost == "":
                 rhost = "localhost"
             if rexec:
-                args = Utilities.parseOptionString(rexec) + \
-                    [rhost, interpreter, debugClient, noencoding,
-                     str(port), redirect, ipaddr]
-                args[0] = Utilities.getExecutablePath(args[0])
+                args = Utilities.parseOptionString(rexec) + [
+                    rhost, interpreter, debugClient, noencoding, str(port),
+                    redirect, ipaddr]
+                if Utilities.isWindowsPlatform():
+                    if not os.path.splitext(args[0])[1]:
+                        for ext in [".exe", ".com", ".cmd", ".bat"]:
+                            prog = Utilities.getExecutablePath(args[0] + ext)
+                            if prog:
+                                args[0] = prog
+                                break
+                else:
+                    args[0] = Utilities.getExecutablePath(args[0])
                 process = self.__startProcess(args[0], args[1:],
                                               workingDir=workingDir)
                 if process is None:
@@ -393,11 +409,10 @@ class DebuggerInterfacePython(QObject):
                             """ started.</p>"""))
                 # set translation function
                 if project.getDebugProperty("PATHTRANSLATION"):
-                    self.translateRemote = \
-                        project.getDebugProperty("REMOTEPATH")
+                    self.translateRemote = project.getDebugProperty(
+                        "REMOTEPATH")
                     self.translateRemoteWindows = "\\" in self.translateRemote
-                    self.translateLocal = \
-                        project.getDebugProperty("LOCALPATH")
+                    self.translateLocal = project.getDebugProperty("LOCALPATH")
                     self.translateLocalWindows = "\\" in self.translateLocal
                     self.translate = self.__remoteTranslation
                 else:
@@ -436,12 +451,12 @@ class DebuggerInterfacePython(QObject):
         
         ipaddr = self.debugServer.getHostAddress(True)
         if runInConsole or project.getDebugProperty("CONSOLEDEBUGGER"):
-            ccmd = project.getDebugProperty("CONSOLECOMMAND") or \
-                Preferences.getDebugger("ConsoleDbgCommand")
+            ccmd = (project.getDebugProperty("CONSOLECOMMAND") or
+                    Preferences.getDebugger("ConsoleDbgCommand"))
             if ccmd:
-                args = Utilities.parseOptionString(ccmd) + \
-                    [interpreter, os.path.abspath(debugClient),
-                        noencoding, str(port), '0', ipaddr]
+                args = Utilities.parseOptionString(ccmd) + [
+                    interpreter, os.path.abspath(debugClient), noencoding,
+                    str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
                 process = self.__startProcess(args[0], args[1:], clientEnv,
                                               workingDir=workingDir)
@@ -911,25 +926,66 @@ class DebuggerInterfacePython(QObject):
             "text": text,
         })
     
-    def remoteUTPrepare(self, fn, tn, tfn, failed, cov, covname, coverase):
+    def remoteUTDiscover(self, syspath, workdir, discoveryStart):
+        """
+        Public method to perform a test case discovery.
+        
+        @param syspath list of directories to be added to sys.path on the
+            remote side
+        @type list of str
+        @param workdir path name of the working directory
+        @type str
+        @param discoveryStart directory to start auto-discovery at
+        @type str
+        """
+        self.__sendJsonCommand("RequestUTDiscover", {
+            "syspath": [] if syspath is None else syspath,
+            "workdir": workdir,
+            "discoverystart": discoveryStart,
+        })
+    
+    def remoteUTPrepare(self, fn, tn, tfn, failed, cov, covname, coverase,
+                        syspath, workdir, discover, discoveryStart, testCases,
+                        debug):
         """
         Public method to prepare a new unittest run.
         
-        @param fn the filename to load (string)
-        @param tn the testname to load (string)
-        @param tfn the test function name to load tests from (string)
+        @param fn name of file to load
+        @type str
+        @param tn name of test to load
+        @type str
+        @param tfn test function name to load tests from
+        @type str
         @param failed list of failed test, if only failed test should be run
-            (list of strings)
+        @type list of str
         @param cov flag indicating collection of coverage data is requested
-            (boolean)
-        @param covname filename to be used to assemble the coverage caches
-            filename (string)
+        @type bool
+        @param covname name of file to be used to assemble the coverage caches
+            filename
+        @type str
         @param coverase flag indicating erasure of coverage data is requested
-            (boolean)
+        @type bool
+        @param syspath list of directories to be added to sys.path on the
+            remote side
+        @type list of str
+        @param workdir path name of the working directory
+        @type str
+        @param discover flag indicating to discover the tests automatically
+        @type bool
+        @param discoveryStart directory to start auto-discovery at
+        @type str
+        @param testCases list of test cases to be loaded
+        @type list of str
+        @param debug flag indicating to run unittest with debugging
+        @type bool
         """
-        self.__scriptName = os.path.abspath(fn)
+        if fn:
+            self.__scriptName = os.path.abspath(fn)
+            
+            fn = self.translate(os.path.abspath(fn), False)
+        else:
+            self.__scriptName = "unittest discover"
         
-        fn = self.translate(os.path.abspath(fn), False)
         self.__sendJsonCommand("RequestUTPrepare", {
             "filename": fn,
             "testname": tn,
@@ -938,13 +994,29 @@ class DebuggerInterfacePython(QObject):
             "coverage": cov,
             "coveragefile": covname,
             "coverageerase": coverase,
+            "syspath": [] if syspath is None else syspath,
+            "workdir": workdir,
+            "discover": discover,
+            "discoverystart": discoveryStart,
+            "testcases": [] if testCases is None else testCases,
+            "debug": debug,
         })
     
-    def remoteUTRun(self):
+    def remoteUTRun(self, debug, failfast):
         """
         Public method to start a unittest run.
+        
+        @param debug flag indicating to run unittest with debugging
+        @type bool
+        @param failfast flag indicating to stop at the first error
+        @type bool
         """
-        self.__sendJsonCommand("RequestUTRun", {})
+        if debug:
+            self.__autoContinue = True
+        self.__sendJsonCommand("RequestUTRun", {
+            "debug": debug,
+            "failfast": failfast,
+        })
     
     def remoteUTStop(self):
         """
@@ -1155,12 +1227,17 @@ class DebuggerInterfacePython(QObject):
             self.debugServer.signalClientCompletionList(
                 params["completions"], params["text"])
         
+        elif method == "ResponseUTDiscover":
+            self.debugServer.clientUtDiscovered(
+                params["testCasesList"], params["exception"],
+                params["message"])
+        
         elif method == "ResponseUTPrepared":
             self.debugServer.clientUtPrepared(
                 params["count"], params["exception"], params["message"])
         
         elif method == "ResponseUTFinished":
-            self.debugServer.clientUtFinished()
+            self.debugServer.clientUtFinished(params["status"])
         
         elif method == "ResponseUTStartTest":
             self.debugServer.clientUtStartTest(
@@ -1290,7 +1367,7 @@ def getRegistryData():
         )
     
     if py3Exts and (Preferences.getDebugger("Python3VirtualEnv") or
-                    sys.version_info[0] == 3):
+                    sys.version_info[0] >= 3):
         registryData.append(
             ("Python3", ClientDefaultCapabilities, py3Exts,
                 createDebuggerInterfacePython3)
