@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Exception Logger widget.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, Qt
 from PyQt5.QtWidgets import QTreeWidget, QTreeWidgetItem, QMenu
@@ -140,5 +139,5 @@ class ExceptionLogger(QTreeWidget):
         """
         Private method to open the configuration dialog.
         """
-        e5App().getObject("UserInterface")\
-            .showPreferences("debuggerGeneralPage")
+        e5App().getObject("UserInterface").showPreferences(
+            "debuggerGeneralPage")
