@@ -1,18 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the watch expression viewer widget.
 """
 
-from __future__ import unicode_literals
 
-from PyQt5.QtCore import Qt, QModelIndex, qVersion, QItemSelectionModel, \
-    QSortFilterProxyModel
-from PyQt5.QtWidgets import QTreeView, QAbstractItemView, QMenu, QHeaderView, \
-    QDialog
+from PyQt5.QtCore import (
+    Qt, QModelIndex, QItemSelectionModel, QSortFilterProxyModel
+)
+from PyQt5.QtWidgets import (
+    QTreeView, QAbstractItemView, QMenu, QHeaderView, QDialog
+)
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -68,10 +69,7 @@ class WatchPointViewer(QTreeView):
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        if qVersion() >= "5.0.0":
-            header.setSectionsClickable(True)
-        else:
-            header.setClickable(True)
+        header.setSectionsClickable(True)
         
         self.setSortingEnabled(True)
         
@@ -160,15 +158,15 @@ class WatchPointViewer(QTreeView):
         self.backMenuActions = {}
         self.backMenu = QMenu()
         self.backMenu.addAction(self.tr("Add"), self.__addWatchPoint)
-        self.backMenuActions["EnableAll"] = \
-            self.backMenu.addAction(self.tr("Enable all"),
-                                    self.__enableAllWatchPoints)
-        self.backMenuActions["DisableAll"] = \
-            self.backMenu.addAction(self.tr("Disable all"),
-                                    self.__disableAllWatchPoints)
-        self.backMenuActions["DeleteAll"] = \
-            self.backMenu.addAction(self.tr("Delete all"),
-                                    self.__deleteAllWatchPoints)
+        self.backMenuActions["EnableAll"] = self.backMenu.addAction(
+            self.tr("Enable all"),
+            self.__enableAllWatchPoints)
+        self.backMenuActions["DisableAll"] = self.backMenu.addAction(
+            self.tr("Disable all"),
+            self.__disableAllWatchPoints)
+        self.backMenuActions["DeleteAll"] = self.backMenu.addAction(
+            self.tr("Delete all"),
+            self.__deleteAllWatchPoints)
         self.backMenu.addSeparator()
         self.backMenu.addAction(self.tr("Configure..."), self.__configure)
         self.backMenu.aboutToShow.connect(self.__showBackMenu)
@@ -221,7 +219,7 @@ class WatchPointViewer(QTreeView):
             self.__setRowSelected(index, False)
     
     def __findDuplicates(self, cond, special, showMessage=False,
-                         index=QModelIndex()):
+                         index=None):
         """
         Private method to check, if an entry already exists.
         
@@ -233,19 +231,22 @@ class WatchPointViewer(QTreeView):
             (QModelIndex)
         @return flag indicating a duplicate entry (boolean)
         """
+        if index is None:
+            index = QModelIndex()
         idx = self.__model.getWatchPointIndex(cond, special)
-        duplicate = idx.isValid() and \
-            idx.internalPointer() != index.internalPointer()
+        duplicate = (idx.isValid() and
+                     idx.internalPointer() != index.internalPointer())
         if showMessage and duplicate:
             if not special:
-                msg = self.tr("""<p>A watch expression '<b>{0}</b>'"""
-                              """ already exists.</p>""")\
-                    .format(Utilities.html_encode(cond))
+                msg = self.tr(
+                    """<p>A watch expression '<b>{0}</b>'"""
+                    """ already exists.</p>"""
+                ).format(Utilities.html_encode(cond))
             else:
                 msg = self.tr(
                     """<p>A watch expression '<b>{0}</b>'"""
-                    """ for the variable <b>{1}</b> already exists.</p>""")\
-                    .format(special, Utilities.html_encode(cond))
+                    """ for the variable <b>{1}</b> already exists.</p>"""
+                ).format(special, Utilities.html_encode(cond))
             E5MessageBox.warning(
                 self,
                 self.tr("Watch expression already exists"),
@@ -440,5 +441,5 @@ class WatchPointViewer(QTreeView):
         """
         Private method to open the configuration dialog.
         """
-        e5App().getObject("UserInterface")\
-            .showPreferences("debuggerGeneralPage")
+        e5App().getObject("UserInterface").showPreferences(
+            "debuggerGeneralPage")
