@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,7 +11,6 @@ Python file. The appearance is determined by several templates defined within
 this module.
 """
 
-from __future__ import unicode_literals
 
 import sys
 import re
@@ -83,120 +82,120 @@ class ModuleDocument(object):
             self.rbFileTemplate = TemplatesListsStyleCSS.rbFileTemplate
             self.classTemplate = TemplatesListsStyleCSS.classTemplate
             self.methodTemplate = TemplatesListsStyleCSS.methodTemplate
-            self.constructorTemplate = \
-                TemplatesListsStyleCSS.constructorTemplate
+            self.constructorTemplate = (
+                TemplatesListsStyleCSS.constructorTemplate)
             self.rbModuleTemplate = TemplatesListsStyleCSS.rbModuleTemplate
-            self.rbModulesClassTemplate = \
-                TemplatesListsStyleCSS.rbModulesClassTemplate
+            self.rbModulesClassTemplate = (
+                TemplatesListsStyleCSS.rbModulesClassTemplate)
             self.functionTemplate = TemplatesListsStyleCSS.functionTemplate
             self.listTemplate = TemplatesListsStyleCSS.listTemplate
             self.listEntryTemplate = TemplatesListsStyleCSS.listEntryTemplate
-            self.listEntryNoneTemplate = \
-                TemplatesListsStyleCSS.listEntryNoneTemplate
-            self.listEntryDeprecatedTemplate = \
-                TemplatesListsStyleCSS.listEntryDeprecatedTemplate
-            self.listEntrySimpleTemplate = \
-                TemplatesListsStyleCSS.listEntrySimpleTemplate
+            self.listEntryNoneTemplate = (
+                TemplatesListsStyleCSS.listEntryNoneTemplate)
+            self.listEntryDeprecatedTemplate = (
+                TemplatesListsStyleCSS.listEntryDeprecatedTemplate)
+            self.listEntrySimpleTemplate = (
+                TemplatesListsStyleCSS.listEntrySimpleTemplate)
             self.paragraphTemplate = TemplatesListsStyleCSS.paragraphTemplate
-            self.parametersListTemplate = \
-                TemplatesListsStyleCSS.parametersListTemplate
-            self.parameterTypesListEntryTemplate = \
-                TemplatesListsStyleCSS.parameterTypesListEntryTemplate
-            self.parametersListEntryTemplate = \
-                TemplatesListsStyleCSS.parametersListEntryTemplate
+            self.parametersListTemplate = (
+                TemplatesListsStyleCSS.parametersListTemplate)
+            self.parameterTypesListEntryTemplate = (
+                TemplatesListsStyleCSS.parameterTypesListEntryTemplate)
+            self.parametersListEntryTemplate = (
+                TemplatesListsStyleCSS.parametersListEntryTemplate)
             self.returnsTemplate = TemplatesListsStyleCSS.returnsTemplate
-            self.returnTypesTemplate = \
-                TemplatesListsStyleCSS.returnTypesTemplate
-            self.exceptionsListTemplate = \
-                TemplatesListsStyleCSS.exceptionsListTemplate
-            self.exceptionsListEntryTemplate = \
-                TemplatesListsStyleCSS.exceptionsListEntryTemplate
-            self.signalsListTemplate = \
-                TemplatesListsStyleCSS.signalsListTemplate
-            self.signalsListEntryTemplate = \
-                TemplatesListsStyleCSS.signalsListEntryTemplate
+            self.returnTypesTemplate = (
+                TemplatesListsStyleCSS.returnTypesTemplate)
+            self.exceptionsListTemplate = (
+                TemplatesListsStyleCSS.exceptionsListTemplate)
+            self.exceptionsListEntryTemplate = (
+                TemplatesListsStyleCSS.exceptionsListEntryTemplate)
+            self.signalsListTemplate = (
+                TemplatesListsStyleCSS.signalsListTemplate)
+            self.signalsListEntryTemplate = (
+                TemplatesListsStyleCSS.signalsListEntryTemplate)
             self.eventsListTemplate = TemplatesListsStyleCSS.eventsListTemplate
-            self.eventsListEntryTemplate = \
-                TemplatesListsStyleCSS.eventsListEntryTemplate
+            self.eventsListEntryTemplate = (
+                TemplatesListsStyleCSS.eventsListEntryTemplate)
             self.deprecatedTemplate = TemplatesListsStyleCSS.deprecatedTemplate
             self.authorInfoTemplate = TemplatesListsStyleCSS.authorInfoTemplate
             self.seeListTemplate = TemplatesListsStyleCSS.seeListTemplate
-            self.seeListEntryTemplate = \
-                TemplatesListsStyleCSS.seeListEntryTemplate
+            self.seeListEntryTemplate = (
+                TemplatesListsStyleCSS.seeListEntryTemplate)
             self.seeLinkTemplate = TemplatesListsStyleCSS.seeLinkTemplate
             self.sinceInfoTemplate = TemplatesListsStyleCSS.sinceInfoTemplate
         else:
             from . import TemplatesListsStyle
-            self.headerTemplate = \
-                TemplatesListsStyle.headerTemplate.format(**colors)
-            self.footerTemplate = \
-                TemplatesListsStyle.footerTemplate.format(**colors)
-            self.moduleTemplate = \
-                TemplatesListsStyle.moduleTemplate.format(**colors)
-            self.rbFileTemplate = \
-                TemplatesListsStyle.rbFileTemplate.format(**colors)
-            self.classTemplate = \
-                TemplatesListsStyle.classTemplate.format(**colors)
-            self.methodTemplate = \
-                TemplatesListsStyle.methodTemplate.format(**colors)
-            self.constructorTemplate = \
-                TemplatesListsStyle.constructorTemplate.format(**colors)
-            self.rbModuleTemplate = \
-                TemplatesListsStyle.rbModuleTemplate.format(**colors)
-            self.rbModulesClassTemplate = \
-                TemplatesListsStyle.rbModulesClassTemplate.format(**colors)
-            self.functionTemplate = \
-                TemplatesListsStyle.functionTemplate.format(**colors)
-            self.listTemplate = \
-                TemplatesListsStyle.listTemplate.format(**colors)
-            self.listEntryTemplate = \
-                TemplatesListsStyle.listEntryTemplate.format(**colors)
-            self.listEntryNoneTemplate = \
-                TemplatesListsStyle.listEntryNoneTemplate.format(**colors)
-            self.listEntryDeprecatedTemplate = \
+            self.headerTemplate = (
+                TemplatesListsStyle.headerTemplate.format(**colors))
+            self.footerTemplate = (
+                TemplatesListsStyle.footerTemplate.format(**colors))
+            self.moduleTemplate = (
+                TemplatesListsStyle.moduleTemplate.format(**colors))
+            self.rbFileTemplate = (
+                TemplatesListsStyle.rbFileTemplate.format(**colors))
+            self.classTemplate = (
+                TemplatesListsStyle.classTemplate.format(**colors))
+            self.methodTemplate = (
+                TemplatesListsStyle.methodTemplate.format(**colors))
+            self.constructorTemplate = (
+                TemplatesListsStyle.constructorTemplate.format(**colors))
+            self.rbModuleTemplate = (
+                TemplatesListsStyle.rbModuleTemplate.format(**colors))
+            self.rbModulesClassTemplate = (
+                TemplatesListsStyle.rbModulesClassTemplate.format(**colors))
+            self.functionTemplate = (
+                TemplatesListsStyle.functionTemplate.format(**colors))
+            self.listTemplate = (
+                TemplatesListsStyle.listTemplate.format(**colors))
+            self.listEntryTemplate = (
+                TemplatesListsStyle.listEntryTemplate.format(**colors))
+            self.listEntryNoneTemplate = (
+                TemplatesListsStyle.listEntryNoneTemplate.format(**colors))
+            self.listEntryDeprecatedTemplate = (
                 TemplatesListsStyle.listEntryDeprecatedTemplate.format(
-                    **colors)
-            self.listEntrySimpleTemplate = \
-                TemplatesListsStyle.listEntrySimpleTemplate.format(**colors)
-            self.paragraphTemplate = \
-                TemplatesListsStyle.paragraphTemplate.format(**colors)
-            self.parametersListTemplate = \
-                TemplatesListsStyle.parametersListTemplate.format(**colors)
-            self.parametersListEntryTemplate = \
+                    **colors))
+            self.listEntrySimpleTemplate = (
+                TemplatesListsStyle.listEntrySimpleTemplate.format(**colors))
+            self.paragraphTemplate = (
+                TemplatesListsStyle.paragraphTemplate.format(**colors))
+            self.parametersListTemplate = (
+                TemplatesListsStyle.parametersListTemplate.format(**colors))
+            self.parametersListEntryTemplate = (
                 TemplatesListsStyle.parametersListEntryTemplate.format(
-                    **colors)
-            self.parameterTypesListEntryTemplate = \
+                    **colors))
+            self.parameterTypesListEntryTemplate = (
                 TemplatesListsStyle.parameterTypesListEntryTemplate.format(
-                    **colors)
-            self.returnsTemplate = \
-                TemplatesListsStyle.returnsTemplate.format(**colors)
-            self.returnTypesTemplate = \
-                TemplatesListsStyle.returnTypesTemplate.format(**colors)
-            self.exceptionsListTemplate = \
-                TemplatesListsStyle.exceptionsListTemplate.format(**colors)
-            self.exceptionsListEntryTemplate = \
+                    **colors))
+            self.returnsTemplate = (
+                TemplatesListsStyle.returnsTemplate.format(**colors))
+            self.returnTypesTemplate = (
+                TemplatesListsStyle.returnTypesTemplate.format(**colors))
+            self.exceptionsListTemplate = (
+                TemplatesListsStyle.exceptionsListTemplate.format(**colors))
+            self.exceptionsListEntryTemplate = (
                 TemplatesListsStyle.exceptionsListEntryTemplate.format(
-                    **colors)
-            self.signalsListTemplate = \
-                TemplatesListsStyle.signalsListTemplate.format(**colors)
-            self.signalsListEntryTemplate = \
-                TemplatesListsStyle.signalsListEntryTemplate.format(**colors)
-            self.eventsListTemplate = \
-                TemplatesListsStyle.eventsListTemplate.format(**colors)
-            self.eventsListEntryTemplate = \
-                TemplatesListsStyle.eventsListEntryTemplate.format(**colors)
-            self.deprecatedTemplate = \
-                TemplatesListsStyle.deprecatedTemplate.format(**colors)
-            self.authorInfoTemplate = \
-                TemplatesListsStyle.authorInfoTemplate.format(**colors)
-            self.seeListTemplate = \
-                TemplatesListsStyle.seeListTemplate.format(**colors)
-            self.seeListEntryTemplate = \
-                TemplatesListsStyle.seeListEntryTemplate.format(**colors)
-            self.seeLinkTemplate = \
-                TemplatesListsStyle.seeLinkTemplate.format(**colors)
-            self.sinceInfoTemplate = \
-                TemplatesListsStyle.sinceInfoTemplate.format(**colors)
+                    **colors))
+            self.signalsListTemplate = (
+                TemplatesListsStyle.signalsListTemplate.format(**colors))
+            self.signalsListEntryTemplate = (
+                TemplatesListsStyle.signalsListEntryTemplate.format(**colors))
+            self.eventsListTemplate = (
+                TemplatesListsStyle.eventsListTemplate.format(**colors))
+            self.eventsListEntryTemplate = (
+                TemplatesListsStyle.eventsListEntryTemplate.format(**colors))
+            self.deprecatedTemplate = (
+                TemplatesListsStyle.deprecatedTemplate.format(**colors))
+            self.authorInfoTemplate = (
+                TemplatesListsStyle.authorInfoTemplate.format(**colors))
+            self.seeListTemplate = (
+                TemplatesListsStyle.seeListTemplate.format(**colors))
+            self.seeListEntryTemplate = (
+                TemplatesListsStyle.seeListEntryTemplate.format(**colors))
+            self.seeLinkTemplate = (
+                TemplatesListsStyle.seeLinkTemplate.format(**colors))
+            self.sinceInfoTemplate = (
+                TemplatesListsStyle.sinceInfoTemplate.format(**colors))
         
         self.keywords = []
         # list of tuples containing the name (string) and
@@ -246,11 +245,14 @@ class ModuleDocument(object):
         
         @return The source code documentation. (string)
         """
-        doc = self.headerTemplate.format(
-            **{'Title': self.module.name,
-               'Style': self.stylesheet}) + \
-            self.__genModuleSection() + \
+        doc = (
+            self.headerTemplate.format(
+                **{'Title': self.module.name,
+                   'Style': self.stylesheet}
+            ) +
+            self.__genModuleSection() +
             self.footerTemplate
+        )
         self.generated = True
         return doc
         
@@ -302,24 +304,25 @@ class ModuleDocument(object):
         return "{0}{1}{2}{3}".format(
             modBody, classesSection, rbModulesSection, functionsSection)
         
-    def __genListSection(self, names, dict, kwSuffix=""):
+    def __genListSection(self, names, sectionDict, kwSuffix=""):
         """
         Private method to generate a list section of the document.
         
         @param names The names to appear in the list. (list of strings)
-        @param dict A dictionary containing all relevant information.
+        @param sectionDict dictionary containing all relevant information
+            (dict)
         @param kwSuffix suffix to be used for the QtHelp keywords (string)
-        @return The list section. (string)
+        @return list section (string)
         """
         lst = []
         for name in names:
             lst.append(self.listEntryTemplate.format(
                 **{'Link': "{0}".format(name),
-                   'Name': dict[name].name,
+                   'Name': sectionDict[name].name,
                    'Description':
-                    self.__getShortDescription(dict[name].description),
+                    self.__getShortDescription(sectionDict[name].description),
                    'Deprecated':
-                    self.__checkDeprecated(dict[name].description) and
+                    self.__checkDeprecated(sectionDict[name].description) and
                     self.listEntryDeprecatedTemplate or "",
                    }))
             if kwSuffix:
@@ -342,8 +345,8 @@ class ModuleDocument(object):
             scope = class_
         else:
             scope = self.module
-        attrNames = sorted([attr for attr in scope.globals.keys()
-                           if not scope.globals[attr].isSignal])
+        attrNames = sorted(attr for attr in scope.globals.keys()
+                           if not scope.globals[attr].isSignal)
         if attrNames:
             s = ''.join(
                 [self.listEntrySimpleTemplate.format(**{'Name': name})
@@ -415,12 +418,12 @@ class ModuleDocument(object):
                 supers = 'None'
             
             globalsList = self.__genGlobalsListSection(_class)
-            classMethList, classMethBodies = \
-                self.__genMethodSection(_class, className, Function.Class)
-            methList, methBodies = \
-                self.__genMethodSection(_class, className, Function.General)
-            staticMethList, staticMethBodies = \
-                self.__genMethodSection(_class, className, Function.Static)
+            classMethList, classMethBodies = self.__genMethodSection(
+                _class, className, Function.Class)
+            methList, methBodies = self.__genMethodSection(
+                _class, className, Function.General)
+            staticMethList, staticMethBodies = self.__genMethodSection(
+                _class, className, Function.Static)
             
             try:
                 clsBody = self.classTemplate.format(
@@ -449,13 +452,14 @@ class ModuleDocument(object):
             
         return ''.join(classes)
         
-    def __genMethodsListSection(self, names, dict, className, clsName,
+    def __genMethodsListSection(self, names, sectionDict, className, clsName,
                                 includeInit=True):
         """
         Private method to generate the methods list section of a class.
         
         @param names names to appear in the list (list of strings)
-        @param dict dictionary containing all relevant information
+        @param sectionDict dictionary containing all relevant information
+            (dict)
         @param className class name containing the names
         @param clsName visible class name containing the names
         @param includeInit flag indicating to include the __init__ method
@@ -469,9 +473,9 @@ class ModuleDocument(object):
                     **{'Link': "{0}.{1}".format(className, '__init__'),
                        'Name': clsName,
                        'Description': self.__getShortDescription(
-                           dict['__init__'].description),
+                           sectionDict['__init__'].description),
                        'Deprecated': self.__checkDeprecated(
-                           dict['__init__'].description) and
+                           sectionDict['__init__'].description) and
                         self.listEntryDeprecatedTemplate or "",
                        }))
                 self.keywords.append(
@@ -483,30 +487,30 @@ class ModuleDocument(object):
         for name in names:
             lst.append(self.listEntryTemplate.format(
                 **{'Link': "{0}.{1}".format(className, name),
-                   'Name': dict[name].name,
+                   'Name': sectionDict[name].name,
                    'Description':
-                    self.__getShortDescription(dict[name].description),
+                    self.__getShortDescription(sectionDict[name].description),
                    'Deprecated':
-                    self.__checkDeprecated(dict[name].description) and
+                    self.__checkDeprecated(sectionDict[name].description) and
                     self.listEntryDeprecatedTemplate or "",
                    }))
             self.keywords.append(("{0}.{1}".format(className, name),
                                   "#{0}.{1}".format(className, name)))
         return ''.join(lst)
         
-    def __genMethodSection(self, obj, className, filter):
+    def __genMethodSection(self, obj, className, modifierFilter):
         """
         Private method to generate the method details section.
         
         @param obj reference to the object being formatted
         @param className name of the class containing the method (string)
-        @param filter filter value designating the method types
+        @param modifierFilter filter value designating the method types
         @return method list and method details section (tuple of two string)
         """
         methList = []
         methBodies = []
-        methods = sorted([k for k in obj.methods.keys()
-                          if obj.methods[k].modifier == filter])
+        methods = sorted(k for k in obj.methods.keys()
+                         if obj.methods[k].modifier == modifierFilter)
         if '__init__' in methods:
             methods.remove('__init__')
             try:
@@ -530,9 +534,9 @@ class ModuleDocument(object):
                 methBody = ""
             methBodies.append(methBody)
         
-        if filter == Function.Class:
+        if modifierFilter == Function.Class:
             methodClassifier = " (class method)"
-        elif filter == Function.Static:
+        elif modifierFilter == Function.Static:
             methodClassifier = " (static)"
         else:
             methodClassifier = ""
@@ -560,7 +564,7 @@ class ModuleDocument(object):
             
         methList = self.__genMethodsListSection(
             methods, obj.methods, className, obj.name,
-            includeInit=filter == Function.General)
+            includeInit=modifierFilter == Function.General)
         
         if not methList:
             methList = self.listEntryNoneTemplate
@@ -628,8 +632,8 @@ class ModuleDocument(object):
             else:
                 supers = 'None'
             
-            methList, methBodies = \
-                self.__genMethodSection(_class, className, Function.General)
+            methList, methBodies = self.__genMethodSection(
+                _class, className, Function.General)
             
             try:
                 clsBody = self.rbModulesClassTemplate.format(
@@ -660,13 +664,14 @@ class ModuleDocument(object):
         return (self.listTemplate.format(**{'Entries': classesList}),
                 ''.join(classes))
         
-    def __genRbModulesClassesListSection(self, names, dict, moduleName):
+    def __genRbModulesClassesListSection(self, names, sectionDict, moduleName):
         """
         Private method to generate the classes list section of a Ruby module.
         
         @param names The names to appear in the list. (list of strings)
-        @param dict A dictionary containing all relevant information.
-        @param moduleName Name of the Ruby module containing the classes.
+        @param sectionDict dictionary containing all relevant information
+            (dict)
+        @param moduleName name of the Ruby module containing the classes
             (string)
         @return The list section. (string)
         """
@@ -674,11 +679,11 @@ class ModuleDocument(object):
         for name in names:
             lst.append(self.listEntryTemplate.format(
                 **{'Link': "{0}.{1}".format(moduleName, name),
-                   'Name': dict[name].name,
+                   'Name': sectionDict[name].name,
                    'Description':
-                    self.__getShortDescription(dict[name].description),
+                    self.__getShortDescription(sectionDict[name].description),
                    'Deprecated':
-                    self.__checkDeprecated(dict[name].description) and
+                    self.__checkDeprecated(sectionDict[name].description) and
                     self.listEntryDeprecatedTemplate or "",
                    }))
             self.keywords.append(("{0}.{1}".format(moduleName, name),
@@ -738,8 +743,10 @@ class ModuleDocument(object):
                 if dotpos == -1:
                     sdlist.append(desc.strip())
                 else:
-                    while dotpos + 1 < len(desc) and \
-                            not desc[dotpos + 1].isspace():
+                    while (
+                        dotpos + 1 < len(desc) and
+                        not desc[dotpos + 1].isspace()
+                    ):
                         # don't recognize '.' inside a number or word as
                         # stop condition
                         dotpos = desc.find('.', dotpos + 1)
@@ -1043,10 +1050,13 @@ class ModuleDocument(object):
                     m = _signal(desc, 0)
                     if m is None:
                         raise TagError("Wrong format in @signal line.\n")
-                    signalName = 1 and m.group("SignalName1") \
-                        or m.group("SignalName2")
-                    signalDesc = 1 and m.group("SignalDescription1") \
-                        or m.group("SignalDescription2")
+                    signalName = (
+                        1 and m.group("SignalName1") or m.group("SignalName2")
+                    )
+                    signalDesc = (
+                        1 and m.group("SignalDescription1") or
+                        m.group("SignalDescription2")
+                    )
                     signalDict[signalName] = []
                     if signalDesc is not None:
                         signalDict[signalName].append(signalDesc)
@@ -1058,10 +1068,13 @@ class ModuleDocument(object):
                     if m is None:
                         raise TagError(
                             "Wrong format in {0} line.\n".format(parts[0]))
-                    eventName = 1 and m.group("EventName1") \
-                        or m.group("EventName2")
-                    eventDesc = 1 and m.group("EventDescription1") \
-                        or m.group("EventDescription2")
+                    eventName = (
+                        1 and m.group("EventName1") or m.group("EventName2")
+                    )
+                    eventDesc = (
+                        1 and m.group("EventDescription1") or
+                        m.group("EventDescription2")
+                    )
                     eventDict[eventName] = []
                     if eventDesc is not None:
                         eventDict[eventName].append(eventDesc)
