@@ -8,15 +8,16 @@ Module implementing the QtHelp generator for the builtin documentation
 generator.
 """
 
-from __future__ import unicode_literals
 
 import sys
 import os
 import shutil
 import subprocess
 
-from Utilities import joinext, relpath, html_encode, getQtBinariesPath, \
-    generateQtToolName
+from Utilities import (
+    joinext, relpath, html_encode, getQtBinariesPath, generateQtToolName,
+    isExecutable
+)
 
 HelpCollection = r"""<?xml version="1.0" encoding="utf-8" ?>
 <QHelpCollectionProject version="1.0">
@@ -83,8 +84,9 @@ class QtHelpGenerator(object):
         self.namespace = namespace
         self.virtualFolder = virtualFolder
         self.filterName = filterName
-        self.filterAttributes = \
+        self.filterAttributes = (
             filterAttributes and filterAttributes.split(':') or []
+        )
         self.relPath = relpath(self.htmlDir, self.outputDir)
         self.title = title
         self.createCollection = createCollection
@@ -249,9 +251,11 @@ class QtHelpGenerator(object):
         f.write(txt)
         f.close()
         
-        if self.createCollection and \
-           not os.path.exists(
-                os.path.join(self.outputDir, HelpCollectionProjectFile)):
+        if (
+            self.createCollection and
+            not os.path.exists(os.path.join(
+                self.outputDir, HelpCollectionProjectFile))
+        ):
             collectionAttribs = {
                 "helpfile": HelpHelpFile,
             }
@@ -270,23 +274,30 @@ class QtHelpGenerator(object):
         
         cwd = os.getcwd()
         # generate the compressed files
+        qhelpgeneratorExe = os.path.join(
+            getQtBinariesPath(), generateQtToolName("qhelpgenerator")
+        )
         shutil.copy(
             os.path.join(self.outputDir, HelpProjectFile), self.htmlDir)
         os.chdir(self.htmlDir)
         subprocess.call([
-            os.path.join(getQtBinariesPath(),
-                         generateQtToolName("qhelpgenerator")),
+            qhelpgeneratorExe,
             HelpProjectFile, "-o", os.path.join(self.outputDir, HelpHelpFile)])
         os.remove(HelpProjectFile)
         
         if self.createCollection:
+            qcollectiongeneratorExe = os.path.join(
+                getQtBinariesPath(), generateQtToolName("qcollectiongenerator")
+            )
+            if not isExecutable(qcollectiongeneratorExe):
+                # assume Qt >= 5.12.0
+                qcollectiongeneratorExe = qhelpgeneratorExe
             sys.stdout.write("Generating QtHelp collection...\n")
             sys.stdout.flush()
             sys.stderr.flush()
             os.chdir(self.outputDir)
             subprocess.call([
-                os.path.join(getQtBinariesPath(),
-                             generateQtToolName("qcollectiongenerator")),
+                qcollectiongeneratorExe,
                 HelpCollectionProjectFile, "-o", HelpCollectionFile])
         
         os.chdir(cwd)
