@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a graphics item subclass for an arrow.
 """
 
-from __future__ import unicode_literals
 
 import math
 
@@ -19,7 +18,7 @@ NormalArrow = 1
 WideArrow = 2
 
 ArrowheadAngleFactor = 0.26179938779914941
-# 0.5 * math.atan(math.sqrt(3.0) / 3.0)
+# That is: 0.5 * math.atan(math.sqrt(3.0) / 3.0)
 
 
 class E5ArrowItem(QAbstractGraphicsShapeItem):
@@ -93,9 +92,8 @@ class E5ArrowItem(QAbstractGraphicsShapeItem):
         """
         extra = self._halfLength / 2.0
         return QRectF(self._origin, QSizeF(self._end.x() - self._origin.x(),
-                                           self._end.y() - self._origin.y()))\
-            .normalized()\
-            .adjusted(-extra, -extra, extra, extra)
+                                           self._end.y() - self._origin.y())
+                      ).normalized().adjusted(-extra, -extra, extra, extra)
         
     def paint(self, painter, option, widget=None):
         """
@@ -105,8 +103,10 @@ class E5ArrowItem(QAbstractGraphicsShapeItem):
         @param option style options (QStyleOptionGraphicsItem)
         @param widget optional reference to the widget painted on (QWidget)
         """
-        if (option.state & QStyle.State_Selected) == \
-                QStyle.State(QStyle.State_Selected):
+        if (
+            (option.state & QStyle.State_Selected) ==
+            QStyle.State(QStyle.State_Selected)
+        ):
             width = 2
         else:
             width = 1
