@@ -7,7 +7,6 @@
 Module implementing a clickable label.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, Qt, QPoint
 from PyQt5.QtWidgets import QLabel
@@ -46,8 +45,10 @@ class E5ClickableLabel(QLabel):
                 self.middleClicked.emit(evt.globalPos())
             else:
                 self.clicked.emit(evt.globalPos())
-        elif evt.button() == Qt.MidButton and \
-                self.rect().contains(evt.pos()):
+        elif (
+            evt.button() == Qt.MidButton and
+            self.rect().contains(evt.pos())
+        ):
             self.middleClicked.emit(evt.globalPos())
         else:
             super(E5ClickableLabel, self).mouseReleaseEvent(evt)
