@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,6 @@ Module implementing a LED widget.
 It was inspired by KLed.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, Qt, QSize, QPoint
 from PyQt5.QtGui import QColor, QRadialGradient, QPalette, QPainter, QBrush
@@ -310,8 +309,10 @@ class E5ClickableLed(E5Led):
                 self.middleClicked.emit(evt.globalPos())
             else:
                 self.clicked.emit(evt.globalPos())
-        elif evt.button() == Qt.MidButton and \
-                self.rect().contains(evt.pos()):
+        elif (
+            evt.button() == Qt.MidButton and
+            self.rect().contains(evt.pos())
+        ):
             self.middleClicked.emit(evt.globalPos())
         else:
             super(E5ClickableLed, self).mouseReleaseEvent(evt)
