@@ -1,22 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing specialized line edits.
 """
 
-from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, Qt, QEvent, qVersion
-from PyQt5.QtGui import QPainter, QPalette
-from PyQt5.QtWidgets import QLineEdit, QStyle, QWidget, QHBoxLayout, \
-    QBoxLayout, QLayout, QApplication, QSpacerItem, QSizePolicy
-if qVersion() >= "5.0.0":
-    from PyQt5.QtWidgets import QStyleOptionFrame
-else:
-    from PyQt5.QtWidgets import QStyleOptionFrameV2 as QStyleOptionFrame
+from PyQt5.QtCore import pyqtSignal, Qt, QEvent
+from PyQt5.QtWidgets import (
+    QLineEdit, QWidget, QHBoxLayout, QBoxLayout, QLayout, QApplication,
+    QSpacerItem, QSizePolicy
+)
 
 import UI.PixmapCache
 
@@ -24,6 +20,8 @@ import UI.PixmapCache
 class E5LineEditSideWidget(QWidget):
     """
     Class implementing the side widgets for the line edit class.
+    
+    @signal sizeHintChanged() emitted to indicate a change of the size hint
     """
     sizeHintChanged = pyqtSignal()
     
@@ -65,10 +63,7 @@ class E5LineEdit(QLineEdit):
         
         self.setMinimumHeight(22)
         
-        if qVersion() < "4.7.0":
-            self.__inactiveText = inactiveText
-        else:
-            self.setPlaceholderText(inactiveText)
+        self.setPlaceholderText(inactiveText)
         
         self.__mainLayout = QHBoxLayout(self)
         self.__mainLayout.setContentsMargins(0, 0, 0, 0)
@@ -144,33 +139,6 @@ class E5LineEdit(QLineEdit):
                 self.__rightLayout.setDirection(QBoxLayout.LeftToRight)
         return QLineEdit.event(self, evt)
     
-    def paintEvent(self, evt):
-        """
-        Protected method handling a paint event.
-        
-        @param evt reference to the paint event (QPaintEvent)
-        """
-        super(E5LineEdit, self).paintEvent(evt)
-        
-        if qVersion() < "4.7.0":
-            if not self.text() and \
-               self.__inactiveText and \
-               not self.hasFocus():
-                panel = QStyleOptionFrame()
-                self.initStyleOption(panel)
-                textRect = self.style().subElementRect(
-                    QStyle.SE_LineEditContents, panel, self)
-                textRect.adjust(2, 0, 0, 0)
-                left = self.textMargin(self.LeftSide)
-                right = self.textMargin(self.RightSide)
-                textRect.adjust(left, 0, -right, 0)
-                painter = QPainter(self)
-                painter.setPen(self.palette().brush(
-                    QPalette.Disabled, QPalette.Text).color())
-                painter.drawText(
-                    textRect, Qt.AlignLeft | Qt.AlignVCenter,
-                    self.__inactiveText)
-    
     def _updateTextMargins(self):
         """
         Protected slot to update the text margins.
@@ -260,10 +228,7 @@ class E5LineEdit(QLineEdit):
         
         @return inactive text (string)
         """
-        if qVersion() < "4.7.0":
-            return self.__inactiveText
-        else:
-            return self.placeholderText()
+        return self.placeholderText()
     
     def setInactiveText(self, inactiveText):
         """
@@ -271,11 +236,7 @@ class E5LineEdit(QLineEdit):
         
         @param inactiveText text to be shown on inactivity (string)
         """
-        if qVersion() < "4.7.0":
-            self.__inactiveText = inactiveText
-            self.update()
-        else:
-            self.setPlaceholderText(inactiveText)
+        self.setPlaceholderText(inactiveText)
 
 
 class E5ClearableLineEdit(E5LineEdit):
