@@ -1,20 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a base class for showing a document map.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import Qt, QSize, QRect, QCoreApplication
 from PyQt5.QtGui import QColor, QBrush, QPainter
 from PyQt5.QtWidgets import QWidget, QAbstractScrollArea
 
-from Globals import qVersionTuple
-
 
 class E5MapWidget(QWidget):
     """
@@ -37,6 +34,7 @@ class E5MapWidget(QWidget):
         
         self._master = None
         self.__enabled = False
+        self.__rightSide = True
         
         if parent is not None and isinstance(parent, QAbstractScrollArea):
             self.setMaster(parent)
@@ -62,7 +60,10 @@ class E5MapWidget(QWidget):
                 width = self.__width
             else:
                 width = 0
-            self._master.setViewportMargins(0, 0, width, 0)
+            if self.__rightSide:
+                self._master.setViewportMargins(0, 0, width, 0)
+            else:
+                self._master.setViewportMargins(width, 0, 0, 0)
     
     def setMaster(self, master):
         """
@@ -72,8 +73,8 @@ class E5MapWidget(QWidget):
         """
         self._master = master
         self._master.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
-        self._master.verticalScrollBar().valueChanged.connect(self.repaint)
-        self._master.verticalScrollBar().rangeChanged.connect(self.repaint)
+        self._master.verticalScrollBar().valueChanged.connect(self.update)
+        self._master.verticalScrollBar().rangeChanged.connect(self.update)
         self.__updateMasterViewportWidth()
     
     def setWidth(self, width):
@@ -95,6 +96,31 @@ class E5MapWidget(QWidget):
         """
         return self.__width
     
+    def setMapPosition(self, onRight):
+        """
+        Public method to set, whether the map should be shown to the right or
+        left of the master widget.
+        
+        @param onRight flag indicating to show the map on the right side of
+            the master widget
+        @type bool
+        """
+        if onRight != self.__rightSide:
+            self.__rightSide = onRight
+            self.__updateMasterViewportWidth()
+            self.update()
+    
+    def isOnRightSide(self):
+        """
+        Public method to test, if the map is shown on the right side of the
+        master widget.
+        
+        @return flag indicating that the map is to the right of the master
+            widget
+        @rtype bool
+        """
+        return self.__rightSide
+    
     def setLineDimensions(self, border, height):
         """
         Public method to set the line (indicator) dimensions.
@@ -222,13 +248,12 @@ class E5MapWidget(QWidget):
         
         @param event reference to the wheel event (QWheelEvent)
         """
-        if qVersionTuple() >= (5, 0, 0):
-            isVertical = event.angleDelta().x() == 0
-        else:
-            isVertical = event.orientation() == Qt.Vertical
-        if self._master and \
-            event.modifiers() == Qt.NoModifier and \
-                isVertical:
+        isVertical = event.angleDelta().x() == 0
+        if (
+            self._master and
+            event.modifiers() == Qt.NoModifier and
+            isVertical
+        ):
             QCoreApplication.sendEvent(self._master.verticalScrollBar(), event)
     
     def calculateGeometry(self):
@@ -245,8 +270,13 @@ class E5MapWidget(QWidget):
             left, top, right, bottom = self._master.getContentsMargins()
             if right > vsbw:
                 vsbw = 0
-            self.setGeometry(QRect(cr.right() - self.__width - vsbw, cr.top(),
-                                   self.__width, cr.height()))
+            if self.__rightSide:
+                self.setGeometry(
+                    QRect(cr.right() - self.__width - vsbw, cr.top(),
+                          self.__width, cr.height()))
+            else:
+                self.setGeometry(
+                    QRect(0, cr.top(), self.__width, cr.height()))
             self.update()
     
     def scaleFactor(self, slider=False):
