@@ -7,14 +7,12 @@
 Module implementing a menu populated from a QAbstractItemModel.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, Qt, QModelIndex, QPoint
-from PyQt5.QtGui import QFontMetrics, QDrag, QPixmap
+from PyQt5.QtGui import QFontMetrics, QDrag
 from PyQt5.QtWidgets import QMenu, QAction, QApplication
 
 import UI.PixmapCache
-from Globals import qVersionTuple
 
 
 class E5ModelMenu(QMenu):
@@ -228,8 +226,10 @@ class E5ModelMenu(QMenu):
             if self.__model.hasChildren(idx):
                 self.createMenu(idx, -1, menu)
             else:
-                if self.__separatorRole != 0 and \
-                        idx.data(self.__separatorRole):
+                if (
+                    self.__separatorRole != 0 and
+                    idx.data(self.__separatorRole)
+                ):
                     self.addSeparator()
                 else:
                     menu.addAction(self.__makeAction(idx))
@@ -393,10 +393,7 @@ class E5ModelMenu(QMenu):
         drag = QDrag(self)
         drag.setMimeData(self.__model.mimeData([idx]))
         actionRect = self.actionGeometry(act)
-        if qVersionTuple() >= (5, 0, 0):
-            drag.setPixmap(self.grab(actionRect))
-        else:
-            drag.setPixmap(QPixmap.grabWidget(self, actionRect))
+        drag.setPixmap(self.grab(actionRect))
         
         if drag.exec_() == Qt.MoveAction:
             row = idx.row()
