@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a path picker widget.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -16,7 +15,7 @@ try:
 except ImportError:
     from ThirdParty.enum import Enum
 
-from PyQt5.QtCore import pyqtSignal, Qt, QFileInfo
+from PyQt5.QtCore import pyqtSignal, Qt, QFileInfo, QCoreApplication, QDir
 from PyQt5.QtWidgets import QWidget, QHBoxLayout, QToolButton, QSizePolicy
 
 from . import E5FileDialog
@@ -25,7 +24,6 @@ from .E5Completers import E5FileCompleter, E5DirCompleter
 from .E5ComboBox import E5ClearableComboBox
 
 import UI.PixmapCache
-import Utilities
 
 
 class E5PathPickerModes(Enum):
@@ -94,10 +92,12 @@ class E5PathPickerBase(QWidget):
         
         if useLineEdit:
             self._editor = E5ClearableLineEdit(
-                self, self.tr("Enter Path Name"))
+                self, QCoreApplication.translate(
+                    "E5PathPickerBase", "Enter Path Name"))
         else:
             self._editor = E5ClearableComboBox(
-                self, self.tr("Enter Path Name"))
+                self, QCoreApplication.translate(
+                    "E5PathPickerBase", "Enter Path Name"))
         
         self.__button = QToolButton(self)
         self.__button.setToolButtonStyle(Qt.ToolButtonIconOnly)
@@ -127,7 +127,7 @@ class E5PathPickerBase(QWidget):
         @type str
         """
         if self._completer and not self._completer.popup().isVisible():
-            self._completer.setRootPath(Utilities.toNativeSeparators(path))
+            self._completer.setRootPath(QDir.toNativeSeparators(path))
     
     def setMode(self, mode):
         """
@@ -244,7 +244,7 @@ class E5PathPickerBase(QWidget):
             self._setEditorText(path)
         else:
             if toNative:
-                path = Utilities.toNativeSeparators(path)
+                path = QDir.toNativeSeparators(path)
             self._setEditorText(path)
             if self._completer:
                 self._completer.setRootPath(path)
@@ -262,14 +262,14 @@ class E5PathPickerBase(QWidget):
         if self.__mode == E5PathPickerModes.OpenFilesMode:
             if toNative:
                 return ";".join(
-                    [Utilities.toNativeSeparators(path)
+                    [QDir.toNativeSeparators(path)
                      for path in self._editorText().split(";")])
             else:
                 return self._editorText()
         else:
             if toNative:
                 return os.path.expanduser(
-                    Utilities.toNativeSeparators(self._editorText()))
+                    QDir.toNativeSeparators(self._editorText()))
             else:
                 return os.path.expanduser(self._editorText())
     
@@ -518,7 +518,7 @@ class E5PathPickerBase(QWidget):
             directory = os.path.expanduser(directory)
         if not os.path.isabs(directory) and self.__defaultDirectory:
             directory = os.path.join(self.__defaultDirectory, directory)
-        directory = Utilities.fromNativeSeparators(directory)
+        directory = QDir.fromNativeSeparators(directory)
         
         if self.__mode == E5PathPickerModes.OpenFileMode:
             path = E5FileDialog.getOpenFileName(
@@ -526,14 +526,14 @@ class E5PathPickerBase(QWidget):
                 windowTitle,
                 directory,
                 self.__filters)
-            path = Utilities.toNativeSeparators(path)
+            path = QDir.toNativeSeparators(path)
         elif self.__mode == E5PathPickerModes.OpenFilesMode:
             paths = E5FileDialog.getOpenFileNames(
                 self,
                 windowTitle,
                 directory,
                 self.__filters)
-            path = ";".join([Utilities.toNativeSeparators(path)
+            path = ";".join([QDir.toNativeSeparators(path)
                              for path in paths])
         elif self.__mode == E5PathPickerModes.SaveFileMode:
             path = E5FileDialog.getSaveFileName(
@@ -542,7 +542,7 @@ class E5PathPickerBase(QWidget):
                 directory,
                 self.__filters,
                 E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
-            path = Utilities.toNativeSeparators(path)
+            path = QDir.toNativeSeparators(path)
         elif self.__mode == E5PathPickerModes.SaveFileEnsureExtensionMode:
             path, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
                 self,
@@ -551,7 +551,7 @@ class E5PathPickerBase(QWidget):
                 self.__filters,
                 None,
                 E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
-            path = Utilities.toNativeSeparators(path)
+            path = QDir.toNativeSeparators(path)
             if path:
                 ext = QFileInfo(path).suffix()
                 if not ext:
@@ -564,14 +564,14 @@ class E5PathPickerBase(QWidget):
                 windowTitle,
                 directory,
                 self.__filters)
-            path = Utilities.toNativeSeparators(path)
+            path = QDir.toNativeSeparators(path)
         elif self.__mode == E5PathPickerModes.DirectoryMode:
             path = E5FileDialog.getExistingDirectory(
                 self,
                 windowTitle,
                 directory,
                 E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
-            path = Utilities.toNativeSeparators(path)
+            path = QDir.toNativeSeparators(path)
             while path.endswith(os.sep):
                 path = path[:-1]
         elif self.__mode == E5PathPickerModes.DirectoryShowFilesMode:
@@ -580,7 +580,7 @@ class E5PathPickerBase(QWidget):
                 windowTitle,
                 directory,
                 E5FileDialog.Options(E5FileDialog.DontUseNativeDialog))
-            path = Utilities.toNativeSeparators(path)
+            path = QDir.toNativeSeparators(path)
             while path.endswith(os.sep):
                 path = path[:-1]
         
@@ -677,13 +677,6 @@ class E5PathPicker(E5PathPickerBase):
     """
     Class implementing a path picker widget consisting of a line edit and a
     tool button to open a file dialog.
-    
-    @signal textChanged(path) emitted when the entered path has changed
-    @signal pathSelected(path) emitted after a path has been selected via the
-        file dialog
-    @signal aboutToShowPathPickerDialog emitted before the file dialog is shown
-    @signal pickerButtonClicked emitted when the picker button was pressed and
-        the widget mode is custom
     """
     def __init__(self, parent=None):
         """
@@ -699,13 +692,6 @@ class E5ComboPathPicker(E5PathPickerBase):
     """
     Class implementing a path picker widget consisting of a combobox and a
     tool button to open a file dialog.
-    
-    @signal editTextChanged(path) emitted when the entered path has changed
-    @signal pathSelected(path) emitted after a path has been selected via the
-        file dialog
-    @signal aboutToShowPathPickerDialog emitted before the file dialog is shown
-    @signal pickerButtonClicked emitted when the picker button was pressed and
-        the widget mode is custom
     """
     def __init__(self, parent=None):
         """
