@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a progress dialog allowing a customized progress bar label.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QProgressBar, QProgressDialog
@@ -19,7 +18,7 @@ class E5ProgressDialog(QProgressDialog):
     label.
     """
     def __init__(self, labelText, cancelButtonText, minimum, maximum,
-                 format=None, parent=None, flags=Qt.WindowFlags()):
+                 labelFormat=None, parent=None, flags=None):
         """
         Constructor
         
@@ -27,18 +26,20 @@ class E5ProgressDialog(QProgressDialog):
         @param cancelButtonText text of the cancel button (string)
         @param minimum minimum value (integer)
         @param maximum maximum value (integer)
-        @keyparam format label format of the progress bar (string)
+        @keyparam labelFormat label format of the progress bar (string)
         @keyparam parent reference to the parent widget (QWidget)
         @keyparam flags window flags of the dialog (Qt.WindowFlags)
         """
+        if flags is None:
+            flags = Qt.WindowFlags()
         super(E5ProgressDialog, self).__init__(
             labelText, cancelButtonText, minimum, maximum, parent, flags)
         
         self.__progressBar = QProgressBar(self)
         self.__progressBar.setMinimum(minimum)
         self.__progressBar.setMaximum(maximum)
-        if format:
-            self.__progressBar.setFormat(format)
+        if labelFormat:
+            self.__progressBar.setFormat(labelFormat)
         
         self.setBar(self.__progressBar)
     
@@ -50,10 +51,10 @@ class E5ProgressDialog(QProgressDialog):
         """
         return self.__progressBar.format()
     
-    def setFormat(self, format):
+    def setFormat(self, labelFormat):
         """
         Public method to set the progress bar format.
         
-        @param format progress bar format (string)
+        @param labelFormat progress bar format (string)
         """
-        self.__progressBar.setFormat(format)
+        self.__progressBar.setFormat(labelFormat)
