@@ -1,18 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a sidebar class.
 """
 
-from __future__ import unicode_literals
 
-from PyQt5.QtCore import QEvent, QSize, Qt, QByteArray, QDataStream, \
-    QIODevice, QTimer, qVersion
-from PyQt5.QtWidgets import QTabBar, QWidget, QStackedWidget, QBoxLayout, \
-    QToolButton, QSizePolicy
+from PyQt5.QtCore import (
+    QEvent, QSize, Qt, QByteArray, QDataStream, QIODevice, QTimer
+)
+from PyQt5.QtWidgets import (
+    QTabBar, QWidget, QStackedWidget, QBoxLayout, QToolButton, QSizePolicy
+)
 
 from E5Gui.E5Application import e5App
 
@@ -24,7 +25,7 @@ class E5SideBar(QWidget):
     Class implementing a sidebar with a widget area, that is hidden or shown,
     if the current tab is clicked again.
     """
-    Version = 1
+    Version = 2
     
     North = 0
     East = 1
@@ -254,10 +255,7 @@ class E5SideBar(QWidget):
                 elif self.isMinimized():
                     self.expand()
             elif evt.type() == QEvent.Wheel:
-                if qVersion() >= "5.0.0":
-                    delta = evt.angleDelta().y()
-                else:
-                    delta = evt.delta()
+                delta = evt.angleDelta().y()
                 if delta > 0:
                     self.prevTab()
                 else:
@@ -576,11 +574,11 @@ class E5SideBar(QWidget):
         stream.writeUInt16(self.Version)
         stream.writeBool(self.__minimized)
         stream << self.__bigSize
-        stream.writeUInt16(self.__minSize)
-        stream.writeUInt16(self.__maxSize)
-        stream.writeUInt16(len(self.splitterSizes))
+        stream.writeUInt32(self.__minSize)
+        stream.writeUInt32(self.__maxSize)
+        stream.writeUInt32(len(self.splitterSizes))
         for size in self.splitterSizes:
-            stream.writeUInt16(size)
+            stream.writeUInt32(size)
         stream.writeBool(self.__autoHide)
         
         return data
@@ -605,19 +603,27 @@ class E5SideBar(QWidget):
         data = QByteArray(state)
         stream = QDataStream(data, QIODevice.ReadOnly)
         stream.setVersion(QDataStream.Qt_4_6)
-        stream.readUInt16()  # version
+        version = stream.readUInt16()  # version
         minimized = stream.readBool()
         
         if minimized and not self.__minimized:
             self.shrink()
         
         stream >> self.__bigSize
-        self.__minSize = max(stream.readUInt16(), minSize)
-        self.__maxSize = max(stream.readUInt16(), maxSize)
-        count = stream.readUInt16()
-        self.splitterSizes = []
-        for i in range(count):
-            self.splitterSizes.append(stream.readUInt16())
+        if version == 1:
+            self.__minSize = max(stream.readUInt16(), minSize)
+            self.__maxSize = max(stream.readUInt16(), maxSize)
+            count = stream.readUInt16()
+            self.splitterSizes = []
+            for _ in range(count):
+                self.splitterSizes.append(stream.readUInt16())
+        elif version == 2:
+            self.__minSize = max(stream.readUInt32(), minSize)
+            self.__maxSize = max(stream.readUInt32(), maxSize)
+            count = stream.readUInt32()
+            self.splitterSizes = []
+            for _ in range(count):
+                self.splitterSizes.append(stream.readUInt32())
         
         self.__autoHide = stream.readBool()
         self.__autoHideButton.setChecked(not self.__autoHide)
@@ -653,11 +659,16 @@ class E5SideBar(QWidget):
         @param old reference to the widget, that lost focus (QWidget or None)
         @param now reference to the widget having the focus (QWidget or None)
         """
-        self.__hasFocus = self.isAncestorOf(now)
-        if self.__autoHide and not self.__hasFocus and not self.isMinimized():
-            self.shrink()
-        elif self.__autoHide and self.__hasFocus and self.isMinimized():
-            self.expand()
+        if isinstance(now, QWidget):
+            self.__hasFocus = self.isAncestorOf(now)
+            if (
+                self.__autoHide and
+                not self.__hasFocus and
+                not self.isMinimized()
+            ):
+                self.shrink()
+            elif self.__autoHide and self.__hasFocus and self.isMinimized():
+                self.expand()
     
     def enterEvent(self, event):
         """
