@@ -1,20 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a TabWidget class substituting QTabWidget.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import Qt, QPoint, QMimeData, QByteArray, pyqtSignal
 from PyQt5.QtGui import QDrag, QMovie
 from PyQt5.QtWidgets import QTabWidget, QTabBar, QApplication, QStyle, QLabel
 
-from Globals import qVersionTuple
-
 
 class E5WheelTabBar(QTabBar):
     """
@@ -37,13 +34,10 @@ class E5WheelTabBar(QTabBar):
         @param event reference to the wheel event (QWheelEvent)
         """
         try:
-            if qVersionTuple() >= (5, 0, 0):
-                delta = event.angleDelta().y()
-            else:
-                delta = event.delta()
+            delta = event.angleDelta().y()
             if delta > 0:
                 self._tabWidget.prevTab()
-            else:
+            elif delta < 0:
                 self._tabWidget.nextTab()
             
             event.accept()
@@ -87,9 +81,11 @@ class E5DnDTabBar(E5WheelTabBar):
         
         @param event reference to the mouse move event (QMouseEvent)
         """
-        if event.buttons() == Qt.MouseButtons(Qt.LeftButton) and \
-           (event.pos() - self.__dragStartPos).manhattanLength() > \
-                QApplication.startDragDistance():
+        if (
+            event.buttons() == Qt.MouseButtons(Qt.LeftButton) and
+            (event.pos() - self.__dragStartPos).manhattanLength() >
+            QApplication.startDragDistance()
+        ):
             drag = QDrag(self)
             mimeData = QMimeData()
             index = self.tabAt(event.pos())
@@ -108,10 +104,12 @@ class E5DnDTabBar(E5WheelTabBar):
         """
         mimeData = event.mimeData()
         formats = mimeData.formats()
-        if "action" in formats and \
-           mimeData.data("action") == b"tab-reordering" and \
-           "tabbar-id" in formats and \
-           int(mimeData.data("tabbar-id")) == id(self):
+        if (
+            "action" in formats and
+            mimeData.data("action") == b"tab-reordering" and
+            "tabbar-id" in formats and
+            int(mimeData.data("tabbar-id")) == id(self)
+        ):
             event.acceptProposedAction()
         E5WheelTabBar.dragEnterEvent(self, event)
     
