@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a toolbar manager class.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import QObject, QByteArray, QDataStream, QIODevice
 from PyQt5.QtWidgets import QToolBar
@@ -228,8 +227,11 @@ class E5ToolBarManager(QObject):
         toRemove = {}
         newActions = []
         for action in actions:
-            if action is None or \
-               (action not in newActions and id(action) in self.__allActions):
+            if (
+                action is None or
+                (action not in newActions and
+                 id(action) in self.__allActions)
+            ):
                 newActions.append(action)
             oldTB = self.toolBarWidgetAction(action)
             if oldTB is not None and oldTB != toolBar:
@@ -303,8 +305,10 @@ class E5ToolBarManager(QObject):
         @param toolBar reference to the toolbar to be checked (QToolBar)
         @return flag indicating an added toolbar (boolean)
         """
-        return toolBar is not None and \
+        return (
+            toolBar is not None and
             id(toolBar) in self.__defaultToolBars
+        )
     
     def createToolBar(self, title, name=""):
         """
@@ -549,11 +553,11 @@ class E5ToolBarManager(QObject):
             return False
         
         toolBarCount = stream.readUInt16()
-        for i in range(toolBarCount):
+        for _i in range(toolBarCount):
             objectName = Utilities.readStringFromStream(stream)
             actionCount = stream.readUInt16()
             actions = []
-            for j in range(actionCount):
+            for _j in range(actionCount):
                 actionName = Utilities.readStringFromStream(stream)
                 if actionName:
                     action = self.__findAction(actionName)
@@ -572,12 +576,12 @@ class E5ToolBarManager(QObject):
         oldCustomToolBars = self.__customToolBars[:]
         
         toolBarCount = stream.readUInt16()
-        for i in range(toolBarCount):
+        for _i in range(toolBarCount):
             objectName = Utilities.readStringFromStream(stream)
             toolBarTitle = Utilities.readStringFromStream(stream)
             actionCount = stream.readUInt16()
             actions = []
-            for j in range(actionCount):
+            for _j in range(actionCount):
                 actionName = Utilities.readStringFromStream(stream)
                 if actionName:
                     action = self.__findAction(actionName)
@@ -626,8 +630,10 @@ class E5ToolBarManager(QObject):
             
             removedActions = []
             for action in actions[tbID]:
-                if action in newActions and \
-                        self.toolBarWidgetAction(action) == toolBar:
+                if (
+                    action in newActions and
+                    self.toolBarWidgetAction(action) == toolBar
+                ):
                     newActions.remove(action)
                     newActionsWithSeparators.remove(action)
                     removedActions.append(action)
