@@ -7,14 +7,15 @@
 Module implementing a dialog to show and edit all certificates.
 """
 
-from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSlot, Qt, QByteArray, QFile, QFileInfo, \
-    QIODevice
+from PyQt5.QtCore import (
+    pyqtSlot, Qt, QByteArray, QFile, QFileInfo, QIODevice
+)
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem
 try:
-    from PyQt5.QtNetwork import QSslCertificate, QSslSocket, \
-        QSslConfiguration, QSsl
+    from PyQt5.QtNetwork import (
+        QSslCertificate, QSslSocket, QSslConfiguration, QSsl
+    )
 except ImportError:
     pass
 
@@ -26,7 +27,6 @@ import Preferences
 import Utilities
 import UI.PixmapCache
 import Globals
-from Globals import qVersionTuple
 
 
 class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
@@ -87,16 +87,10 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         @param cert certificate to insert (QSslCertificate)
         """
         # step 1: extract the info to be shown
-        if qVersionTuple() >= (5, 0, 0):
-            organisation = Utilities.decodeString(
-                ", ".join(cert.subjectInfo(QSslCertificate.Organization)))
-            commonName = Utilities.decodeString(
-                ", ".join(cert.subjectInfo(QSslCertificate.CommonName)))
-        else:
-            organisation = Utilities.decodeString(
-                cert.subjectInfo(QSslCertificate.Organization))
-            commonName = Utilities.decodeString(
-                cert.subjectInfo(QSslCertificate.CommonName))
+        organisation = Utilities.decodeString(
+            ", ".join(cert.subjectInfo(QSslCertificate.Organization)))
+        commonName = Utilities.decodeString(
+            ", ".join(cert.subjectInfo(QSslCertificate.CommonName)))
         if organisation is None or organisation == "":
             organisation = self.tr("(Unknown)")
         if commonName is None or commonName == "":
@@ -137,8 +131,9 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         Private slot to show data of the selected server certificate.
         """
         try:
-            from E5Network.E5SslCertificatesInfoDialog import \
+            from E5Network.E5SslCertificatesInfoDialog import (
                 E5SslCertificatesInfoDialog
+            )
             cert = QSslCertificate.fromData(
                 self.serversCertificatesTree.currentItem().data(
                     0, self.CertRole))
@@ -216,12 +211,8 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
             pems = QByteArray()
             for cert in certs:
                 if cert in sCerts:
-                    if qVersionTuple() >= (5, 0, 0):
-                        commonStr = ", ".join(
-                            cert.subjectInfo(QSslCertificate.CommonName))
-                    else:
-                        commonStr = cert.subjectInfo(
-                            QSslCertificate.CommonName)
+                    commonStr = ", ".join(
+                        cert.subjectInfo(QSslCertificate.CommonName))
                     E5MessageBox.warning(
                         self,
                         self.tr("Import Certificate"),
@@ -250,8 +241,10 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         """
         cert = self.serversCertificatesTree.currentItem().data(
             0, self.CertRole)
-        fname = self.serversCertificatesTree.currentItem().text(0)\
-            .replace(" ", "").replace("\t", "")
+        fname = (
+            self.serversCertificatesTree.currentItem().text(0).replace(" ", "")
+            .replace("\t", "")
+        )
         self.__exportCertificate(fname, cert)
     
     def __updateDefaultConfiguration(self):
@@ -300,16 +293,10 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         @param cert certificate to insert (QSslCertificate)
         """
         # step 1: extract the info to be shown
-        if qVersionTuple() >= (5, 0, 0):
-            organisation = Utilities.decodeString(
-                ", ".join(cert.subjectInfo(QSslCertificate.Organization)))
-            commonName = Utilities.decodeString(
-                ", ".join(cert.subjectInfo(QSslCertificate.CommonName)))
-        else:
-            organisation = Utilities.decodeString(
-                cert.subjectInfo(QSslCertificate.Organization))
-            commonName = Utilities.decodeString(
-                cert.subjectInfo(QSslCertificate.CommonName))
+        organisation = Utilities.decodeString(
+            ", ".join(cert.subjectInfo(QSslCertificate.Organization)))
+        commonName = Utilities.decodeString(
+            ", ".join(cert.subjectInfo(QSslCertificate.CommonName)))
         if organisation is None or organisation == "":
             organisation = self.tr("(Unknown)")
         if commonName is None or commonName == "":
@@ -349,8 +336,9 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         Private slot to show data of the selected CA certificate.
         """
         try:
-            from E5Network.E5SslCertificatesInfoDialog import \
+            from E5Network.E5SslCertificatesInfoDialog import (
                 E5SslCertificatesInfoDialog
+            )
             cert = QSslCertificate.fromData(
                 self.caCertificatesTree.currentItem().data(0, self.CertRole))
             dlg = E5SslCertificatesInfoDialog(cert, self)
@@ -407,12 +395,8 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
             caCerts = self.__getSystemCaCertificates()
             for cert in certs:
                 if cert in caCerts:
-                    if qVersionTuple() >= (5, 0, 0):
-                        commonStr = ", ".join(
-                            cert.subjectInfo(QSslCertificate.CommonName))
-                    else:
-                        commonStr = cert.subjectInfo(
-                            QSslCertificate.CommonName)
+                    commonStr = ", ".join(
+                        cert.subjectInfo(QSslCertificate.CommonName))
                     E5MessageBox.warning(
                         self,
                         self.tr("Import Certificate"),
@@ -440,8 +424,10 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         Private slot to export the selected CA certificate.
         """
         cert = self.caCertificatesTree.currentItem().data(0, self.CertRole)
-        fname = self.caCertificatesTree.currentItem().text(0)\
-            .replace(" ", "").replace("\t", "")
+        fname = (
+            self.caCertificatesTree.currentItem().text(0).replace(" ", "")
+            .replace("\t", "")
+        )
         self.__exportCertificate(fname, cert)
     
     def __exportCertificate(self, name, cert):
