@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,6 @@ Module implementing the TLD Extractor.
 # Copyright (C) 2014  Razi Alavizadeh <s.r.alavizadeh@gmail.com>
 #
 
-from __future__ import unicode_literals
 
 import collections
 
@@ -274,16 +273,18 @@ class E5TldExtractor(QObject):
         parsedDataFileExist = False
         
         for path in self.__dataSearchPaths:
-            dataFileName = QFileInfo(path + "/effective_tld_names.dat")\
-                .absoluteFilePath()
+            dataFileName = (
+                QFileInfo(path + "/effective_tld_names.dat").absoluteFilePath()
+            )
             if QFileInfo(dataFileName).exists():
                 parsedDataFileExist = True
                 break
         
         if not parsedDataFileExist:
-            tldDataFileDownloadLink = \
-                "http://mxr.mozilla.org/mozilla-central/source/netwerk/dns/" \
+            tldDataFileDownloadLink = (
+                "http://mxr.mozilla.org/mozilla-central/source/netwerk/dns/"
                 "effective_tld_names.dat?raw=1"
+            )
             E5MessageBox.information(
                 None,
                 self.tr("TLD Data File not found"),
@@ -337,8 +338,10 @@ class E5TldExtractor(QObject):
                 if "===END PRIVATE DOMAINS===" in line:
                     seekToEndOfPrivateDomains = False
                 
-                if not loadPrivateDomains and \
-                        "===BEGIN PRIVATE DOMAINS===" in line:
+                if (
+                    not loadPrivateDomains and
+                    "===BEGIN PRIVATE DOMAINS===" in line
+                ):
                     seekToEndOfPrivateDomains = True
                 
                 continue
@@ -450,16 +453,18 @@ class E5TldExtractor(QObject):
         testDataFileExist = False
         
         for path in self.__dataSearchPaths:
-            testDataFileName = QFileInfo(path + "/test_psl.txt")\
-                .absoluteFilePath()
+            testDataFileName = (
+                QFileInfo(path + "/test_psl.txt").absoluteFilePath()
+            )
             if QFileInfo(testDataFileName).exists():
                 testDataFileExist = True
                 break
         
         if not testDataFileExist:
-            testFileDownloadLink = \
-                "http://mxr.mozilla.org/mozilla-central/source/netwerk/test/" \
+            testFileDownloadLink = (
+                "http://mxr.mozilla.org/mozilla-central/source/netwerk/test/"
                 "unit/data/test_psl.txt?raw=1"
+            )
             E5MessageBox.information(
                 None,
                 self.tr("TLD Data File not found"),
