@@ -7,15 +7,13 @@
 Module implementing a xmlrpc client for Qt.
 """
 
-from __future__ import unicode_literals
-try:
-    import xmlrpclib as xmlrpc
-except ImportError:
-    import xmlrpc.client as xmlrpc
+
+import xmlrpc.client as xmlrpc
 
 from PyQt5.QtCore import QObject, QUrl, QByteArray
-from PyQt5.QtNetwork import QNetworkAccessManager, \
-    QNetworkRequest, QNetworkReply
+from PyQt5.QtNetwork import (
+    QNetworkAccessManager, QNetworkRequest, QNetworkReply
+)
 
 from E5Network.E5NetworkProxyFactory import proxyAuthenticationRequired
 try:
