@@ -8,7 +8,6 @@ Module implementing a class for reading an XML project debugger properties
 file.
 """
 
-from __future__ import unicode_literals
 
 from .Config import debuggerPropertiesFileFormatVersion
 from .XMLStreamReaderBase import XMLStreamReaderBase
@@ -50,34 +49,42 @@ class DebuggerPropertiesReader(XMLStreamReaderBase):
                     if self.version not in self.supportedVersions:
                         self.raiseUnsupportedFormatVersion(self.version)
                 elif self.name() == "VirtualEnv":
-                    self.project.debugProperties["VIRTUALENV"] = \
+                    self.project.debugProperties["VIRTUALENV"] = (
                         self.readElementText()
+                    )
                 elif self.name() == "Interpreter":
                     # just read this obsolete entry and ignore it
                     self.readElementText()
                 elif self.name() == "DebugClient":
-                    self.project.debugProperties["DEBUGCLIENT"] = \
+                    self.project.debugProperties["DEBUGCLIENT"] = (
                         self.readElementText()
+                    )
                 elif self.name() == "Environment":
-                    self.project.debugProperties["ENVIRONMENTOVERRIDE"] = \
+                    self.project.debugProperties["ENVIRONMENTOVERRIDE"] = (
                         int(self.attribute("override", "0"))
-                    self.project.debugProperties["ENVIRONMENTSTRING"] = \
+                    )
+                    self.project.debugProperties["ENVIRONMENTSTRING"] = (
                         self.readElementText()
+                    )
                 elif self.name() == "RemoteDebugger":
                     self.__readRemoteDebugger()
                 elif self.name() == "PathTranslation":
                     self.__readPathTranslation()
                 elif self.name() == "ConsoleDebugger":
-                    self.project.debugProperties["CONSOLEDEBUGGER"] = \
+                    self.project.debugProperties["CONSOLEDEBUGGER"] = (
                         int(self.attribute("on", "0"))
-                    self.project.debugProperties["CONSOLECOMMAND"] = \
+                    )
+                    self.project.debugProperties["CONSOLECOMMAND"] = (
                         self.readElementText()
+                    )
                 elif self.name() == "Redirect":
-                    self.project.debugProperties["REDIRECT"] = \
+                    self.project.debugProperties["REDIRECT"] = (
                         int(self.attribute("on", "1"))
+                    )
                 elif self.name() == "Noencoding":
-                    self.project.debugProperties["NOENCODING"] = \
+                    self.project.debugProperties["NOENCODING"] = (
                         int(self.attribute("on", "0"))
+                    )
                 else:
                     self.raiseUnexpectedStartTag(self.name())
         
@@ -98,11 +105,13 @@ class DebuggerPropertiesReader(XMLStreamReaderBase):
             
             if self.isStartElement():
                 if self.name() == "RemoteHost":
-                    self.project.debugProperties["REMOTEHOST"] = \
+                    self.project.debugProperties["REMOTEHOST"] = (
                         self.readElementText()
+                    )
                 elif self.name() == "RemoteCommand":
-                    self.project.debugProperties["REMOTECOMMAND"] = \
+                    self.project.debugProperties["REMOTECOMMAND"] = (
                         self.readElementText()
+                    )
                 else:
                     self.raiseUnexpectedStartTag(self.name())
     
@@ -120,10 +129,12 @@ class DebuggerPropertiesReader(XMLStreamReaderBase):
             
             if self.isStartElement():
                 if self.name() == "RemotePath":
-                    self.project.debugProperties["REMOTEPATH"] = \
+                    self.project.debugProperties["REMOTEPATH"] = (
                         self.readElementText()
+                    )
                 elif self.name() == "LocalPath":
-                    self.project.debugProperties["LOCALPATH"] = \
+                    self.project.debugProperties["LOCALPATH"] = (
                         self.readElementText()
+                    )
                 else:
                     self.raiseUnexpectedStartTag(self.name())
