@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the writer class for writing an XML project file.
 """
 
-from __future__ import unicode_literals
 
 import time
 
 from E5Gui.E5Application import e5App
 
 from .XMLStreamWriterBase import XMLStreamWriterBase
-from .Config import projectFileFormatVersion
+from .Config import (
+    projectFileFormatVersion, projectFileFormatVersionUic,
+    projectFileFormatVersionIdl, projectFileFormatVersionMake,
+    projectFileFormatVersionProto, projectFileFormatVersionAlt
+)
 
 import Preferences
 import Utilities
@@ -42,8 +45,22 @@ class ProjectWriter(XMLStreamWriterBase):
         """
         XMLStreamWriterBase.writeXML(self)
         
+        project = e5App().getObject("Project")
+        if not project.hasDefaultRccCompilerParameters():
+            fileFormatVersion = projectFileFormatVersion
+        elif not project.hasDefaultUicCompilerParameters():
+            fileFormatVersion = projectFileFormatVersionUic
+        elif not project.hasDefaultIdlCompilerParameters():
+            fileFormatVersion = projectFileFormatVersionIdl
+        elif not project.hasDefaultMakeParameters():
+            fileFormatVersion = projectFileFormatVersionMake
+        elif self.pdata["PROTOCOLS"]:
+            fileFormatVersion = projectFileFormatVersionProto
+        else:
+            fileFormatVersion = projectFileFormatVersionAlt
+        
         self.writeDTD('<!DOCTYPE Project SYSTEM "Project-{0}.dtd">'.format(
-            projectFileFormatVersion))
+            fileFormatVersion))
         
         # add some generation comments
         self.writeComment(
@@ -53,83 +70,87 @@ class ProjectWriter(XMLStreamWriterBase):
                 " Saved: {0} ".format(time.strftime('%Y-%m-%d, %H:%M:%S')))
         self.writeComment(" Copyright (C) {0} {1}, {2} ".format(
             time.strftime('%Y'),
-            self.pdata["AUTHOR"][0],
-            self.pdata["EMAIL"][0]))
+            self.pdata["AUTHOR"],
+            self.pdata["EMAIL"]))
         
         # add the main tag
         self.writeStartElement("Project")
-        self.writeAttribute("version", projectFileFormatVersion)
+        self.writeAttribute("version", fileFormatVersion)
         
         # do the language (used for spell checking)
-        self.writeTextElement("Language", self.pdata["SPELLLANGUAGE"][0])
-        if len(self.pdata["SPELLWORDS"][0]) > 0:
+        self.writeTextElement("Language", self.pdata["SPELLLANGUAGE"])
+        if self.pdata["SPELLWORDS"]:
             self.writeTextElement(
                 "ProjectWordList",
-                Utilities.fromNativeSeparators(self.pdata["SPELLWORDS"][0]))
-        if len(self.pdata["SPELLEXCLUDES"][0]) > 0:
+                Utilities.fromNativeSeparators(self.pdata["SPELLWORDS"]))
+        if self.pdata["SPELLEXCLUDES"]:
             self.writeTextElement(
                 "ProjectExcludeList",
-                Utilities.fromNativeSeparators(self.pdata["SPELLEXCLUDES"][0]))
+                Utilities.fromNativeSeparators(self.pdata["SPELLEXCLUDES"]))
         
         # do the hash
-        self.writeTextElement("Hash", self.pdata["HASH"][0])
+        self.writeTextElement("Hash", self.pdata["HASH"])
         
         # do the programming language
         self.writeStartElement("ProgLanguage")
-        self.writeAttribute("mixed", str(int(self.pdata["MIXEDLANGUAGE"][0])))
-        self.writeCharacters(self.pdata["PROGLANGUAGE"][0])
+        self.writeAttribute("mixed", str(int(self.pdata["MIXEDLANGUAGE"])))
+        self.writeCharacters(self.pdata["PROGLANGUAGE"])
         self.writeEndElement()
         
         # do the UI type
-        self.writeTextElement("ProjectType", self.pdata["PROJECTTYPE"][0])
+        self.writeTextElement("ProjectType", self.pdata["PROJECTTYPE"])
         
         # do description
         if self.pdata["DESCRIPTION"]:
-            self.writeTextElement("Description", self.pdata["DESCRIPTION"][0])
+            self.writeTextElement("Description", self.pdata["DESCRIPTION"])
         
         # do version, author and email
-        self.writeTextElement("Version", self.pdata["VERSION"][0])
-        self.writeTextElement("Author", self.pdata["AUTHOR"][0])
-        self.writeTextElement("Email", self.pdata["EMAIL"][0])
+        self.writeTextElement("Version", self.pdata["VERSION"])
+        self.writeTextElement("Author", self.pdata["AUTHOR"])
+        self.writeTextElement("Email", self.pdata["EMAIL"])
             
         # do the translation pattern
         if self.pdata["TRANSLATIONPATTERN"]:
             self.writeTextElement(
                 "TranslationPattern",
                 Utilities.fromNativeSeparators(
-                    self.pdata["TRANSLATIONPATTERN"][0]))
+                    self.pdata["TRANSLATIONPATTERN"]))
         
         # do the binary translations path
         if self.pdata["TRANSLATIONSBINPATH"]:
             self.writeTextElement(
                 "TranslationsBinPath",
                 Utilities.fromNativeSeparators(
-                    self.pdata["TRANSLATIONSBINPATH"][0]))
+                    self.pdata["TRANSLATIONSBINPATH"]))
         
         # do the eol setting
-        if self.pdata["EOL"] and self.pdata["EOL"][0]:
+        if self.pdata["EOL"] >= 0:
             self.writeEmptyElement("Eol")
-            self.writeAttribute("index", str(int(self.pdata["EOL"][0])))
+            self.writeAttribute("index", str(int(self.pdata["EOL"])))
         
         # do the sources
-        self.writeStartElement("Sources")
-        for name in sorted(self.pdata["SOURCES"]):
-            self.writeTextElement(
-                "Source", Utilities.fromNativeSeparators(name))
-        self.writeEndElement()
+        if self.pdata["SOURCES"]:
+            self.writeStartElement("Sources")
+            for name in sorted(self.pdata["SOURCES"]):
+                self.writeTextElement(
+                    "Source", Utilities.fromNativeSeparators(name))
+            self.writeEndElement()
         
         # do the forms
-        self.writeStartElement("Forms")
-        for name in sorted(self.pdata["FORMS"]):
-            self.writeTextElement("Form", Utilities.fromNativeSeparators(name))
-        self.writeEndElement()
+        if self.pdata["FORMS"]:
+            self.writeStartElement("Forms")
+            for name in sorted(self.pdata["FORMS"]):
+                self.writeTextElement(
+                    "Form", Utilities.fromNativeSeparators(name))
+            self.writeEndElement()
         
         # do the translations
-        self.writeStartElement("Translations")
-        for name in sorted(self.pdata["TRANSLATIONS"]):
-            self.writeTextElement(
-                "Translation", Utilities.fromNativeSeparators(name))
-        self.writeEndElement()
+        if self.pdata["TRANSLATIONS"]:
+            self.writeStartElement("Translations")
+            for name in sorted(self.pdata["TRANSLATIONS"]):
+                self.writeTextElement(
+                    "Translation", Utilities.fromNativeSeparators(name))
+            self.writeEndElement()
         
         # do the translation exceptions
         if self.pdata["TRANSLATIONEXCEPTIONS"]:
@@ -141,40 +162,51 @@ class ProjectWriter(XMLStreamWriterBase):
             self.writeEndElement()
         
         # do the resources
-        self.writeStartElement("Resources")
-        for name in sorted(self.pdata["RESOURCES"]):
-            self.writeTextElement(
-                "Resource", Utilities.fromNativeSeparators(name))
-        self.writeEndElement()
+        if self.pdata["RESOURCES"]:
+            self.writeStartElement("Resources")
+            for name in sorted(self.pdata["RESOURCES"]):
+                self.writeTextElement(
+                    "Resource", Utilities.fromNativeSeparators(name))
+            self.writeEndElement()
         
         # do the interfaces (IDL)
-        self.writeStartElement("Interfaces")
-        for name in sorted(self.pdata["INTERFACES"]):
-            self.writeTextElement(
-                "Interface", Utilities.fromNativeSeparators(name))
-        self.writeEndElement()
+        if self.pdata["INTERFACES"]:
+            self.writeStartElement("Interfaces")
+            for name in sorted(self.pdata["INTERFACES"]):
+                self.writeTextElement(
+                    "Interface", Utilities.fromNativeSeparators(name))
+            self.writeEndElement()
+        
+        # do the protocols (protobuf)
+        if self.pdata["PROTOCOLS"]:
+            self.writeStartElement("Protocols")
+            for name in sorted(self.pdata["PROTOCOLS"]):
+                self.writeTextElement(
+                    "Protocol", Utilities.fromNativeSeparators(name))
+            self.writeEndElement()
         
         # do the others
-        self.writeStartElement("Others")
-        for name in sorted(self.pdata["OTHERS"]):
-            self.writeTextElement(
-                "Other", Utilities.fromNativeSeparators(name))
-        self.writeEndElement()
+        if self.pdata["OTHERS"]:
+            self.writeStartElement("Others")
+            for name in sorted(self.pdata["OTHERS"]):
+                self.writeTextElement(
+                    "Other", Utilities.fromNativeSeparators(name))
+            self.writeEndElement()
         
         # do the main script
         if self.pdata["MAINSCRIPT"]:
             self.writeTextElement(
                 "MainScript",
-                Utilities.fromNativeSeparators(self.pdata["MAINSCRIPT"][0]))
+                Utilities.fromNativeSeparators(self.pdata["MAINSCRIPT"]))
         
         # do the vcs stuff
         self.writeStartElement("Vcs")
         if self.pdata["VCS"]:
-            self.writeTextElement("VcsType", self.pdata["VCS"][0])
+            self.writeTextElement("VcsType", self.pdata["VCS"])
         if self.pdata["VCSOPTIONS"]:
-            self.writeBasics("VcsOptions", self.pdata["VCSOPTIONS"][0])
+            self.writeBasics("VcsOptions", self.pdata["VCSOPTIONS"])
         if self.pdata["VCSOTHERDATA"]:
-            self.writeBasics("VcsOtherData", self.pdata["VCSOTHERDATA"][0])
+            self.writeBasics("VcsOtherData", self.pdata["VCSOTHERDATA"])
         self.writeEndElement()
         
         # do the filetype associations
@@ -194,6 +226,30 @@ class ProjectWriter(XMLStreamWriterBase):
                 self.writeAttribute("lexer", lexer)
             self.writeEndElement()
         
+        # do the 'make' parameters
+        if not e5App().getObject("Project").hasDefaultMakeParameters():
+            self.writeStartElement("Make")
+            self.writeBasics("MakeParameters", self.pdata["MAKEPARAMS"])
+            self.writeEndElement()
+        
+        # do the 'IDL' parameters
+        if not e5App().getObject("Project").hasDefaultIdlCompilerParameters():
+            self.writeStartElement("IdlCompiler")
+            self.writeBasics("IdlCompilerParameters", self.pdata["IDLPARAMS"])
+            self.writeEndElement()
+        
+        # do the 'uic' parameters
+        if not e5App().getObject("Project").hasDefaultUicCompilerParameters():
+            self.writeStartElement("UicCompiler")
+            self.writeBasics("UicCompilerParameters", self.pdata["UICPARAMS"])
+            self.writeEndElement()
+        
+        # do the 'rcc' parameters
+        if not e5App().getObject("Project").hasDefaultRccCompilerParameters():
+            self.writeStartElement("RccCompiler")
+            self.writeBasics("RccCompilerParameters", self.pdata["RCCPARAMS"])
+            self.writeEndElement()
+        
         # do the extra project data stuff
         if len(self.pdata["PROJECTTYPESPECIFICDATA"]):
             self.writeStartElement("ProjectTypeSpecific")
