@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a class for reading an XML session file.
 """
 
-from __future__ import unicode_literals
 
 from E5Gui.E5Application import e5App
 
@@ -396,8 +395,8 @@ class SessionReader(XMLStreamReaderBase):
         while not self.atEnd():
             self.readNext()
             if self.isEndElement() and self.name() == "ProjectBrowserState":
-                projectBrowser = \
-                    self.projectBrowser.getProjectBrowser(browserName)
+                projectBrowser = self.projectBrowser.getProjectBrowser(
+                    browserName)
                 if projectBrowser is not None:
                     projectBrowser.expandItemsByName(expandedNames)
                 break
