@@ -11,19 +11,16 @@ Module defining common data to be used by all modules.
 # Note: Do not import any eric stuff in here!!!!!!!
 #
 
-from __future__ import unicode_literals
-try:
-    str = unicode       # __IGNORE_EXCEPTION__
-except NameError:
-    pass
 
 import sys
 import os
 import re
 import shutil
 
-from PyQt5.QtCore import QDir, QLibraryInfo, QByteArray, QCoreApplication, \
-    QT_VERSION_STR, QT_VERSION, QProcess, qVersion
+from PyQt5.QtCore import (
+    QDir, QLibraryInfo, QByteArray, QCoreApplication, QT_VERSION_STR,
+    QT_VERSION, QProcess, qVersion
+)
 
 # names of the various settings objects
 settingsNameOrganization = "Eric6"
@@ -119,9 +116,11 @@ def isKdeDesktop():
     
     isKDE = False
     
-    desktop = os.environ.get("XDG_CURRENT_DESKTOP", "").lower() or \
-        os.environ.get("XDG_SESSION_DESKTOP", "").lower() or \
+    desktop = (
+        os.environ.get("XDG_CURRENT_DESKTOP", "").lower() or
+        os.environ.get("XDG_SESSION_DESKTOP", "").lower() or
         os.environ.get("DESKTOP_SESSION", "").lower()
+    )
     if desktop:
         isKDE = "kde" in desktop or "plasma" in desktop
     else:
@@ -142,9 +141,11 @@ def isGnomeDesktop():
     
     isGnome = False
     
-    desktop = os.environ.get("XDG_CURRENT_DESKTOP", "").lower() or \
-        os.environ.get("XDG_SESSION_DESKTOP", "").lower() or \
+    desktop = (
+        os.environ.get("XDG_CURRENT_DESKTOP", "").lower() or
+        os.environ.get("XDG_SESSION_DESKTOP", "").lower() or
         os.environ.get("GDMSESSION", "").lower()
+    )
     if desktop:
         isGnome = "gnome" in desktop
     else:
@@ -236,15 +237,15 @@ def getPythonModulesDirectory():
 
 def getPyQt5ModulesDirectory():
     """
-    Function to determine the path to PyQt5's (or PyQt4's) modules directory.
+    Function to determine the path to PyQt5 modules directory.
     
-    @return path to the PyQt5/PyQt4 modules directory (string)
+    @return path to the PyQt5 modules directory (string)
     """
     import distutils.sysconfig
-    for pyqt in ["PyQt5", "PyQt4"]:
-        pyqtPath = os.path.join(distutils.sysconfig.get_python_lib(True), pyqt)
-        if os.path.exists(pyqtPath):
-            return pyqtPath
+    
+    pyqtPath = os.path.join(distutils.sysconfig.get_python_lib(True), "PyQt5")
+    if os.path.exists(pyqtPath):
+        return pyqtPath
     
     return ""
     
@@ -425,12 +426,8 @@ def strToQByteArray(txt):
     @return converted QByteArray
     @rtype QByteArray
     """
-    if sys.version_info[0] == 2:
-        if isinstance(txt, unicode):    # __IGNORE_WARNING__
-            txt = txt.encode("utf-8")
-    else:
-        if isinstance(txt, str):
-            txt = txt.encode("utf-8")
+    if isinstance(txt, str):
+        txt = txt.encode("utf-8")
     
     return QByteArray(txt)
 
@@ -446,19 +443,23 @@ def dataString(size):
     """
     if size < 1024:
         return QCoreApplication.translate(
-            "Globals", "{0:.1f} Bytes").format(size)
+            "Globals", "{0:4.2f} Bytes").format(size)
     elif size < 1024 * 1024:
         size /= 1024
         return QCoreApplication.translate(
-            "Globals", "{0:.1f} KiB").format(size)
+            "Globals", "{0:4.2f} KiB").format(size)
     elif size < 1024 * 1024 * 1024:
         size /= 1024 * 1024
         return QCoreApplication.translate(
-            "Globals", "{0:.2f} MiB").format(size)
-    else:
+            "Globals", "{0:4.2f} MiB").format(size)
+    elif size < 1024 * 1024 * 1024 * 1024:
         size /= 1024 * 1024 * 1024
         return QCoreApplication.translate(
-            "Globals", "{0:.2f} GiB").format(size)
+            "Globals", "{0:4.2f} GiB").format(size)
+    else:
+        size /= 1024 * 1024 * 1024 * 1024
+        return QCoreApplication.translate(
+            "Globals", "{0:4.2f} TiB").format(size)
 
 
 ###############################################################################
@@ -532,7 +533,7 @@ def getWebBrowserSupport():
     Module function to determine the supported web browser variant.
     
     @return string indicating the supported web browser variant ("QtWebEngine",
-        "QtWebKit" or "None")
+        or "None")
     @rtype str
     """
     from eric6config import getConfig
