@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a graphics item for an association between two items.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import QPointF, QRectF, QLineF
 from PyQt5.QtWidgets import QGraphicsItem
@@ -75,8 +74,9 @@ class AssociationItem(E5ArrowItem):
         self.setFlag(QGraphicsItem.ItemIsSelectable, False)
         
         if topToBottom:
-            self.calculateEndingPoints = \
+            self.calculateEndingPoints = (
                 self.__calculateEndingPoints_topToBottom
+            )
         else:
             ## self.calculateEndingPoints = self.__calculateEndingPoints_center
             self.calculateEndingPoints = self.__calculateEndingPoints_rectangle
@@ -155,8 +155,12 @@ class AssociationItem(E5ArrowItem):
         startP = self.__findRectIntersectionPoint(self.itemA, midA, midB)
         endP = self.__findRectIntersectionPoint(self.itemB, midB, midA)
         
-        if startP.x() != -1 and startP.y() != -1 and \
-           endP.x() != -1 and endP.y() != -1:
+        if (
+            startP.x() != -1 and
+            startP.y() != -1 and
+            endP.x() != -1 and
+            endP.y() != -1
+        ):
             self.setPoints(startP.x(), startP.y(), endP.x(), endP.y())
         
     def __calculateEndingPoints_rectangle(self):
@@ -168,21 +172,23 @@ class AssociationItem(E5ArrowItem):
         For each item the diagram is divided in four Regions by its diagonals
         as indicated below
         <pre>
-                   \  Region 2  /
-                    \          /
-                     |--------|
-                     | \    / |
-                     |  \  /  |
-                     |   \/   |
-            Region 1 |   /\   | Region 3
-                     |  /  \  |
-                     | /    \ |
-                     |--------|
-                    /          \
-                   /  Region 4  \
+            +------------------------------+
+            |        \  Region 2  /        |
+            |         \          /         |
+            |          |--------|          |
+            |          | \    / |          |
+            |          |  \  /  |          |
+            |          |   \/   |          |
+            | Region 1 |   /\   | Region 3 |
+            |          |  /  \  |          |
+            |          | /    \ |          |
+            |          |--------|          |
+            |         /          \         |
+            |        /  Region 4  \        |
+            +------------------------------+
         </pre>
         
-        Each diagonal is defined by two corners of the bounding rectangle
+        Each diagonal is defined by two corners of the bounding rectangle.
         
         To calculate the start point  we have to find out in which
         region (defined by itemA's diagonals) is itemB's TopLeft corner
@@ -372,8 +378,10 @@ class AssociationItem(E5ArrowItem):
         intersectLine = QLineF(p1, p2)
         intersectPoint = QPointF(0, 0)
         for line in lines:
-            if intersectLine.intersect(line, intersectPoint) == \
-               QLineF.BoundedIntersection:
+            if (
+                intersectLine.intersect(line, intersectPoint) ==
+                QLineF.BoundedIntersection
+            ):
                 return intersectPoint
         return QPointF(-1.0, -1.0)
         
