@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog showing an imports diagram of a package.
 """
 
-from __future__ import unicode_literals
 
 import glob
 import os
@@ -79,12 +78,16 @@ class ImportsDiagramBuilder(UMLDiagramBuilder):
         @return dictionary of modules contained in the package.
         """
         import Utilities.ModuleParser
-        extensions = Preferences.getPython("PythonExtensions") + \
+        extensions = (
+            Preferences.getPython("PythonExtensions") +
             Preferences.getPython("Python3Extensions")
+        )
         moduleDict = {}
         modules = []
-        for ext in Preferences.getPython("PythonExtensions") + \
-                Preferences.getPython("Python3Extensions"):
+        for ext in (
+            Preferences.getPython("PythonExtensions") +
+            Preferences.getPython("Python3Extensions")
+        ):
             modules.extend(glob.glob(Utilities.normjoinpath(
                 self.packagePath, '*{0}'.format(ext))))
         
@@ -274,9 +277,11 @@ class ImportsDiagramBuilder(UMLDiagramBuilder):
         @return flag indicating success (boolean)
         """
         parts = data.split(", ")
-        if len(parts) != 2 or \
-           not parts[0].startswith("package=") or \
-           not parts[1].startswith("show_external="):
+        if (
+            len(parts) != 2 or
+            not parts[0].startswith("package=") or
+            not parts[1].startswith("show_external=")
+        ):
             return False
         
         self.packagePath = parts[0].split("=", 1)[1].strip()
