@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a package item.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtGui import QFont
 from PyQt5.QtWidgets import QGraphicsSimpleTextItem, QStyle
@@ -158,8 +157,10 @@ class PackageItem(UMLItem):
         @param widget optional reference to the widget painted on (QWidget)
         """
         pen = self.pen()
-        if (option.state & QStyle.State_Selected) == \
-                QStyle.State(QStyle.State_Selected):
+        if (
+            (option.state & QStyle.State_Selected) ==
+            QStyle.State(QStyle.State_Selected)
+        ):
             pen.setWidth(2)
         else:
             pen.setWidth(1)
