@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog showing UML like diagrams.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot, Qt, QFileInfo
 from PyQt5.QtWidgets import QAction, QToolBar, QGraphicsScene
@@ -74,39 +73,39 @@ class UMLDialog(E5MainWindow):
         """
         Private slot to initialize the actions.
         """
-        self.closeAct = \
-            QAction(UI.PixmapCache.getIcon("close.png"),
-                    self.tr("Close"), self)
+        self.closeAct = QAction(
+            UI.PixmapCache.getIcon("close.png"),
+            self.tr("Close"), self)
         self.closeAct.triggered.connect(self.close)
         
-        self.openAct = \
-            QAction(UI.PixmapCache.getIcon("open.png"),
-                    self.tr("Load"), self)
+        self.openAct = QAction(
+            UI.PixmapCache.getIcon("open.png"),
+            self.tr("Load"), self)
         self.openAct.triggered.connect(self.load)
         
-        self.saveAct = \
-            QAction(UI.PixmapCache.getIcon("fileSave.png"),
-                    self.tr("Save"), self)
+        self.saveAct = QAction(
+            UI.PixmapCache.getIcon("fileSave.png"),
+            self.tr("Save"), self)
         self.saveAct.triggered.connect(self.__save)
         
-        self.saveAsAct = \
-            QAction(UI.PixmapCache.getIcon("fileSaveAs.png"),
-                    self.tr("Save As..."), self)
+        self.saveAsAct = QAction(
+            UI.PixmapCache.getIcon("fileSaveAs.png"),
+            self.tr("Save As..."), self)
         self.saveAsAct.triggered.connect(self.__saveAs)
         
-        self.saveImageAct = \
-            QAction(UI.PixmapCache.getIcon("fileSavePixmap.png"),
-                    self.tr("Save as Image"), self)
+        self.saveImageAct = QAction(
+            UI.PixmapCache.getIcon("fileSavePixmap.png"),
+            self.tr("Save as Image"), self)
         self.saveImageAct.triggered.connect(self.umlView.saveImage)
         
-        self.printAct = \
-            QAction(UI.PixmapCache.getIcon("print.png"),
-                    self.tr("Print"), self)
+        self.printAct = QAction(
+            UI.PixmapCache.getIcon("print.png"),
+            self.tr("Print"), self)
         self.printAct.triggered.connect(self.umlView.printDiagram)
         
-        self.printPreviewAct = \
-            QAction(UI.PixmapCache.getIcon("printPreview.png"),
-                    self.tr("Print Preview"), self)
+        self.printPreviewAct = QAction(
+            UI.PixmapCache.getIcon("printPreview.png"),
+            self.tr("Print Preview"), self)
         self.printPreviewAct.triggered.connect(
             self.umlView.printPreviewDiagram)
     
@@ -307,8 +306,10 @@ class UMLDialog(E5MainWindow):
             # step 1: check version
             linenum = 0
             key, value = lines[linenum].split(": ", 1)
-            if key.strip() != "version" or \
-                    value.strip() not in UMLDialog.FileVersions:
+            if (
+                key.strip() != "version" or
+                value.strip() not in UMLDialog.FileVersions
+            ):
                 self.__showInvalidDataMessage(filename, linenum)
                 return False
             else:
