@@ -7,15 +7,16 @@
 Module implementing the hex editor main window.
 """
 
-from __future__ import unicode_literals
 
 import os
 
-from PyQt5.QtCore import pyqtSignal, pyqtSlot, QFile, QFileInfo, QSize, \
-    QCoreApplication, QLocale
+from PyQt5.QtCore import (
+    pyqtSignal, pyqtSlot, QFile, QFileInfo, QSize, QCoreApplication, QLocale
+)
 from PyQt5.QtGui import QKeySequence
-from PyQt5.QtWidgets import QWhatsThis, QLabel, QWidget, QVBoxLayout, \
-    QDialog, QAction, QFrame, QMenu
+from PyQt5.QtWidgets import (
+    QWhatsThis, QLabel, QWidget, QVBoxLayout, QDialog, QAction, QFrame, QMenu
+)
 
 from E5Gui.E5Action import E5Action
 from E5Gui.E5MainWindow import E5MainWindow
