@@ -1,17 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a search and replace widget for the hex editor.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode       # __IGNORE_EXCEPTION__
-except NameError:
-    pass
 
 from PyQt5.QtCore import pyqtSlot, Qt, QByteArray, QRegExp
 from PyQt5.QtGui import QRegExpValidator
@@ -242,7 +237,7 @@ class HexEditSearchReplaceWidget(QWidget):
         """
         if not self.__havefound or not self.__ui.findtextCombo.currentText():
             self.show()
-            return
+            return False
         
         self.__findBackwards = prev
         ba, txt = self.__getContent()
@@ -251,14 +246,18 @@ class HexEditSearchReplaceWidget(QWidget):
         if len(ba) > 0:
             startIndex = self.__editor.cursorPosition() // 2
             if prev:
-                if self.__editor.hasSelection() and \
-                        startIndex == self.__editor.getSelectionEnd():
+                if (
+                    self.__editor.hasSelection() and
+                    startIndex == self.__editor.getSelectionEnd()
+                ):
                     # skip to the selection start
                     startIndex = self.__editor.getSelectionBegin()
                 idx = self.__editor.lastIndexOf(ba, startIndex)
             else:
-                if self.__editor.hasSelection() and \
-                        startIndex == self.__editor.getSelectionBegin() - 1:
+                if (
+                    self.__editor.hasSelection() and
+                    startIndex == self.__editor.getSelectionBegin() - 1
+                ):
                     # skip to the selection end
                     startIndex = self.__editor.getSelectionEnd()
                 idx = self.__editor.indexOf(ba, startIndex)
@@ -341,8 +340,10 @@ class HexEditSearchReplaceWidget(QWidget):
         @type bool
         """
         # Check enabled status due to dual purpose usage of this method
-        if not self.__ui.replaceButton.isEnabled() and \
-           not self.__ui.replaceSearchButton.isEnabled():
+        if (
+            not self.__ui.replaceButton.isEnabled() and
+            not self.__ui.replaceSearchButton.isEnabled()
+        ):
             return
         
         fba, ftxt = self.__getContent(False)
