@@ -7,13 +7,14 @@
 Module implementing the icon editor grid.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QPoint, QRect, QSize
-from PyQt5.QtGui import QImage, QColor, QPixmap, qRgba, QPainter, QCursor, \
-    QBrush, qGray, qAlpha
-from PyQt5.QtWidgets import QUndoCommand, QWidget, QSizePolicy, QUndoStack, \
-    QApplication, QDialog
+from PyQt5.QtGui import (
+    QImage, QColor, QPixmap, qRgba, QPainter, QCursor, QBrush, qGray, qAlpha
+)
+from PyQt5.QtWidgets import (
+    QUndoCommand, QWidget, QSizePolicy, QUndoStack, QApplication, QDialog
+)
 
 from E5Gui import E5MessageBox
 
@@ -712,9 +713,11 @@ class IconEditorGrid(QWidget):
         @param doUpdate flag indicating an update is requested (boolean)
             (used for speed optimizations)
         """
-        if not self.__image.rect().contains(i, j) or \
-           self.__image.pixel(i, j) != oldColor.rgba() or \
-           self.__image.pixel(i, j) == self.penColor().rgba():
+        if (
+            not self.__image.rect().contains(i, j) or
+            self.__image.pixel(i, j) != oldColor.rgba() or
+            self.__image.pixel(i, j) == self.penColor().rgba()
+        ):
             return
         
         self.__image.setPixel(i, j, self.penColor().rgba())
@@ -894,8 +897,10 @@ class IconEditorGrid(QWidget):
         """
         img, ok = self.__clipboardImage()
         if ok:
-            if img.width() > self.__image.width() or \
-                    img.height() > self.__image.height():
+            if (
+                img.width() > self.__image.width() or
+                img.height() > self.__image.height()
+            ):
                 res = E5MessageBox.yesNo(
                     self,
                     self.tr("Paste"),
@@ -983,8 +988,10 @@ class IconEditorGrid(QWidget):
         res = dlg.exec_()
         if res == QDialog.Accepted:
             newWidth, newHeight = dlg.getData()
-            if newWidth != self.__image.width() or \
-                    newHeight != self.__image.height():
+            if (
+                newWidth != self.__image.width() or
+                newHeight != self.__image.height()
+            ):
                 cmd = IconEditCommand(self, self.tr("Resize Image"),
                                       self.__image)
                 img = self.__image.scaled(
