@@ -1,20 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the icon editor main window.
 """
 
-from __future__ import unicode_literals
 
 import os
 
-from PyQt5.QtCore import pyqtSignal, Qt, QSize, QSignalMapper, QFileInfo, \
-    QFile, QEvent
-from PyQt5.QtGui import QPalette, QImage, QImageReader, QImageWriter, \
-    QKeySequence
+from PyQt5.QtCore import (
+    pyqtSignal, Qt, QSize, QSignalMapper, QFileInfo, QFile, QEvent
+)
+from PyQt5.QtGui import (
+    QPalette, QImage, QImageReader, QImageWriter, QKeySequence
+)
 from PyQt5.QtWidgets import QScrollArea, QLabel, QDockWidget, QWhatsThis
 
 from E5Gui.E5Action import E5Action, createActionGroup
@@ -28,7 +29,6 @@ import UI.PixmapCache
 import UI.Config
 
 import Preferences
-from Globals import qVersionTuple
 
 
 class IconEditorWindow(E5MainWindow):
@@ -1353,10 +1353,7 @@ class IconEditorWindow(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersionTuple() >= (5, 0, 0):
-                delta = evt.angleDelta().y()
-            else:
-                delta = evt.delta()
+            delta = evt.angleDelta().y()
             if delta < 0:
                 self.__zoomOut()
             elif delta > 0:
