@@ -7,7 +7,6 @@
 Module implementing the add project dialog.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -19,6 +18,7 @@ from E5Gui.E5PathPicker import E5PathPickerModes
 from .Ui_AddProjectDialog import Ui_AddProjectDialog
 
 import Utilities
+import Preferences
 
 
 class AddProjectDialog(QDialog, Ui_AddProjectDialog):
@@ -46,6 +46,8 @@ class AddProjectDialog(QDialog, Ui_AddProjectDialog):
         
         self.filenamePicker.setMode(E5PathPickerModes.OpenFileMode)
         self.filenamePicker.setFilters(self.tr("Project Files (*.e4p)"))
+        self.filenamePicker.setDefaultDirectory(
+            Preferences.getMultiProject("Workspace"))
         
         if categories:
             self.categoryComboBox.addItem("")
