@@ -7,19 +7,21 @@
 Module implementing the multi project management functionality.
 """
 
-from __future__ import unicode_literals
 
 import os
+import shutil
 
-from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QFileInfo, QFile, \
-    QIODevice, QObject
+from PyQt5.QtCore import (
+    pyqtSignal, pyqtSlot, Qt, QFileInfo, QFile, QIODevice, QObject, QUuid
+)
 from PyQt5.QtGui import QCursor
 from PyQt5.QtWidgets import QMenu, QApplication, QDialog, QToolBar
 
 from Globals import recentNameMultiProject
 
 from E5Gui.E5Action import E5Action, createActionGroup
-from E5Gui import E5FileDialog, E5MessageBox
+from E5Gui import E5FileDialog, E5MessageBox, E5PathPickerDialog
+from E5Gui.E5PathPickerDialog import E5PathPickerModes
 
 import UI.PixmapCache
 
@@ -200,8 +202,10 @@ class MultiProject(QObject):
         Private slot to extract the categories used in the project definitions.
         """
         for project in self.__projects.values():
-            if project['category'] and \
-                    project['category'] not in self.categories:
+            if (
+                project['category'] and
+                project['category'] not in self.categories
+            ):
                 self.categories.append(project['category'])
     
     def getCategories(self):
@@ -270,8 +274,9 @@ class MultiProject(QObject):
         if f.open(QIODevice.WriteOnly):
             from E5XML.MultiProjectWriter import MultiProjectWriter
             MultiProjectWriter(
-                f, self, os.path.splitext(os.path.basename(fn))[0])\
-                .writeXML()
+                f,
+                self, os.path.splitext(os.path.basename(fn))[0]
+            ).writeXML()
             res = True
         else:
             E5MessageBox.critical(
@@ -303,11 +308,14 @@ class MultiProject(QObject):
         self.__projects[project['uid']] = project
     
     @pyqtSlot()
-    def addNewProject(self, startdir=None):
+    def addNewProject(self, startdir="", category=""):
         """
         Public slot used to add a new project to the multi-project.
         
-        @param startdir start directory for the selection dialog (string)
+        @param startdir start directory for the selection dialog
+        @type str
+        @param category category to be preset
+        @type str
         """
         from .AddProjectDialog import AddProjectDialog
         if not startdir:
@@ -315,10 +323,11 @@ class MultiProject(QObject):
         if not startdir:
             startdir = Preferences.getMultiProject("Workspace")
         dlg = AddProjectDialog(self.ui, startdir=startdir,
-                               categories=self.categories)
+                               categories=self.categories, category=category)
         if dlg.exec_() == QDialog.Accepted:
-            name, filename, isMaster, description, category, uid = \
+            name, filename, isMaster, description, category, uid = (
                 dlg.getData()
+            )
             
             # step 1: check, if project was already added
             for project in self.__projects.values():
@@ -349,6 +358,59 @@ class MultiProject(QObject):
             self.projectAdded.emit(project)
             self.setDirty(True)
     
+    def copyProject(self, uid):
+        """
+        Public method to copy the project with given UID on disk.
+        
+        @param uid UID of the project to copy
+        @type str
+        """
+        if uid in self.__projects:
+            startdir = self.ppath
+            if not startdir:
+                startdir = Preferences.getMultiProject("Workspace")
+            srcProject = self.__projects[uid]
+            srcProjectDirectory = os.path.dirname(srcProject["file"])
+            dstProjectDirectory, ok = E5PathPickerDialog.getPath(
+                self.parent(),
+                self.tr("Copy Project"),
+                self.tr("Enter directory for the new project (must not exist"
+                        " already):"),
+                mode=E5PathPickerModes.DirectoryMode,
+                path=srcProjectDirectory,
+                defaultDirectory=startdir,
+            )
+            if (
+                ok and
+                dstProjectDirectory and
+                not os.path.exists(dstProjectDirectory)
+            ):
+                try:
+                    shutil.copytree(srcProjectDirectory, dstProjectDirectory)
+                except shutil.Error:
+                    E5MessageBox.critical(
+                        self.parent(),
+                        self.tr("Copy Project"),
+                        self.tr("<p>The source project <b>{0}</b> could not"
+                                " be copied to its destination <b>{1}</b>."
+                                "</p>").format(srcProjectDirectory,
+                                               dstProjectDirectory))
+                    return
+                
+                dstUid = QUuid.createUuid().toString()
+                dstProject = {
+                    'name': self.tr("{0} - Copy").format(srcProject["name"]),
+                    'file': os.path.join(dstProjectDirectory,
+                                         os.path.basename(srcProject["file"])),
+                    'master': False,
+                    'description': srcProject["description"],
+                    'category': srcProject["category"],
+                    'uid': dstUid,
+                }
+                self.__projects[dstUid] = dstProject
+                self.projectAdded.emit(dstProject)
+                self.setDirty(True)
+    
     def changeProjectProperties(self, pro):
         """
         Public method to change the data of a project entry.
@@ -414,6 +476,21 @@ class MultiProject(QObject):
             self.projectRemoved.emit(project)
             self.setDirty(True)
     
+    def deleteProject(self, uid):
+        """
+        Public slot to delete project(s) from the multi project and disk.
+        
+        @param uid UID of the project to be removed from the multi
+            project
+        @type str
+        """
+        if uid in self.__projects:
+            project = self.__projects[uid]
+            projectPath = os.path.dirname(project["file"])
+            shutil.rmtree(projectPath, True)
+            
+            self.removeProject(uid)
+    
     def __newMultiProject(self):
         """
         Private slot to build a new multi project.
@@ -525,8 +602,10 @@ class MultiProject(QObject):
         if self.ppath:
             defaultPath = self.ppath
         else:
-            defaultPath = Preferences.getMultiProject("Workspace") or \
+            defaultPath = (
+                Preferences.getMultiProject("Workspace") or
                 Utilities.getHomeDir()
+            )
         fn, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self.parent(),
             self.tr("Save multiproject as"),
@@ -908,9 +987,11 @@ class MultiProject(QObject):
         """
         for project in self.__projects.values():
             if project['master']:
-                if reopen or \
-                   not self.projectObject.isOpen() or \
-                   self.projectObject.getProjectFile() != project['file']:
+                if (
+                    reopen or
+                    not self.projectObject.isOpen() or
+                    self.projectObject.getProjectFile() != project['file']
+                ):
                     self.openProject(project['file'])
                     return
     
