@@ -1,21 +1,25 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the IRC channel widget.
 """
 
-from __future__ import unicode_literals
+
+from itertools import zip_longest
 
 import re
 
-from PyQt5.QtCore import pyqtSlot, pyqtSignal, QDateTime, QPoint, QFileInfo, \
-    QTimer, QUrl
+from PyQt5.QtCore import (
+    pyqtSlot, pyqtSignal, QDateTime, QPoint, QFileInfo, QTimer, QUrl,
+    QCoreApplication
+)
 from PyQt5.QtGui import QIcon, QPainter, QTextCursor, QDesktopServices
-from PyQt5.QtWidgets import QWidget, QListWidgetItem, QMenu, QApplication, \
-    QInputDialog, QLineEdit
+from PyQt5.QtWidgets import (
+    QWidget, QListWidgetItem, QMenu, QApplication, QInputDialog, QLineEdit
+)
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5Application import e5App
@@ -63,7 +67,9 @@ class IrcUserItem(QListWidgetItem):
         
         self.__privilege = IrcUserItem.Normal
         self.__name = name
+        self.__ignored = False
         
+        self.__setText()
         self.__setIcon()
     
     def name(self):
@@ -81,7 +87,7 @@ class IrcUserItem(QListWidgetItem):
         @param name new nick name for the user (string)
         """
         self.__name = name
-        self.setText(name)
+        self.__setText()
     
     def changePrivilege(self, privilege):
         """
@@ -106,6 +112,17 @@ class IrcUserItem(QListWidgetItem):
         self.__privilege = IrcUserItem.Normal
         self.__setIcon()
     
+    def __setText(self):
+        """
+        Private method to set the user item text.
+        """
+        if self.__ignored:
+            self.setText(QCoreApplication.translate(
+                "IrcUserItem",
+                "{0} (ignored)").format(self.__name))
+        else:
+            self.setText(self.__name)
+    
     def __setIcon(self):
         """
         Private method to set the icon dependent on user privileges.
@@ -176,6 +193,25 @@ class IrcUserItem(QListWidgetItem):
         return(bool(self.__privilege & IrcUserItem.Operator) or
                bool(self.__privilege & IrcUserItem.Admin) or
                bool(self.__privilege & IrcUserItem.Owner))
+    
+    def setIgnored(self, ignored):
+        """
+        Public method to set the user status to ignored.
+        
+        @param ignored flag indicating the new ignored status
+        @type bool
+        """
+        self.__ignored = ignored
+        self.__setText()
+    
+    def isIgnored(self):
+        """
+        Public method to check, if this user is ignored.
+        
+        @return flag indicating the ignored status
+        @rtype bool
+        """
+        return self.__ignored
 
 
 class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
@@ -183,15 +219,24 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
     Class implementing the IRC channel widget.
     
     @signal sendData(str) emitted to send a message to the channel
+    @signal sendCtcpRequest(str, str, str) emitted to send a CTCP request
     @signal sendCtcpReply(str, str) emitted to send a CTCP reply
     @signal channelClosed(str) emitted after the user has left the channel
     @signal openPrivateChat(str) emitted to open a "channel" for private
         messages
+    @signal awayCommand(str) emitted to set the away status via the /away
+        command
+    @signal leaveChannels(list) emitted to leave a list of channels
+    @signal leaveAllChannels() emitted to leave all channels
     """
     sendData = pyqtSignal(str)
+    sendCtcpRequest = pyqtSignal(str, str, str)
     sendCtcpReply = pyqtSignal(str, str)
     channelClosed = pyqtSignal(str)
     openPrivateChat = pyqtSignal(str)
+    awayCommand = pyqtSignal(str)
+    leaveChannels = pyqtSignal(list)
+    leaveAllChannels = pyqtSignal()
     
     UrlRe = re.compile(
         r"""((?:http|ftp|https):\/\/[\w\-_]+(?:\.[\w\-_]+)+"""
@@ -234,6 +279,8 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         self.__markerLine = ""
         self.__hidden = True
         
+        self.__serviceNamesLower = ["nickserv", "chanserv", "memoserv"]
+        
         self.__patterns = [
             # :foo_!n=foo@foohost.bar.net PRIVMSG #eric-ide :some long message
             # :foo_!n=foo@foohost.bar.net PRIVMSG bar_ :some long message
@@ -349,37 +396,137 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         """
         msg = self.messageEdit.text()
         if msg:
-            self.messages.append(
-                '<font color="{0}">{2} <b>&lt;</b><font color="{1}">{3}</font>'
-                '<b>&gt;</b> {4}</font>'.format(
-                    Preferences.getIrc("ChannelMessageColour"),
-                    Preferences.getIrc("OwnNickColour"),
-                    ircTimestamp(), self.__userName,
-                    Utilities.html_encode(msg)))
-            if msg.startswith("/"):
-                if self.__private:
-                    E5MessageBox.information(
-                        self,
-                        self.tr("Send Message"),
-                        self.tr(
-                            """Messages starting with a '/' are not allowed"""
-                            """ in private chats."""))
-                else:
-                    msgList = msg.split(None, 1)
-                    cmd = msgList[0][1:].upper()
-                    if cmd == "MSG":
-                        cmd = "PRIVMSG"
-                    msgList[0] = cmd
-                    self.sendData.emit(" ".join(msgList))
+            self.__processUserMessage(msg)
+
+    def __processUserMessage(self, msg):
+        """
+        Private method to process a message entered by the user or via the
+        user list context menu.
+        
+        @param msg message to be processed
+        @type str
+        """
+        self.messages.append(
+            '<font color="{0}">{2} <b>&lt;</b><font color="{1}">{3}</font>'
+            '<b>&gt;</b> {4}</font>'.format(
+                Preferences.getIrc("ChannelMessageColour"),
+                Preferences.getIrc("OwnNickColour"),
+                ircTimestamp(), self.__userName,
+                Utilities.html_encode(msg)))
+
+        if msg.startswith("/"):
+            if self.__private:
+                E5MessageBox.information(
+                    self,
+                    self.tr("Send Message"),
+                    self.tr(
+                        """Messages starting with a '/' are not allowed"""
+                        """ in private chats."""))
             else:
-                if self.__private:
-                    self.sendData.emit(
-                        "PRIVMSG " + self.__privatePartner + " :" + msg)
+                sendData = True
+                # flag set to False, if command was handled
+
+                msgList = msg.split()
+                cmd = msgList[0][1:].upper()
+                if cmd in ["MSG", "QUERY"]:
+                    cmd = "PRIVMSG"
+                    if len(msgList) > 1:
+                        if (
+                            msgList[1].strip().lower() in
+                            self.__serviceNamesLower
+                        ):
+                            msg = (
+                                "PRIVMSG " +
+                                msgList[1].strip().lower() +
+                                " :" + " ".join(msgList[2:])
+                            )
+                        else:
+                            msg = "PRIVMSG {0} :{1}".format(
+                                msgList[1], " ".join(msgList[2:]))
+                    else:
+                        msgList[0] = cmd
+                        msg = " ".join(msgList)
+                elif cmd == "NOTICE":
+                    if len(msgList) > 2:
+                        msg = "NOTICE {0} :{1}".format(
+                            msgList[1], " ".join(msgList[2:]))
+                    else:
+                        msg = "NOTICE {0}".format(" ".join(msgList[1:]))
+                elif cmd == "PING":
+                    receiver = msgList[1]
+                    msg = "PING {0} "
+                    self.sendCtcpRequest.emit(receiver, "PING", "")
+                    sendData = False
+                elif cmd == "IGNORE":
+                    sendData = False
+                    if len(msgList) > 1:
+                        if msgList[1] == "-r":
+                            ignored = False
+                            userNamesList = msgList[2:]
+                        else:
+                            ignored = True
+                            userNamesList = msgList[1:]
+                    else:
+                        userNamesList = []
+                    userNames = ",".join(
+                        u.rstrip(",") for u in userNamesList).split(",")
+                    for userName in userNames:
+                        itm = self.__findUser(userName)
+                        if itm:
+                            itm.setIgnored(ignored)
+                elif cmd == "UNIGNORE":
+                    sendData = False
+                    if len(msgList) > 1:
+                        userNamesList = msgList[1:]
+                    else:
+                        userNamesList = []
+                    userNames = ",".join(
+                        u.rstrip(",") for u in userNamesList).split(",")
+                    for userName in userNames:
+                        itm = self.__findUser(userName)
+                        if itm:
+                            itm.setIgnored(False)
+                elif cmd == "AWAY":
+                    sendData = False
+                    if len(msgList) > 1:
+                        msg = " ".join(msgList[1:])
+                    else:
+                        msg = ""
+                    self.awayCommand.emit(msg)
+                elif cmd == "JOIN":
+                    sendData = False
+                    if len(msgList) > 1:
+                        channels = msgList[1].split(",")
+                        if len(msgList) > 2:
+                            keys = msgList[2].split(",")
+                        else:
+                            keys = []
+                        for channel, key in zip_longest(
+                                channels, keys, fillvalue=""):
+                            self.__ircWidget.joinChannel(channel, key)
+                elif cmd == "PART":
+                    sendData = False
+                    if len(msgList) == 1:
+                        self.leaveChannel()
+                    else:
+                        self.leaveChannels.emit(msgList[1:])
+                elif cmd == "PARTALL":
+                    sendData = False
+                    self.leaveAllChannels.emit()
                 else:
-                    self.sendData.emit(
-                        "PRIVMSG " + self.__name + " :" + msg)
-            self.messageEdit.clear()
-            self.unsetMarkerLine()
+                    msg = msg[1:]
+                if sendData:
+                    self.sendData.emit(msg)
+        else:
+            if self.__private:
+                self.sendData.emit(
+                    "PRIVMSG " + self.__privatePartner + " :" + msg)
+            else:
+                self.sendData.emit(
+                    "PRIVMSG " + self.__name + " :" + msg)
+
+        self.messageEdit.clear()
+        self.unsetMarkerLine()
     
     def requestLeave(self):
         """
@@ -389,13 +536,19 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
             self,
             self.tr("Leave IRC channel"),
             self.tr(
-                """Do you really want to leave the IRC channel <b>{0}</b>?""")
-            .format(self.__name))
+                """Do you really want to leave the IRC channel"""
+                """ <b>{0}</b>?""").format(self.__name))
         if ok:
-            if not self.__private:
-                self.sendData.emit(
-                    "PART " + self.__name + " :" + self.__partMessage)
-            self.channelClosed.emit(self.__name)
+            self.leaveChannel()
+
+    def leaveChannel(self):
+        """
+        Public slot to leave the channel.
+        """
+        if not self.__private:
+            self.sendData.emit(
+                "PART " + self.__name + " :" + self.__partMessage)
+        self.channelClosed.emit(self.__name)
     
     def name(self):
         """
@@ -500,10 +653,16 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         # group(3)   target nick
         # group(4)   message
         if match.group(3).lower() == self.__name.lower():
+            senderName = match.group(1)
+            itm = self.__findUser(senderName)
+            if itm and itm.isIgnored():
+                # user should be ignored
+                return True
+            
             if match.group(4).startswith("\x01"):
                 return self.__handleCtcp(match)
             
-            self.addMessage(match.group(1), match.group(4))
+            self.addMessage(senderName, match.group(4))
             if self.__private and not self.topicLabel.text():
                 self.setPrivateInfo(
                     "{0} - {1}".format(match.group(1), match.group(2)))
@@ -529,8 +688,10 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                 self.__ui.showNotification(
                     UI.PixmapCache.getPixmap("irc48.png"),
                     self.tr("Channel Message"), msg)
-            elif Preferences.getIrc("NotifyNick") and \
-                    self.__userName.lower() in msg.lower():
+            elif (
+                Preferences.getIrc("NotifyNick") and
+                self.__userName.lower() in msg.lower()
+            ):
                 self.__ui.showNotification(
                     UI.PixmapCache.getPixmap("irc48.png"),
                     self.tr("Nick mentioned"), msg)
@@ -567,8 +728,10 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                     self.__name, match.group(2))
                 self.__addManagementMessage(
                     IrcChannelWidget.JoinIndicator, msg)
-            if Preferences.getIrc("ShowNotifications") and \
-               Preferences.getIrc("NotifyJoinPart"):
+            if (
+                Preferences.getIrc("ShowNotifications") and
+                Preferences.getIrc("NotifyJoinPart")
+            ):
                 self.__ui.showNotification(
                     UI.PixmapCache.getPixmap("irc48.png"),
                     self.tr("Join Channel"), msg)
@@ -600,8 +763,10 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                     match.group(1), self.__name, match.group(3))
                 self.__addManagementMessage(
                     IrcChannelWidget.LeaveIndicator, msg)
-            if Preferences.getIrc("ShowNotifications") and \
-               Preferences.getIrc("NotifyJoinPart"):
+            if (
+                Preferences.getIrc("ShowNotifications") and
+                Preferences.getIrc("NotifyJoinPart")
+            ):
                 self.__ui.showNotification(
                     UI.PixmapCache.getPixmap("irc48.png"),
                     self.tr("Leave Channel"), nmsg)
@@ -630,8 +795,10 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                     match.group(1), self.__name, ircFilter(match.group(2)))
                 self.__addManagementMessage(
                     IrcChannelWidget.MessageIndicator, msg)
-            if Preferences.getIrc("ShowNotifications") and \
-               Preferences.getIrc("NotifyJoinPart"):
+            if (
+                Preferences.getIrc("ShowNotifications") and
+                Preferences.getIrc("NotifyJoinPart")
+            ):
                 self.__ui.showNotification(
                     UI.PixmapCache.getPixmap("irc48.png"),
                     self.tr("Quit"), msg)
@@ -831,8 +998,8 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                 elif mode == "a":
                     if isPlus:
                         message = self.tr(
-                            "{0} sets the channel mode to 'anonymous'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'anonymous'."
+                        ).format(nick)
                     else:
                         message = self.tr(
                             "{0} removes the 'anonymous' mode from the"
@@ -867,8 +1034,8 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                 elif mode == "i":
                     if isPlus:
                         message = self.tr(
-                            "{0} sets the channel mode to 'invite only'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'invite only'."
+                        ).format(nick)
                     else:
                         message = self.tr(
                             "{0} removes the 'invite only' mode from the"
@@ -892,12 +1059,12 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                 elif mode == "m":
                     if isPlus:
                         message = self.tr(
-                            "{0} sets the channel mode to 'moderated'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'moderated'."
+                        ).format(nick)
                     else:
                         message = self.tr(
-                            "{0} sets the channel mode to 'unmoderated'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'unmoderated'."
+                        ).format(nick)
                 elif mode == "n":
                     if isPlus:
                         message = self.tr(
@@ -910,40 +1077,40 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                 elif mode == "p":
                     if isPlus:
                         message = self.tr(
-                            "{0} sets the channel mode to 'private'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'private'."
+                        ).format(nick)
                     else:
                         message = self.tr(
-                            "{0} sets the channel mode to 'public'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'public'."
+                        ).format(nick)
                 elif mode == "q":
                     if isPlus:
                         message = self.tr(
-                            "{0} sets the channel mode to 'quiet'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'quiet'."
+                        ).format(nick)
                     else:
                         message = self.tr(
-                            "{0} removes the 'quiet' mode from the channel.")\
-                            .format(nick)
+                            "{0} removes the 'quiet' mode from the channel."
+                        ).format(nick)
                 elif mode == "r":
                     continue
                 elif mode == "s":
                     if isPlus:
                         message = self.tr(
-                            "{0} sets the channel mode to 'secret'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'secret'."
+                        ).format(nick)
                     else:
                         message = self.tr(
-                            "{0} sets the channel mode to 'visible'.")\
-                            .format(nick)
+                            "{0} sets the channel mode to 'visible'."
+                        ).format(nick)
                 elif mode == "t":
                     if isPlus:
                         message = self.tr(
                             "{0} switches on 'topic protection'.").format(nick)
                     else:
                         message = self.tr(
-                            "{0} switches off 'topic protection'.")\
-                            .format(nick)
+                            "{0} switches off 'topic protection'."
+                        ).format(nick)
                 elif mode == "I":
                     if isPlus:
                         message = self.tr(
@@ -1119,9 +1286,11 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         
         @param message message to be appended (string)
         """
-        if self.__hidden and \
-           self.__markerLine == "" and \
-           Preferences.getIrc("MarkPositionWhenHidden"):
+        if (
+            self.__hidden and
+            self.__markerLine == "" and
+            Preferences.getIrc("MarkPositionWhenHidden")
+        ):
             self.setMarkerLine()
         self.messages.append(message)
     
@@ -1130,11 +1299,12 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         Public method to draw a line to mark the current position.
         """
         self.unsetMarkerLine()
-        self.__markerLine = \
-            '<span style=" color:{0}; background-color:{1};">{2}</span>'\
+        self.__markerLine = (
+            '<span style=" color:{0}; background-color:{1};">{2}</span>'
             .format(Preferences.getIrc("MarkerLineForegroundColour"),
                     Preferences.getIrc("MarkerLineBackgroundColour"),
                     self.tr('--- New From Here ---'))
+        )
         self.messages.append(self.__markerLine)
     
     def unsetMarkerLine(self):
@@ -1246,29 +1416,24 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         Private slot to initialize the context menu of the messages pane.
         """
         self.__messagesMenu = QMenu(self)
-        self.__copyMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editCopy.png"),
-                self.tr("Copy"), self.__copyMessages)
+        self.__copyMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editCopy.png"),
+            self.tr("Copy"), self.__copyMessages)
         self.__messagesMenu.addSeparator()
-        self.__cutAllMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editCut.png"),
-                self.tr("Cut all"), self.__cutAllMessages)
-        self.__copyAllMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editCopy.png"),
-                self.tr("Copy all"), self.__copyAllMessages)
+        self.__cutAllMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editCut.png"),
+            self.tr("Cut all"), self.__cutAllMessages)
+        self.__copyAllMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editCopy.png"),
+            self.tr("Copy all"), self.__copyAllMessages)
         self.__messagesMenu.addSeparator()
-        self.__clearMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editDelete.png"),
-                self.tr("Clear"), self.__clearMessages)
+        self.__clearMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editDelete.png"),
+            self.tr("Clear"), self.__clearMessages)
         self.__messagesMenu.addSeparator()
-        self.__saveMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("fileSave.png"),
-                self.tr("Save"), self.__saveMessages)
+        self.__saveMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("fileSave.png"),
+            self.tr("Save"), self.__saveMessages)
         self.__messagesMenu.addSeparator()
         self.__setMarkerMessagesAct = self.__messagesMenu.addAction(
             self.tr("Mark Current Position"), self.setMarkerLine)
@@ -1317,6 +1482,62 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         user = self.usersList.selectedItems()[0].text()
         self.openPrivateChat.emit(user)
     
+    def __sendUserMessage(self):
+        """
+        Private slot to send a private message to a specific user.
+        """
+        from E5Gui import E5TextInputDialog
+        
+        user = self.usersList.selectedItems()[0].text()
+        ok, message = E5TextInputDialog.getText(
+            self, self.tr("Send Message"),
+            self.tr("Enter the message to be sent:"),
+            minimumWidth=400)
+        if ok and message:
+            self.__processUserMessage("/MSG {0} {1}".format(user, message))
+    
+    def __sendUserQuery(self):
+        """
+        Private slot to send a query message to a specific user.
+        """
+        from E5Gui import E5TextInputDialog
+        
+        user = self.usersList.selectedItems()[0].text()
+        ok, message = E5TextInputDialog.getText(
+            self, self.tr("Send Query"),
+            self.tr("Enter the message to be sent:"),
+            minimumWidth=400)
+        if ok and message:
+            self.__processUserMessage("/QUERY {0} {1}".format(user, message))
+    
+    def __sendUserNotice(self):
+        """
+        Private slot to send a notice message to a specific user.
+        """
+        from E5Gui import E5TextInputDialog
+        
+        user = self.usersList.selectedItems()[0].text()
+        ok, message = E5TextInputDialog.getText(
+            self, self.tr("Send Notice"),
+            self.tr("Enter the message to be sent:"),
+            minimumWidth=400)
+        if ok and message:
+            self.__processUserMessage("/NOTICE {0} {1}".format(user, message))
+    
+    def __pingUser(self):
+        """
+        Private slot to send a ping to a specific user.
+        """
+        user = self.usersList.selectedItems()[0].text()
+        self.__processUserMessage("/PING {0}".format(user))
+    
+    def __ignoreUser(self):
+        """
+        Private slot to ignore a specific user.
+        """
+        user = self.usersList.selectedItems()[0].text()
+        self.__processUserMessage("/IGNORE {0}".format(user))
+    
     def __initUsersMenu(self):
         """
         Private slot to initialize the users list context menu.
@@ -1328,6 +1549,18 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         self.__privateChatAct = self.__usersMenu.addAction(
             self.tr("Private Chat"), self.__openPrivateChat)
         self.__usersMenu.addSeparator()
+        self.__sendUserMessageAct = self.__usersMenu.addAction(
+            self.tr("Send Message"), self.__sendUserMessage)
+        self.__sendUserQueryAct = self.__usersMenu.addAction(
+            self.tr("Send Query"), self.__sendUserQuery)
+        self.__sendUserNoticeAct = self.__usersMenu.addAction(
+            self.tr("Send Notice"), self.__sendUserNotice)
+        self.__usersMenu.addSeparator()
+        self.__pingUserAct = self.__usersMenu.addAction(
+            self.tr("Send Ping"), self.__pingUser)
+        self.__ignoreUserAct = self.__usersMenu.addAction(
+            self.tr("Ignore User"), self.__ignoreUser)
+        self.__usersMenu.addSeparator()
         self.__usersListRefreshAct = self.__usersMenu.addAction(
             self.tr("Refresh"), self.__sendAutoWhoCommand)
     
@@ -1437,8 +1670,10 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
         # group(5)  user flags
         # group(6)  real name
         if match.group(1).lower() == self.__name.lower():
-            away = self.tr(" (Away)") if match.group(5).startswith("G") \
-                else ""
+            away = (
+                self.tr(" (Away)")
+                if match.group(5).startswith("G") else ""
+            )
             self.__addManagementMessage(
                 self.tr("Who"),
                 self.tr("{0} is {1}@{2} ({3}){4}").format(
@@ -1491,8 +1726,10 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
             for channel in channelList:
                 if channel.startswith(("*", "&")):
                     adminChannels.append(channel[1:])
-                elif channel.startswith(("!", "~")) and \
-                        self.__ircWidget.isChannelName(channel[1:]):
+                elif (
+                    channel.startswith(("!", "~")) and
+                    self.__ircWidget.isChannelName(channel[1:])
+                ):
                     ownerChannels.append(channel[1:])
                 elif channel.startswith("@+"):
                     opChannels.append(channel[2:])
