@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the identities management dialog.
 """
 
-from __future__ import unicode_literals
 
 import copy
 
@@ -49,6 +48,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         self.nicknameUpButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
         self.nicknameDownButton.setIcon(
             UI.PixmapCache.getIcon("1downarrow.png"))
+        self.showPasswordButton.setIcon(
+            UI.PixmapCache.getIcon("showPassword.png"))
         
         self.__manager = manager
         
@@ -56,8 +57,9 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         self.__currentIdentity = None
         
         identities = list(sorted(self.__manager.getIdentityNames()))
-        identities[identities.index(IrcIdentity.DefaultIdentityName)] = \
+        identities[identities.index(IrcIdentity.DefaultIdentityName)] = (
             IrcIdentity.DefaultIdentityDisplay
+        )
         self.identitiesCombo.addItems(identities)
         if identityName == IrcIdentity.DefaultIdentityName:
             identityName = IrcIdentity.DefaultIdentityDisplay
@@ -362,8 +364,10 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
             if self.nicknamesList.currentRow() == 0:
                 self.nicknameUpButton.setEnabled(False)
                 self.nicknameDownButton.setEnabled(True)
-            elif self.nicknamesList.currentRow() == \
-                    self.nicknamesList.count() - 1:
+            elif (
+                self.nicknamesList.currentRow() ==
+                self.nicknamesList.count() - 1
+            ):
                 self.nicknameUpButton.setEnabled(True)
                 self.nicknameDownButton.setEnabled(False)
             else:
@@ -453,6 +457,27 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
             self.nicknamesList.insertItem(row, itm)
             self.nicknamesList.setCurrentItem(itm)
     
+    @pyqtSlot(bool)
+    def on_showPasswordButton_clicked(self, checked):
+        """
+        Private slot to show or hide the password.
+        
+        @param checked state of the button
+        @type bool
+        """
+        if checked:
+            self.passwordEdit.setEchoMode(QLineEdit.Normal)
+            self.showPasswordButton.setIcon(
+                UI.PixmapCache.getIcon("hidePassword.png"))
+            self.showPasswordButton.setToolTip(
+                self.tr("Press to hide the password"))
+        else:
+            self.passwordEdit.setEchoMode(QLineEdit.Password)
+            self.showPasswordButton.setIcon(
+                UI.PixmapCache.getIcon("showPassword.png"))
+            self.showPasswordButton.setToolTip(
+                self.tr("Press to show the password"))
+    
     def accept(self):
         """
         Public slot handling the acceptance of the dialog.
