@@ -7,14 +7,11 @@
 Module implementing a specialized line edit for entering IRC messages.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import Qt
 
 from E5Gui.E5LineEdit import E5LineEdit, E5ClearableLineEdit
 
-from Globals import qVersionTuple
-
 
 class IrcMessageEdit(E5ClearableLineEdit):
     """
@@ -77,10 +74,7 @@ class IrcMessageEdit(E5ClearableLineEdit):
         
         @param evt reference to the wheel event (QWheelEvent)
         """
-        if qVersionTuple() >= (5, 0, 0):
-            delta = evt.angleDelta().y()
-        else:
-            delta = evt.delta()
+        delta = evt.angleDelta().y()
         if delta > 0:
             self.__getHistory(True)
         elif delta < 0:
@@ -95,8 +89,10 @@ class IrcMessageEdit(E5ClearableLineEdit):
         @param txt text to be added to the history (string)
         """
         # Only add the entry, if it is not the same as last time
-        if len(self.__historyList) == 1 or \
-           (len(self.__historyList) > 1 and self.__historyList[1] != txt):
+        if (
+            len(self.__historyList) == 1 or
+            (len(self.__historyList) > 1 and self.__historyList[1] != txt)
+        ):
             # Replace empty first entry and add new empty first entry
             self.__historyList[0] = txt
             self.__historyList.insert(0, "")
