@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the IRC data structures and their manager.
 """
 
-from __future__ import unicode_literals
 
 import copy
 
@@ -806,8 +805,7 @@ class IrcNetworkManager(QObject):
         
         self.__settings.endGroup()
         
-        if not self.__identities or \
-           not self.__networks:
+        if not self.__identities or not self.__networks:
             # data structures got corrupted; load defaults
             self.__loadDefaults()
         
@@ -917,8 +915,10 @@ class IrcNetworkManager(QObject):
         
         @param name name of the identity to delete (string)
         """
-        if name in self.__identities and \
-                name != IrcIdentity.DefaultIdentityName:
+        if (
+            name in self.__identities and
+            name != IrcIdentity.DefaultIdentityName
+        ):
             del self.__identities[name]
             self.identityChanged()
     
