@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the network part of the IRC widget.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QPoint, QFileInfo, QUrl, QThread
 from PyQt5.QtGui import QDesktopServices
@@ -167,20 +166,41 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         Private slot to toggle the away status.
         """
         if self.__away:
+            self.handleAwayCommand("")
+        else:
+            networkName = self.networkCombo.currentText()
+            identityName = (
+                self.__manager.getNetwork(networkName).getIdentityName()
+            )
+            identity = self.__manager.getIdentity(identityName)
+            if identity:
+                awayMessage = identity.getAwayMessage()
+            else:
+                awayMessage = ""
+            self.handleAwayCommand(awayMessage)
+    
+    @pyqtSlot(str)
+    def handleAwayCommand(self, awayMessage):
+        """
+        Public slot to process an away command.
+        
+        @param awayMessage message to be set for being away
+        @type str
+        """
+        if awayMessage and not self.__away:
+            # set being away
+            # don't send away, if the status is already set
+            self.sendData.emit("AWAY :" + awayMessage)
+            self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserAway.png"))
+            self.__away = True
+            self.away.emit(self.__away)
+        elif not awayMessage and self.__away:
+            # cancel being away
             self.sendData.emit("AWAY")
             self.awayButton.setIcon(
                 UI.PixmapCache.getIcon("ircUserPresent.png"))
             self.__away = False
-        else:
-            networkName = self.networkCombo.currentText()
-            identityName = self.__manager.getNetwork(networkName)\
-                .getIdentityName()
-            awayMessage = self.__manager.getIdentity(identityName)\
-                .getAwayMessage()
-            self.sendData.emit("AWAY :" + awayMessage)
-            self.awayButton.setIcon(UI.PixmapCache.getIcon("ircUserAway.png"))
-            self.__away = True
-        self.away.emit(self.__away)
+            self.away.emit(self.__away)
     
     @pyqtSlot()
     def on_editButton_clicked(self):
@@ -450,29 +470,24 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
         Private slot to initialize the context menu of the messages pane.
         """
         self.__messagesMenu = QMenu(self)
-        self.__copyMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editCopy.png"),
-                self.tr("Copy"), self.__copyMessages)
+        self.__copyMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editCopy.png"),
+            self.tr("Copy"), self.__copyMessages)
         self.__messagesMenu.addSeparator()
-        self.__cutAllMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editCut.png"),
-                self.tr("Cut all"), self.__cutAllMessages)
-        self.__copyAllMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editCopy.png"),
-                self.tr("Copy all"), self.__copyAllMessages)
+        self.__cutAllMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editCut.png"),
+            self.tr("Cut all"), self.__cutAllMessages)
+        self.__copyAllMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editCopy.png"),
+            self.tr("Copy all"), self.__copyAllMessages)
         self.__messagesMenu.addSeparator()
-        self.__clearMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("editDelete.png"),
-                self.tr("Clear"), self.__clearMessages)
+        self.__clearMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("editDelete.png"),
+            self.tr("Clear"), self.__clearMessages)
         self.__messagesMenu.addSeparator()
-        self.__saveMessagesAct = \
-            self.__messagesMenu.addAction(
-                UI.PixmapCache.getIcon("fileSave.png"),
-                self.tr("Save"), self.__saveMessages)
+        self.__saveMessagesAct = self.__messagesMenu.addAction(
+            UI.PixmapCache.getIcon("fileSave.png"),
+            self.tr("Save"), self.__saveMessages)
         
         self.on_messages_copyAvailable(False)
     
