@@ -1,22 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the IRC window.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import re
 import logging
 
-from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QByteArray, QTimer
+from PyQt5.QtCore import (
+    pyqtSlot, pyqtSignal, Qt, QByteArray, QTimer, QDateTime
+)
 from PyQt5.QtWidgets import QWidget, QToolButton, QLabel, QTabWidget
 from PyQt5.QtNetwork import QTcpSocket, QAbstractSocket
 try:
@@ -127,7 +124,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         self.networkWidget.initialize(self.__ircNetworkManager)
         self.networkWidget.connectNetwork.connect(self.__connectNetwork)
         self.networkWidget.editNetwork.connect(self.__editNetwork)
-        self.networkWidget.joinChannel.connect(self.__joinChannel)
+        self.networkWidget.joinChannel.connect(self.joinChannel)
         self.networkWidget.nickChanged.connect(self.__changeNick)
         self.networkWidget.sendData.connect(self.__send)
         self.networkWidget.away.connect(self.__away)
@@ -181,54 +178,66 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                 self.__identityName = network.getIdentityName()
                 identity = self.__ircNetworkManager.getIdentity(
                     self.__identityName)
-                self.__userName = identity.getIdent()
-                self.__quitMessage = identity.getQuitMessage()
-                if self.__server:
-                    useSSL = self.__server.useSSL()
-                    if useSSL and not SSL_AVAILABLE:
-                        E5MessageBox.critical(
-                            self,
-                            self.tr("SSL Connection"),
-                            self.tr(
-                                """An encrypted connection to the IRC"""
-                                """ network was requested but SSL is not"""
-                                """ available. Please change the server"""
-                                """ configuration."""))
-                        return
-                    
-                    if useSSL:
-                        # create SSL socket
-                        self.__socket = QSslSocket(self)
-                        self.__socket.encrypted.connect(self.__hostConnected)
-                        self.__socket.sslErrors.connect(self.__sslErrors)
-                    else:
-                        # create TCP socket
-                        self.__socket = QTcpSocket(self)
-                        self.__socket.connected.connect(self.__hostConnected)
-                    self.__socket.hostFound.connect(self.__hostFound)
-                    self.__socket.disconnected.connect(self.__hostDisconnected)
-                    self.__socket.readyRead.connect(self.__readyRead)
-                    self.__socket.error.connect(self.__tcpError)
-                    
-                    self.__connectionState = IrcWidget.ServerConnecting
-                    if useSSL:
-                        self.networkWidget.addServerMessage(
-                            self.tr("Info"),
-                            self.tr("Looking for server {0} (port {1})"
-                                    " using an SSL encrypted connection"
-                                    "...").format(self.__server.getName(),
-                                                  self.__server.getPort()))
-                        self.__socket.connectToHostEncrypted(
-                            self.__server.getName(), self.__server.getPort())
-                    else:
-                        self.networkWidget.addServerMessage(
-                            self.tr("Info"),
-                            self.tr(
-                                "Looking for server {0} (port {1})...").format(
+                if identity:
+                    self.__userName = identity.getIdent()
+                    self.__quitMessage = identity.getQuitMessage()
+                    if self.__server:
+                        useSSL = self.__server.useSSL()
+                        if useSSL and not SSL_AVAILABLE:
+                            E5MessageBox.critical(
+                                self,
+                                self.tr("SSL Connection"),
+                                self.tr(
+                                    """An encrypted connection to the IRC"""
+                                    """ network was requested but SSL is not"""
+                                    """ available. Please change the server"""
+                                    """ configuration."""))
+                            return
+                        
+                        if useSSL:
+                            # create SSL socket
+                            self.__socket = QSslSocket(self)
+                            self.__socket.encrypted.connect(
+                                self.__hostConnected)
+                            self.__socket.sslErrors.connect(
+                                self.__sslErrors)
+                        else:
+                            # create TCP socket
+                            self.__socket = QTcpSocket(self)
+                            self.__socket.connected.connect(
+                                self.__hostConnected)
+                        self.__socket.hostFound.connect(
+                            self.__hostFound)
+                        self.__socket.disconnected.connect(
+                            self.__hostDisconnected)
+                        self.__socket.readyRead.connect(
+                            self.__readyRead)
+                        self.__socket.error.connect(
+                            self.__tcpError)
+                        
+                        self.__connectionState = IrcWidget.ServerConnecting
+                        if useSSL:
+                            self.networkWidget.addServerMessage(
+                                self.tr("Info"),
+                                self.tr("Looking for server {0} (port {1})"
+                                        " using an SSL encrypted connection"
+                                        "...").format(self.__server.getName(),
+                                                      self.__server.getPort()))
+                            self.__socket.connectToHostEncrypted(
                                 self.__server.getName(),
-                                self.__server.getPort()))
-                        self.__socket.connectToHost(self.__server.getName(),
-                                                    self.__server.getPort())
+                                self.__server.getPort()
+                            )
+                        else:
+                            self.networkWidget.addServerMessage(
+                                self.tr("Info"),
+                                self.tr(
+                                    "Looking for server {0} (port {1})...")
+                                .format(
+                                    self.__server.getName(),
+                                    self.__server.getPort()))
+                            self.__socket.connectToHost(
+                                self.__server.getName(),
+                                self.__server.getPort())
         else:
             if silent:
                 ok = True
@@ -288,9 +297,9 @@ class IrcWidget(QWidget, Ui_IrcWidget):
             for channel in self.__channelList:
                 channel.setPartMessage(partMsg)
     
-    def __joinChannel(self, name, key=""):
+    def joinChannel(self, name, key=""):
         """
-        Private slot to join a channel.
+        Public slot to join a channel.
         
         @param name name of the channel (string)
         @param key key of the channel (string)
@@ -305,14 +314,19 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         channel.setName(name)
         channel.setUserName(self.__nickName)
         identity = self.__ircNetworkManager.getIdentity(self.__identityName)
-        channel.setPartMessage(identity.getPartMessage())
+        if identity:
+            channel.setPartMessage(identity.getPartMessage())
         channel.setUserPrivilegePrefix(self.__userPrefix)
         channel.initAutoWho()
         
         channel.sendData.connect(self.__send)
+        channel.sendCtcpRequest.connect(self.__sendCtcpRequest)
         channel.sendCtcpReply.connect(self.__sendCtcpReply)
         channel.channelClosed.connect(self.__closeChannel)
         channel.openPrivateChat.connect(self.__openPrivate)
+        channel.awayCommand.connect(self.networkWidget.handleAwayCommand)
+        channel.leaveChannels.connect(self.__leaveChannels)
+        channel.leaveAllChannels.connect(self.__leaveAllChannels)
         
         self.channelsWidget.addTab(channel, name)
         self.__channelList.append(channel)
@@ -365,14 +379,19 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         channel.setName(self.__nickName)
         channel.setUserName(self.__nickName)
         identity = self.__ircNetworkManager.getIdentity(self.__identityName)
-        channel.setPartMessage(identity.getPartMessage())
+        if identity:
+            channel.setPartMessage(identity.getPartMessage())
         channel.setUserPrivilegePrefix(self.__userPrefix)
         channel.setPrivate(True, name)
         channel.addUsers([name, self.__nickName])
         
         channel.sendData.connect(self.__send)
+        channel.sendCtcpRequest.connect(self.__sendCtcpRequest)
         channel.sendCtcpReply.connect(self.__sendCtcpReply)
         channel.channelClosed.connect(self.__closeChannel)
+        channel.awayCommand.connect(self.networkWidget.handleAwayCommand)
+        channel.leaveChannels.connect(self.__leaveChannels)
+        channel.leaveAllChannels.connect(self.__leaveAllChannels)
         
         self.channelsWidget.addTab(channel, name)
         self.__channelList.append(channel)
@@ -386,6 +405,29 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         channel = self.channelsWidget.currentWidget()
         channel.requestLeave()
     
+    @pyqtSlot(list)
+    def __leaveChannels(self, channelNames):
+        """
+        Private slot to leave a list of channels and close their associated
+        tabs.
+        
+        @param channelNames list of channels to leave
+        @type list of str
+        """
+        for channelName in channelNames:
+            for channel in self.__channelList:
+                if channel.name() == channelName:
+                    channel.leaveChannel()
+    
+    @pyqtSlot()
+    def __leaveAllChannels(self):
+        """
+        Private slot to leave all channels and close their tabs.
+        """
+        while self.__channelList:
+            channel = self.__channelList[0]
+            channel.leaveChannel()
+    
     def __closeAllChannels(self):
         """
         Private method to close all channels.
@@ -441,12 +483,33 @@ class IrcWidget(QWidget, Ui_IrcWidget):
             self.__socket.write(
                 QByteArray("{0}\r\n".format(data).encode("utf-8")))
     
+    def __sendCtcpRequest(self, receiver, request, arguments):
+        """
+        Private slot to send a CTCP request.
+        
+        @param receiver nick name of the receiver
+        @type str
+        @param request CTCP request to be sent
+        @type str
+        @param arguments arguments to be sent
+        @type str
+        """
+        request = request.upper()
+        if request == "PING":
+            arguments = "Eric IRC {0}".format(
+                QDateTime.currentMSecsSinceEpoch())
+            
+        self.__send("PRIVMSG {0} :\x01{1} {2}\x01".format(
+            receiver, request, arguments))
+    
     def __sendCtcpReply(self, receiver, text):
         """
         Private slot to send a CTCP reply.
         
-        @param receiver nick name of the receiver (string)
-        @param text text to be sent (string)
+        @param receiver nick name of the receiver
+        @type str
+        @param text text to be sent
+        @type str
         """
         self.__send("NOTICE {0} :\x01{1}\x01".format(receiver, text))
     
@@ -472,24 +535,26 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         serverPassword = self.__server.getPassword()
         if serverPassword:
             self.__send("PASS " + serverPassword)
+        
+        identity = self.__ircNetworkManager.getIdentity(
+            self.__identityName)
         nick = self.networkWidget.getNickname()
-        if not nick:
+        if not nick and identity:
             self.__nickIndex = 0
             try:
-                nick = self.__ircNetworkManager.getIdentity(
-                    self.__identityName).getNickNames()[self.__nickIndex]
+                nick = identity.getNickNames()[self.__nickIndex]
             except IndexError:
                 nick = ""
         if not nick:
             nick = self.__userName
         self.__nickName = nick
         self.networkWidget.setNickName(nick)
-        realName = self.__ircNetworkManager.getIdentity(
-            self.__identityName).getRealName()
-        if not realName:
-            realName = "eric IDE chat"
-        self.__send("NICK " + nick)
-        self.__send("USER " + self.__userName + " 0 * :" + realName)
+        if identity:
+            realName = identity.getRealName()
+            if not realName:
+                realName = "eric IDE chat"
+            self.__send("NICK " + nick)
+            self.__send("USER " + self.__userName + " 0 * :" + realName)
     
     def __hostDisconnected(self):
         """
@@ -507,7 +572,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
             self.__nickIndex = -1
             self.__channelTypePrefixes = ""
             
-            self.__socket.deleteLater()
+            if self.__socket:
+                self.__socket.deleteLater()
             self.__socket = None
             
             self.__connectionState = IrcWidget.ServerDisconnected
@@ -526,7 +592,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                 for line in self.__buffer.splitlines():
                     line = line.strip()
                     if line:
-                        logging.debug("<IRC> " + line)
+                        logging.debug("<IRC> %s", line)
                         handled = False
                         # step 1: give channels a chance to handle the message
                         for channel in self.__channelList:
@@ -551,6 +617,42 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                 self.__updateUsersCount()
                 self.__buffer = ""
     
+    def __handleCtcpReply(self, match):
+        """
+        Private method to handle a server message containing a CTCP reply.
+        
+        @param match reference to the match object
+        """
+        if "!" in match.group(1):
+            sender = match.group(1).split("!", 1)[0]
+            
+            try:
+                ctcpCommand = match.group(3).split(":", 1)[1]
+            except IndexError:
+                ctcpCommand = match.group(3)
+            ctcpCommand = ctcpCommand[1:].split("\x01", 1)[0]
+            if " " in ctcpCommand:
+                ctcpReply, ctcpArg = ctcpCommand.split(" ", 1)
+            else:
+                ctcpReply, ctcpArg = ctcpCommand, ""
+            ctcpReply = ctcpReply.upper()
+            
+            if ctcpReply == "PING" and ctcpArg.startswith("Eric IRC "):
+                # it is a response to a ping request
+                pingDateTime = int(ctcpArg.split()[-1])
+                latency = QDateTime.currentMSecsSinceEpoch() - pingDateTime
+                self.networkWidget.addServerMessage(
+                    self.tr("CTCP"),
+                    self.tr(
+                        "Received CTCP-PING response from {0} with latency"
+                        " of {1} ms.").format(sender, latency))
+            else:
+                self.networkWidget.addServerMessage(
+                    self.tr("CTCP"),
+                    self.tr(
+                        "Received unknown CTCP-{0} response from {1}.")
+                    .format(ctcpReply, sender))
+    
     def __handleNamedMessage(self, match):
         """
         Private method to handle a server message containing a message name.
@@ -564,6 +666,11 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                 msg = match.group(3).split(":", 1)[1]
             except IndexError:
                 msg = match.group(3)
+            
+            if msg.startswith("\x01"):
+                self.__handleCtcpReply(match)
+                return True
+            
             if "!" in match.group(1):
                 name = match.group(1).split("!", 1)[0]
                 msg = "-{0}- {1}".format(name, msg)
@@ -612,6 +719,11 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                     self.tr("User {0} is now known as {1}.").format(
                         oldNick, newNick))
             return True
+        elif name == "PONG":
+            nick = match.group(3).split(":", 1)[1]
+            self.networkWidget.addMessage(
+                self.tr("Received PONG from {0}").format(nick))
+            return True
         elif name == "ERROR":
             self.networkWidget.addErrorMessage(
                 self.tr("Server Error"), match.group(3).split(":", 1)[1])
@@ -685,8 +797,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
             parts = message.strip().split()
             message = self.tr(
                 "Server {0} (Version {1}), User-Modes: {2},"
-                " Channel-Modes: {3}")\
-                .format(parts[1], parts[2], parts[3], parts[4])
+                " Channel-Modes: {3}"
+            ).format(parts[1], parts[2], parts[3], parts[4])
         elif code == 265:
             parts = message.strip().split()
             message = self.tr(
@@ -735,10 +847,11 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private method to register to services.
         """
         identity = self.__ircNetworkManager.getIdentity(self.__identityName)
-        service = identity.getServiceName()
-        password = identity.getPassword()
-        if service and password:
-            self.__send("PRIVMSG " + service + " :identify " + password)
+        if identity:
+            service = identity.getServiceName()
+            password = identity.getPassword()
+            if service and password:
+                self.__send("PRIVMSG " + service + " :identify " + password)
     
     def __autoJoinChannels(self):
         """
@@ -749,7 +862,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
             if channel.autoJoin():
                 name = channel.getName()
                 key = channel.getKey()
-                self.__joinChannel(name, key)
+                self.joinChannel(name, key)
     
     def __tcpError(self, error):
         """
@@ -926,9 +1039,16 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         self.__nickIndex += 1
         try:
-            nick = self.__ircNetworkManager.getIdentity(self.__identityName)\
-                .getNickNames()[self.__nickIndex]
-            self.__nickName = nick
+            identity = self.__ircNetworkManager.getIdentity(
+                self.__identityName)
+            if identity:
+                nick = identity.getNickNames()[self.__nickIndex]
+                self.__nickName = nick
+            else:
+                self.__connectNetwork("", False, True)
+                self.__nickName = ""
+                self.__nickIndex = -1
+                return
         except IndexError:
             self.networkWidget.addServerMessage(
                 self.tr("Critical"),
@@ -994,6 +1114,6 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         if isAway and self.__identityName:
             identity = self.__ircNetworkManager.getIdentity(
                 self.__identityName)
-            if identity.rememberAwayPosition():
+            if identity and identity.rememberAwayPosition():
                 for channel in self.__channelList:
                     channel.setMarkerLine()
