@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Plugin installation dialog.
 """
 
-from __future__ import unicode_literals
 
 import os
 import sys
@@ -21,8 +20,10 @@ except (ImportError):
     import urlparse as parse    # __IGNORE_WARNING__
 
 from PyQt5.QtCore import pyqtSlot, Qt, QDir, QFileInfo
-from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QAbstractButton, \
-    QApplication, QDialog, QVBoxLayout
+from PyQt5.QtWidgets import (
+    QWidget, QDialogButtonBox, QAbstractButton, QApplication, QDialog,
+    QVBoxLayout
+)
 
 from E5Gui import E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
@@ -143,12 +144,14 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             self.__cancelButton.show()
             
             msg = self.tr(
-                "Plugin ZIP-Archives:\n{0}\n\nDestination:\n{1} ({2})")\
-                .format("\n".join(self.__createArchivesList()),
-                        self.destinationCombo.currentText(),
-                        self.destinationCombo.itemData(
-                            self.destinationCombo.currentIndex())
-                        )
+                "Plugin ZIP-Archives:\n{0}\n\nDestination:\n{1} ({2})"
+            ).format(
+                "\n".join(self.__createArchivesList()),
+                self.destinationCombo.currentText(),
+                self.destinationCombo.itemData(
+                    self.destinationCombo.currentIndex()
+                )
+            )
             self.summaryEdit.setPlainText(msg)
     
     @pyqtSlot()
@@ -269,27 +272,33 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
 
         # check, if the archive exists
         if not os.path.exists(archive):
-            return False, \
+            return (
+                False,
                 self.tr(
                     """<p>The archive file <b>{0}</b> does not exist. """
-                    """Aborting...</p>""").format(archive), \
+                    """Aborting...</p>""").format(archive),
                 False
+            )
         
         # check, if the archive is a valid zip file
         if not zipfile.is_zipfile(archive):
-            return False, \
+            return (
+                False,
                 self.tr(
                     """<p>The file <b>{0}</b> is not a valid plugin """
-                    """ZIP-archive. Aborting...</p>""").format(archive), \
+                    """ZIP-archive. Aborting...</p>""").format(archive),
                 False
+            )
         
         # check, if the destination is writeable
         if not os.access(destination, os.W_OK):
-            return False, \
+            return (
+                False,
                 self.tr(
                     """<p>The destination directory <b>{0}</b> is not """
-                    """writeable. Aborting...</p>""").format(destination), \
+                    """writeable. Aborting...</p>""").format(destination),
                 False
+            )
         
         zipFile = zipfile.ZipFile(archive, "r")
         
@@ -304,11 +313,13 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                 break
         
         if not pluginFound:
-            return False, \
+            return (
+                False,
                 self.tr(
                     """<p>The file <b>{0}</b> is not a valid plugin """
-                    """ZIP-archive. Aborting...</p>""").format(archive), \
+                    """ZIP-archive. Aborting...</p>""").format(archive),
                 False
+            )
         
         # parse the plugin module's plugin header
         pluginSource = Utilities.decode(zipFile.read(pluginFileName))[0]
@@ -320,8 +331,10 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         for line in pluginSource.splitlines():
             if line.startswith("packageName"):
                 tokens = line.split("=")
-                if tokens[0].strip() == "packageName" and \
-                   tokens[1].strip()[1:-1] != "__core__":
+                if (
+                    tokens[0].strip() == "packageName" and
+                    tokens[1].strip()[1:-1] != "__core__"
+                ):
                     if tokens[1].strip()[0] in ['"', "'"]:
                         packageName = tokens[1].strip()[1:-1]
                     else:
@@ -349,54 +362,69 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                 break
         
         if not packageName:
-            return False, \
+            return (
+                False,
                 self.tr(
                     """<p>The plugin module <b>{0}</b> does not contain """
-                    """a 'packageName' attribute. Aborting...</p>""")\
-                .format(pluginFileName), \
+                    """a 'packageName' attribute. Aborting...</p>"""
+                ).format(pluginFileName),
                 False
+            )
         
         if pyqtApi < 2:
-            return False, \
+            return (
+                False,
                 self.tr(
                     """<p>The plugin module <b>{0}</b> does not conform"""
-                    """ with the PyQt v2 API. Aborting...</p>""")\
-                .format(pluginFileName), \
+                    """ with the PyQt v2 API. Aborting...</p>"""
+                ).format(pluginFileName),
                 False
+            )
         
         # check, if it is a plugin, that collides with others
-        if not os.path.exists(os.path.join(destination, pluginFileName)) and \
-           packageName != "None" and \
-           os.path.exists(os.path.join(destination, packageName)):
-            return False, \
+        if (
+            not os.path.exists(os.path.join(destination, pluginFileName)) and
+            packageName != "None" and
+            os.path.exists(os.path.join(destination, packageName))
+        ):
+            return (
+                False,
                 self.tr("""<p>The plugin package <b>{0}</b> exists. """
-                        """Aborting...</p>""")\
-                    .format(os.path.join(destination, packageName)), \
+                        """Aborting...</p>""").format(
+                    os.path.join(destination, packageName)),
                 False
+            )
         
-        if os.path.exists(os.path.join(destination, pluginFileName)) and \
-           packageName != "None" and \
-           not os.path.exists(os.path.join(destination, packageName)):
-            return False, \
+        if (
+            os.path.exists(os.path.join(destination, pluginFileName)) and
+            packageName != "None" and
+            not os.path.exists(os.path.join(destination, packageName))
+        ):
+            return (
+                False,
                 self.tr("""<p>The plugin module <b>{0}</b> exists. """
-                        """Aborting...</p>""")\
-                    .format(os.path.join(destination, pluginFileName)), \
+                        """Aborting...</p>""").format(
+                    os.path.join(destination, pluginFileName)),
                 False
+            )
         
         activatePlugin = False
         if not self.__external:
-            activatePlugin = \
+            activatePlugin = (
                 not self.__pluginManager.isPluginLoaded(
-                    installedPluginName) or \
+                    installedPluginName) or
                 (self.__pluginManager.isPluginLoaded(installedPluginName) and
                  self.__pluginManager.isPluginActive(installedPluginName))
+            )
             # try to unload a plugin with the same name
             self.__pluginManager.unloadPlugin(installedPluginName)
         
         # uninstall existing plug-in first to get clean conditions
-        if packageName != "None" and \
+        if (
+            packageName != "None" and
             not os.path.exists(
-                os.path.join(destination, packageName, "__init__.py")):
+                os.path.join(destination, packageName, "__init__.py"))
+        ):
             # package directory contains just data, don't delete it
             self.__uninstallPackage(destination, pluginFileName, "")
         else:
@@ -420,9 +448,11 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                     self.progress.setValue(prog)
                     QApplication.processEvents()
                     prog += 1
-                    if name == pluginFileName or \
-                       name.startswith("{0}/".format(packageName)) or \
-                       name.startswith("{0}\\".format(packageName)):
+                    if (
+                        name == pluginFileName or
+                        name.startswith("{0}/".format(packageName)) or
+                        name.startswith("{0}\\".format(packageName))
+                    ):
                         outname = name.replace("/", os.sep)
                         outname = os.path.join(destination, outname)
                         if outname.endswith("/") or outname.endswith("\\"):
@@ -450,36 +480,41 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                 self.__installedFiles.append(outname)
         except os.error as why:
             self.__rollback()
-            return False, \
+            return (
+                False,
                 self.tr(
-                    "Error installing plugin. Reason: {0}").format(str(why)), \
+                    "Error installing plugin. Reason: {0}").format(str(why)),
                 False
+            )
         except IOError as why:
             self.__rollback()
-            return False, \
+            return (
+                False,
                 self.tr(
-                    "Error installing plugin. Reason: {0}").format(str(why)), \
+                    "Error installing plugin. Reason: {0}").format(str(why)),
                 False
+            )
         except OSError as why:
             self.__rollback()
-            return False, \
+            return (
+                False,
                 self.tr(
-                    "Error installing plugin. Reason: {0}").format(str(why)), \
+                    "Error installing plugin. Reason: {0}").format(str(why)),
                 False
+            )
         except Exception:
             sys.stderr.write("Unspecific exception installing plugin.\n")
             self.__rollback()
-            return False, \
-                self.tr("Unspecific exception installing plugin."), \
+            return (
+                False,
+                self.tr("Unspecific exception installing plugin."),
                 False
+            )
         
         # now compile the plugins
         if doCompile:
             dirName = os.path.join(destination, packageName)
             files = os.path.join(destination, pluginFileName)
-            if sys.version_info[0] == 2:
-                dirName = dirName.encode(sys.getfilesystemencoding())
-                files = files.encode(sys.getfilesystemencoding())
             os.path.join_unicode = False
             compileall.compile_dir(dirName, quiet=True)
             compileall.compile_file(files, quiet=True)
