@@ -7,18 +7,18 @@
 Module implementing the Plugin Manager.
 """
 
-from __future__ import unicode_literals, print_function
-
 import os
 import sys
 import imp
 import zipfile
 
-from PyQt5.QtCore import pyqtSignal, QObject, QDate, QFile, QFileInfo, QUrl, \
-    QIODevice
+from PyQt5.QtCore import (
+    pyqtSignal, QObject, QDate, QFile, QFileInfo, QUrl, QIODevice
+)
 from PyQt5.QtGui import QPixmap
-from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
-    QNetworkReply
+from PyQt5.QtNetwork import (
+    QNetworkAccessManager, QNetworkRequest, QNetworkReply
+)
 
 from E5Gui import E5MessageBox
 from E5Gui.E5Application import e5App
@@ -30,9 +30,10 @@ try:
 except ImportError:
     SSL_AVAILABLE = False
 
-from .PluginExceptions import PluginPathError, PluginModulesError, \
-    PluginLoadError, PluginActivationError, PluginModuleFormatError, \
-    PluginClassFormatError, PluginPy2IncompatibleError
+from .PluginExceptions import (
+    PluginPathError, PluginModulesError, PluginLoadError,
+    PluginActivationError, PluginModuleFormatError, PluginClassFormatError
+)
 
 import UI.PixmapCache
 
@@ -146,8 +147,8 @@ class PluginManager(QObject):
         
         self.__checkPluginsDownloadDirectory()
         
-        self.pluginRepositoryFile = \
-            os.path.join(Utilities.getConfigDir(), "PluginRepository")
+        self.pluginRepositoryFile = os.path.join(Utilities.getConfigDir(),
+                                                 "PluginRepository")
         
         # attributes for the network objects
         self.__networkManager = QNetworkAccessManager(self)
@@ -168,8 +169,10 @@ class PluginManager(QObject):
         """
         Public method to finalize the setup of the plugin manager.
         """
-        for module in list(self.__onDemandInactiveModules.values()) + \
-                list(self.__onDemandActiveModules.values()):
+        for module in (
+            list(self.__onDemandInactiveModules.values()) +
+            list(self.__onDemandActiveModules.values())
+        ):
             if hasattr(module, "moduleSetup"):
                 module.moduleSetup()
         
@@ -220,8 +223,10 @@ class PluginManager(QObject):
             except IOError:
                 del self.pluginDirs["user"]
         
-        if not os.path.exists(self.pluginDirs["global"]) and \
-           os.access(Utilities.getPythonModulesDirectory(), os.W_OK):
+        if (
+            not os.path.exists(self.pluginDirs["global"]) and
+            os.access(Utilities.getPythonModulesDirectory(), os.W_OK)
+        ):
             # create the global plugins directory
             os.mkdir(self.pluginDirs["global"], 0o755)
             fname = os.path.join(self.pluginDirs["global"], "__init__.py")
@@ -250,19 +255,21 @@ class PluginManager(QObject):
         
         @return flag indicating the availability of plugins (boolean)
         """
-        if self.__develPluginFile and \
-                not os.path.exists(self.__develPluginFile):
+        if (
+            self.__develPluginFile and
+            not os.path.exists(self.__develPluginFile)
+        ):
             return False
         
         self.__foundCoreModules = self.getPluginModules(
             self.pluginDirs["eric6"])
         if Preferences.getPluginManager("ActivateExternal"):
             if "global" in self.pluginDirs:
-                self.__foundGlobalModules = \
-                    self.getPluginModules(self.pluginDirs["global"])
+                self.__foundGlobalModules = self.getPluginModules(
+                    self.pluginDirs["global"])
             if "user" in self.pluginDirs:
-                self.__foundUserModules = \
-                    self.getPluginModules(self.pluginDirs["user"])
+                self.__foundUserModules = self.getPluginModules(
+                    self.pluginDirs["user"])
         
         return len(self.__foundCoreModules + self.__foundGlobalModules +
                    self.__foundUserModules) > 0
@@ -311,22 +318,26 @@ class PluginManager(QObject):
         """
         develPluginName = ""
         if self.__develPluginFile:
-            develPluginPath, develPluginName = \
-                Utilities.splitPath(self.__develPluginFile)
+            develPluginPath, develPluginName = Utilities.splitPath(
+                self.__develPluginFile)
             if self.isValidPluginName(develPluginName):
                 develPluginName = develPluginName[:-3]
         
         for pluginName in self.__foundGlobalModules:
             # user and core plug-ins have priority
-            if pluginName not in self.__foundUserModules and \
-               pluginName not in self.__foundCoreModules and \
-               pluginName != develPluginName:
+            if (
+                pluginName not in self.__foundUserModules and
+                pluginName not in self.__foundCoreModules and
+                pluginName != develPluginName
+            ):
                 self.loadPlugin(pluginName, self.pluginDirs["global"])
         
         for pluginName in self.__foundUserModules:
             # core plug-ins have priority
-            if pluginName not in self.__foundCoreModules and \
-               pluginName != develPluginName:
+            if (
+                pluginName not in self.__foundCoreModules and
+                pluginName != develPluginName
+            ):
                 self.loadPlugin(pluginName, self.pluginDirs["user"])
         
         for pluginName in self.__foundCoreModules:
@@ -352,15 +363,19 @@ class PluginManager(QObject):
         
         for pluginName in self.__foundGlobalModules:
             # user and core plug-ins have priority
-            if pluginName not in self.__foundUserModules and \
-               pluginName not in self.__foundCoreModules and \
-               pluginName.startswith("PluginDocumentationSets"):
+            if (
+                pluginName not in self.__foundUserModules and
+                pluginName not in self.__foundCoreModules and
+                pluginName.startswith("PluginDocumentationSets")
+            ):
                 self.loadPlugin(pluginName, self.pluginDirs["global"])
         
         for pluginName in self.__foundUserModules:
             # core plug-ins have priority
-            if pluginName not in self.__foundCoreModules and \
-               pluginName.startswith("PluginDocumentationSets"):
+            if (
+                pluginName not in self.__foundCoreModules and
+                pluginName.startswith("PluginDocumentationSets")
+            ):
                 self.loadPlugin(pluginName, self.pluginDirs["user"])
         
         for pluginName in self.__foundCoreModules:
@@ -382,8 +397,6 @@ class PluginManager(QObject):
         @param reload_ flag indicating to reload the module (boolean)
         @exception PluginLoadError raised to indicate an issue loading
             the plug-in
-        @exception PluginPy2IncompatibleError raised to indicate the Python 2
-            incompatibility of a plug-in
         """
         try:
             fname = "{0}.py".format(os.path.join(directory, name))
@@ -393,29 +406,17 @@ class PluginManager(QObject):
                     "Module is missing the 'autoactivate' attribute.")
                 self.__failedModules[name] = module
                 raise PluginLoadError(name)
-            if sys.version_info[0] < 3:
-                if not hasattr(module, "python2Compatible"):
-                    module.error = self.tr(
-                        "Module is missing the Python2 compatibility flag."
-                        " Please update.")
-                    compatible = False
-                elif not getattr(module, "python2Compatible"):
-                    module.error = self.tr(
-                        "Module is not Python2 compatible.")
-                    compatible = False
-                else:
-                    compatible = True
-                if not compatible:
-                    self.__failedModules[name] = module
-                    raise PluginPy2IncompatibleError(name)
-            if getattr(module, "autoactivate"):
+            if getattr(module, "autoactivate", False):
                 self.__inactiveModules[name] = module
             else:
-                if not hasattr(module, "pluginType") or \
-                   not hasattr(module, "pluginTypename"):
-                    module.error = \
-                        self.tr("Module is missing the 'pluginType' "
-                                "and/or 'pluginTypename' attributes.")
+                if (
+                    not hasattr(module, "pluginType") or
+                    not hasattr(module, "pluginTypename")
+                ):
+                    module.error = self.tr(
+                        "Module is missing the 'pluginType' "
+                        "and/or 'pluginTypename' attributes."
+                    )
                     self.__failedModules[name] = module
                     raise PluginLoadError(name)
                 else:
@@ -434,9 +435,6 @@ class PluginManager(QObject):
                     pass
         except PluginLoadError:
             print("Error loading plug-in module:", name)
-        except PluginPy2IncompatibleError:
-            print("Error loading plug-in module:", name)
-            print("The plug-in is not Python2 compatible.")
         except Exception as err:
             module = imp.new_module(name)
             module.error = self.tr(
@@ -504,8 +502,10 @@ class PluginManager(QObject):
         if not package:
             package = "__None__"
         for moduleName in list(sys.modules.keys())[:]:
-            if moduleName == pluginName or \
-                    moduleName.split(".")[0] in packages:
+            if (
+                moduleName == pluginName or
+                moduleName.split(".")[0] in packages
+            ):
                 found = True
                 del sys.modules[moduleName]
         return found
@@ -538,8 +538,8 @@ class PluginManager(QObject):
             
             if not self.__canActivatePlugin(module):
                 raise PluginActivationError(module.eric6PluginModuleName)
-            version = getattr(module, "version")
-            className = getattr(module, "className")
+            version = getattr(module, "version", "0.0.0")
+            className = getattr(module, "className", "")
             pluginClass = getattr(module, className)
             pluginObject = None
             if name not in self.__onDemandInactivePlugins:
@@ -577,8 +577,10 @@ class PluginManager(QObject):
         if savedInactiveList is not None:
             inactiveList += [p for p in savedInactiveList
                              if p not in self.__disabledPlugins]
-        if self.__develPluginName is not None and \
-           self.__develPluginName in inactiveList:
+        if (
+            self.__develPluginName is not None and
+            self.__develPluginName in inactiveList
+        ):
             inactiveList.remove(self.__develPluginName)
         names = sorted(self.__inactiveModules.keys())
         for name in names:
@@ -608,8 +610,8 @@ class PluginManager(QObject):
             
             if not self.__canActivatePlugin(module):
                 raise PluginActivationError(module.eric6PluginModuleName)
-            version = getattr(module, "version")
-            className = getattr(module, "className")
+            version = getattr(module, "version", "0.0.0")
+            className = getattr(module, "className", "")
             pluginClass = getattr(module, className)
             pluginObject = None
             if onDemand and name in self.__onDemandInactivePlugins:
@@ -677,8 +679,8 @@ class PluginManager(QObject):
             if not hasattr(module, "className"):
                 raise PluginModuleFormatError(
                     module.eric6PluginModuleName, "className")
-            className = getattr(module, "className")
-            if not hasattr(module, className):
+            className = getattr(module, "className", "")
+            if not className or not hasattr(module, className):
                 raise PluginModuleFormatError(
                     module.eric6PluginModuleName, className)
             pluginClass = getattr(module, className)
@@ -765,14 +767,18 @@ class PluginManager(QObject):
         @return reference to the initialized plugin object
         """
         for name, module in list(self.__onDemandInactiveModules.items()):
-            if getattr(module, "pluginType") == type_ and \
-               getattr(module, "pluginTypename") == typename:
+            if (
+                getattr(module, "pluginType", "") == type_ and
+                getattr(module, "pluginTypename", "") == typename
+            ):
                 return self.activatePlugin(name, onDemand=True)
         
         if maybeActive:
             for name, module in list(self.__onDemandActiveModules.items()):
-                if getattr(module, "pluginType") == type_ and \
-                   getattr(module, "pluginTypename") == typename:
+                if (
+                    getattr(module, "pluginType", "") == type_ and
+                    getattr(module, "pluginTypename", "") == typename
+                ):
                     self.deactivatePlugin(name, onDemand=True)
                     return self.activatePlugin(name, onDemand=True)
         
@@ -928,20 +934,25 @@ class PluginManager(QObject):
         """
         pluginDict = {}
         
-        for module in list(self.__onDemandActiveModules.values()) + \
-                list(self.__onDemandInactiveModules.values()):
-            if getattr(module, "pluginType") == type_ and \
-               getattr(module, "error", "") == "":
-                plugin_name = getattr(module, "pluginTypename")
-                if hasattr(module, "displayString"):
-                    try:
-                        disp = module.displayString()
-                    except TypeError:
-                        disp = getattr(module, "displayString")
-                    if disp != "":
-                        pluginDict[plugin_name] = disp
-                else:
-                    pluginDict[plugin_name] = plugin_name
+        for module in (
+            list(self.__onDemandActiveModules.values()) +
+            list(self.__onDemandInactiveModules.values())
+        ):
+            if (
+                getattr(module, "pluginType", "") == type_ and
+                getattr(module, "error", "") == ""
+            ):
+                plugin_name = getattr(module, "pluginTypename", "")
+                if plugin_name:
+                    if hasattr(module, "displayString"):
+                        try:
+                            disp = module.displayString()
+                        except TypeError:
+                            disp = getattr(module, "displayString", "")
+                        if disp != "":
+                            pluginDict[plugin_name] = disp
+                    else:
+                        pluginDict[plugin_name] = plugin_name
         
         return pluginDict
         
@@ -953,10 +964,14 @@ class PluginManager(QObject):
         @param name name of the plugin type (string)
         @return preview pixmap (QPixmap)
         """
-        for module in list(self.__onDemandActiveModules.values()) + \
-                list(self.__onDemandInactiveModules.values()):
-            if getattr(module, "pluginType") == type_ and \
-               getattr(module, "pluginTypename") == name:
+        for module in (
+            list(self.__onDemandActiveModules.values()) +
+            list(self.__onDemandInactiveModules.values())
+        ):
+            if (
+                getattr(module, "pluginType", "") == type_ and
+                getattr(module, "pluginTypename", "") == name
+            ):
                 if hasattr(module, "previewPix"):
                     return module.previewPix()
                 else:
@@ -973,8 +988,10 @@ class PluginManager(QObject):
         """
         apis = []
         
-        for module in list(self.__activeModules.values()) + \
-                list(self.__onDemandActiveModules.values()):
+        for module in (
+            list(self.__activeModules.values()) +
+            list(self.__onDemandActiveModules.values())
+        ):
             if hasattr(module, "apiFiles"):
                 apis.extend(module.apiFiles(language))
         
@@ -990,8 +1007,10 @@ class PluginManager(QObject):
         @rtype dict (key: str, value: list of str)
         """
         helpFiles = {}
-        for module in list(self.__activeModules.values()) + \
-                list(self.__onDemandActiveModules.values()):
+        for module in (
+            list(self.__activeModules.values()) +
+            list(self.__onDemandActiveModules.values())
+        ):
             if hasattr(module, "helpFiles"):
                 helpFiles.update(module.helpFiles())
         
@@ -1033,14 +1052,18 @@ class PluginManager(QObject):
         """
         infos = []
         
-        for module in list(self.__activeModules.values()) + \
-                list(self.__inactiveModules.values()):
+        for module in (
+            list(self.__activeModules.values()) +
+            list(self.__inactiveModules.values())
+        ):
             if hasattr(module, "exeDisplayDataList"):
                 infos.extend(module.exeDisplayDataList())
             elif hasattr(module, "exeDisplayData"):
                 infos.append(module.exeDisplayData())
-        for module in list(self.__onDemandActiveModules.values()) + \
-                list(self.__onDemandInactiveModules.values()):
+        for module in (
+            list(self.__onDemandActiveModules.values()) +
+            list(self.__onDemandInactiveModules.values())
+        ):
             if hasattr(module, "exeDisplayDataList"):
                 infos.extend(module.exeDisplayDataList())
             elif hasattr(module, "exeDisplayData"):
@@ -1081,9 +1104,11 @@ class PluginManager(QObject):
         @return plug-in configuration data
         """
         configData = {}
-        for module in list(self.__activeModules.values()) + \
-            list(self.__onDemandActiveModules.values()) + \
-                list(self.__onDemandInactiveModules.values()):
+        for module in (
+            list(self.__activeModules.values()) +
+            list(self.__onDemandActiveModules.values()) +
+                list(self.__onDemandInactiveModules.values())
+        ):
             if hasattr(module, 'getConfigData'):
                 configData.update(module.getConfigData())
         return configData
@@ -1095,10 +1120,12 @@ class PluginManager(QObject):
         @param pluginName name of the plugin to check for (string)
         @return flag indicating, if the plugin is loaded (boolean)
         """
-        return pluginName in self.__activeModules or \
-            pluginName in self.__inactiveModules or \
-            pluginName in self.__onDemandActiveModules or \
+        return (
+            pluginName in self.__activeModules or
+            pluginName in self.__inactiveModules or
+            pluginName in self.__onDemandActiveModules or
             pluginName in self.__onDemandInactiveModules
+        )
         
     def isPluginActive(self, pluginName):
         """
@@ -1107,8 +1134,10 @@ class PluginManager(QObject):
         @param pluginName name of the plugin to check for (string)
         @return flag indicating, if the plugin is active (boolean)
         """
-        return pluginName in self.__activeModules or \
+        return (
+            pluginName in self.__activeModules or
             pluginName in self.__onDemandActiveModules
+        )
     
     ###########################################################################
     ## Specialized plug-in module handling methods below
@@ -1132,9 +1161,11 @@ class PluginManager(QObject):
         """
         vcsDict = {}
         
-        for module in list(self.__onDemandActiveModules.values()) + \
-                list(self.__onDemandInactiveModules.values()):
-            if getattr(module, "pluginType") == "version_control":
+        for module in (
+            list(self.__onDemandActiveModules.values()) +
+            list(self.__onDemandInactiveModules.values())
+        ):
+            if getattr(module, "pluginType", "") == "version_control":
                 if hasattr(module, "getVcsSystemIndicator"):
                     res = module.getVcsSystemIndicator()
                     for indicator, vcsData in list(res.items()):
@@ -1150,7 +1181,7 @@ class PluginManager(QObject):
         Public method to deactivated all activated VCS plugins.
         """
         for name, module in list(self.__onDemandActiveModules.items()):
-            if getattr(module, "pluginType") == "version_control":
+            if getattr(module, "pluginType", "") == "version_control":
                 self.deactivatePlugin(name, True)
     
     ########################################################################
@@ -1227,9 +1258,11 @@ class PluginManager(QObject):
                 elif period == 2 and lastModifiedDate.daysTo(now) < 7:
                     # weekly
                     return
-                elif period == 3 and \
+                elif (
+                    period == 3 and
                     (lastModifiedDate.daysTo(now) <
-                     lastModifiedDate.daysInMonth()):
+                     lastModifiedDate.daysInMonth())
+                ):
                     # monthly
                     return
         
@@ -1392,11 +1425,12 @@ class PluginManager(QObject):
         
         @param type_ type of the plugin to clear private data for (string)
         """
-        for module in \
-            list(self.__onDemandActiveModules.values()) + \
-            list(self.__onDemandInactiveModules.values()) + \
-            list(self.__activeModules.values()) + \
-                list(self.__inactiveModules.values()):
+        for module in (
+            list(self.__onDemandActiveModules.values()) +
+            list(self.__onDemandInactiveModules.values()) +
+            list(self.__activeModules.values()) +
+            list(self.__inactiveModules.values())
+        ):
             if getattr(module, "pluginType", "") == type_:
                 if hasattr(module, "clearPrivateData"):
                     module.clearPrivateData()
