@@ -8,7 +8,6 @@
 Module implementing a dialog showing the available plugins.
 """
 
-from __future__ import unicode_literals
 
 import sys
 import os
@@ -16,12 +15,18 @@ import zipfile
 import glob
 import re
 
-from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QFile, QIODevice, QUrl, \
-    QProcess, QPoint, QCoreApplication
-from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QAbstractButton, \
-    QTreeWidgetItem, QDialog, QVBoxLayout, QMenu
-from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
-    QNetworkReply, QNetworkConfigurationManager
+from PyQt5.QtCore import (
+    pyqtSignal, pyqtSlot, Qt, QFile, QIODevice, QUrl, QProcess, QPoint,
+    QCoreApplication
+)
+from PyQt5.QtWidgets import (
+    QWidget, QDialogButtonBox, QAbstractButton, QTreeWidgetItem, QDialog,
+    QVBoxLayout, QMenu
+)
+from PyQt5.QtNetwork import (
+    QNetworkAccessManager, QNetworkRequest, QNetworkReply,
+    QNetworkConfigurationManager
+)
 
 from .Ui_PluginRepositoryDialog import Ui_PluginRepositoryDialog
 
@@ -97,11 +102,12 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__downloadInstallButton.setEnabled(False)
         self.__downloadCancelButton = self.buttonBox.addButton(
             self.tr("Cancel"), QDialogButtonBox.ActionRole)
-        self.__installButton = \
-            self.buttonBox.addButton(self.tr("Close && Install"),
-                                     QDialogButtonBox.ActionRole)
         self.__downloadCancelButton.setEnabled(False)
+        self.__installButton = self.buttonBox.addButton(
+            self.tr("Close && Install"), QDialogButtonBox.ActionRole)
         self.__installButton.setEnabled(False)
+        self.__closeButton = self.buttonBox.button(QDialogButtonBox.Close)
+        self.__closeButton.setEnabled(True)
         
         self.repositoryUrlEdit.setText(
             Preferences.getUI("PluginRepositoryUrl6"))
@@ -122,8 +128,8 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__pluginContextMenu.addAction(
             self.tr("Cleanup Downloads"), self.__cleanupDownloads)
         
-        self.pluginRepositoryFile = \
-            os.path.join(Utilities.getConfigDir(), "PluginRepository")
+        self.pluginRepositoryFile = os.path.join(Utilities.getConfigDir(),
+                                                 "PluginRepository")
         
         # attributes for the network objects
         self.__networkManager = QNetworkAccessManager(self)
@@ -135,8 +141,9 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__replies = []
         
         if Preferences.getUI("DynamicOnlineCheck"):
-            self.__networkConfigurationManager = \
+            self.__networkConfigurationManager = (
                 QNetworkConfigurationManager(self)
+            )
             self.__onlineStateChanged(
                 self.__networkConfigurationManager.isOnline())
             self.__networkConfigurationManager.onlineStateChanged.connect(
@@ -227,6 +234,21 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         # join lines by a blank
         return ' '.join(newlines)
     
+    def __changeScheme(self, url, newScheme=""):
+        """
+        Private method to change the scheme of the given URL.
+        
+        @param url URL to be modified
+        @type str
+        @param newScheme scheme to be set for the given URL
+        @return modified URL
+        @rtype str
+        """
+        if not newScheme:
+            newScheme = self.repositoryUrlEdit.text().split("//", 1)[0]
+        
+        return newScheme + "//" + url.split("//", 1)[1]
+    
     @pyqtSlot(QPoint)
     def on_repositoryList_customContextMenuRequested(self, pos):
         """
@@ -253,8 +275,12 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         if self.__repositoryMissing or current is None:
             return
         
-        self.urlEdit.setText(
-            current.data(0, PluginRepositoryWidget.UrlRole) or "")
+        url = current.data(0, PluginRepositoryWidget.UrlRole)
+        if url is None:
+            url = ""
+        else:
+            url = self.__changeScheme(url)
+        self.urlEdit.setText(url)
         self.descriptionEdit.setPlainText(
             current.data(0, PluginRepositoryWidget.DescrRole) and
             self.__formatDescription(
@@ -341,10 +367,14 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__downloadButton.setEnabled(False)
         self.__downloadInstallButton.setEnabled(False)
         self.__installButton.setEnabled(False)
+        
+        newScheme = self.repositoryUrlEdit.text().split("//", 1)[0]
         for itm in self.repositoryList.selectedItems():
             if itm not in [self.__stableItem, self.__unstableItem,
                            self.__unknownItem, self.__obsoleteItem]:
-                url = itm.data(0, PluginRepositoryWidget.UrlRole)
+                url = self.__changeScheme(
+                    itm.data(0, PluginRepositoryWidget.UrlRole),
+                    newScheme)
                 filename = os.path.join(
                     Preferences.getPluginManager("DownloadPath"),
                     itm.data(0, PluginRepositoryWidget.FilenameRole))
@@ -357,7 +387,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         self.__downloadButton.setEnabled(len(self.__selectedItems()))
         self.__downloadInstallButton.setEnabled(len(self.__selectedItems()))
-        self.__installButton.setEnabled(True)
+        self.__installButton.setEnabled(len(self.__selectedItems()))
         if not self.__external:
             ui = e5App().getObject("UserInterface")
         else:
@@ -461,6 +491,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             self.__updateButton.setEnabled(False)
             self.__downloadButton.setEnabled(False)
             self.__downloadInstallButton.setEnabled(False)
+            self.__closeButton.setEnabled(False)
             self.__downloadCancelButton.setEnabled(True)
             
             self.statusLabel.setText(url)
@@ -495,6 +526,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         @type func
         """
         self.__updateButton.setEnabled(True)
+        self.__closeButton.setEnabled(True)
         self.__downloadCancelButton.setEnabled(False)
         self.__onlineStateChanged(self.__isOnline())
         
@@ -588,30 +620,26 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         
         if status == "stable":
             if self.__stableItem is None:
-                self.__stableItem = \
-                    QTreeWidgetItem(self.repositoryList,
-                                    [self.tr("Stable")])
+                self.__stableItem = QTreeWidgetItem(
+                    self.repositoryList, [self.tr("Stable")])
                 self.__stableItem.setExpanded(True)
             parent = self.__stableItem
         elif status == "unstable":
             if self.__unstableItem is None:
-                self.__unstableItem = \
-                    QTreeWidgetItem(self.repositoryList,
-                                    [self.tr("Unstable")])
+                self.__unstableItem = QTreeWidgetItem(
+                    self.repositoryList, [self.tr("Unstable")])
                 self.__unstableItem.setExpanded(True)
             parent = self.__unstableItem
         elif status == "obsolete":
             if self.__obsoleteItem is None:
-                self.__obsoleteItem = \
-                    QTreeWidgetItem(self.repositoryList,
-                                    [self.tr("Obsolete")])
+                self.__obsoleteItem = QTreeWidgetItem(
+                    self.repositoryList, [self.tr("Obsolete")])
                 self.__obsoleteItem.setExpanded(True)
             parent = self.__obsoleteItem
         else:
             if self.__unknownItem is None:
-                self.__unknownItem = \
-                    QTreeWidgetItem(self.repositoryList,
-                                    [self.tr("Unknown")])
+                self.__unknownItem = QTreeWidgetItem(
+                    self.repositoryList, [self.tr("Unknown")])
                 self.__unknownItem.setExpanded(True)
             parent = self.__unknownItem
         itm = QTreeWidgetItem(parent, [name, version, short])
@@ -661,8 +689,10 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             # Check against installed/loaded plug-ins
             pluginName = filename.rsplit('-', 1)[0]
             pluginDetails = self.__pluginManager.getPluginDetails(pluginName)
-            if pluginDetails is None or \
-                    pluginDetails["moduleName"] != pluginName:
+            if (
+                pluginDetails is None or
+                pluginDetails["moduleName"] != pluginName
+            ):
                 return PluginRepositoryWidget.PluginStatusNew
             if pluginDetails["error"]:
                 return PluginRepositoryWidget.PluginStatusError
@@ -695,8 +725,10 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             pluginDetails = self.__pluginManager.getPluginDetails(pluginName)
             if pluginDetails is None:
                 return PluginRepositoryWidget.PluginStatusLocalUpdate
-            if Globals.versionToTuple(pluginDetails["version"])[:3] < \
-               Globals.versionToTuple(version)[:3]:
+            if (
+                Globals.versionToTuple(pluginDetails["version"])[:3] <
+                Globals.versionToTuple(version)[:3]
+            ):
                 return PluginRepositoryWidget.PluginStatusLocalUpdate
             else:
                 return PluginRepositoryWidget.PluginStatusUpToDate
@@ -879,8 +911,10 @@ class PluginRepositoryWindow(E5MainWindow):
         args.append(applPath)
         args += self.cw.getDownloadedPlugins()
         
-        if not os.path.isfile(applPath) or \
-                not proc.startDetached(sys.executable, args):
+        if (
+            not os.path.isfile(applPath) or
+            not proc.startDetached(sys.executable, args)
+        ):
             E5MessageBox.critical(
                 self,
                 self.tr('Process Generation Error'),
@@ -929,8 +963,9 @@ def PluginRepositoryDownloadCleanup(quiet=False):
             continue
         
         try:
-            pluginName, pluginVersion = \
+            pluginName, pluginVersion = (
                 pluginFile.replace(".zip", "").rsplit("-", 1)
+            )
             pluginVersionList = re.split("[._-]", pluginVersion)
             for index in range(len(pluginVersionList)):
                 try:
@@ -954,8 +989,10 @@ def PluginRepositoryDownloadCleanup(quiet=False):
     for pluginName in downloads:
         downloads[pluginName].sort(key=lambda x: x[1])
     
-        if pluginName in hiddenPlugins and \
-                not Preferences.getPluginManager("KeepHidden"):
+        if (
+            pluginName in hiddenPlugins and
+            not Preferences.getPluginManager("KeepHidden")
+        ):
             removeFiles = [f[0] for f in downloads[pluginName]]
         else:
             removeFiles = [f[0] for f in downloads[pluginName][
