@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -103,6 +103,8 @@ def extractLineFlags(line, startComment="#", endComment="", flagsLine=False):
                     comment = comment[:endPos]
             flags = [f.strip() for f in comment.split()
                      if (f.startswith("__") and f.endswith("__"))]
+            flags += [f.strip().lower() for f in comment.split()
+                      if f in ("noqa", "NOQA")]
     return flags
 
 
@@ -119,7 +121,10 @@ def ignoreCode(code, lineFlags):
     """
     if lineFlags:
         
-        if "__IGNORE_WARNING__" in lineFlags:
+        if (
+            "__IGNORE_WARNING__" in lineFlags or
+            "noqa" in lineFlags
+        ):
             # ignore all warning codes
             return True
         
@@ -135,18 +140,24 @@ def ignoreCode(code, lineFlags):
 
 def codeStyleCheck(filename, source, args):
     """
-    Do the code style check and/ or fix found errors.
+    Do the code style check and/or fix found errors.
     
-    @param filename source filename (string)
-    @param source string containing the code to check (string)
+    @param filename source filename
+    @type str
+    @param source string containing the code to check
+    @type str
     @param args arguments used by the codeStyleCheck function (list of
-        excludeMessages (str), includeMessages (str), repeatMessages
-        (bool), fixCodes (str), noFixCodes (str), fixIssues (bool),
-        maxLineLength (int), hangClosing (bool), docType (str), errors
-        (list of str), eol (str), encoding (str), backup (bool))
-    @return tuple of stats (dict) and results (tuple for each found violation
-        of style (tuple of lineno (int), position (int), text (str), ignored
-            (bool), fixed (bool), autofixing (bool), fixedMsg (str)))
+        excludeMessages, includeMessages, repeatMessages, fixCodes,
+        noFixCodes, fixIssues, maxLineLength, maxDocLineLength, blankLines,
+        hangClosing, docType, codeComplexityArgs, miscellaneousArgs, errors,
+        eol, encoding, backup)
+    @type list of (str, str, bool, str, str, bool, int, list of (int, int),
+        bool, str, dict, dict, list of str, str, str, bool)
+    @return tuple of statistics (dict) and list of results (tuple for each
+        found violation of style (lineno, position, text, ignored, fixed,
+        autofixing, fixedMsg))
+    @rtype tuple of (dict, list of tuples of (int, int, str, bool, bool, bool,
+        str))
     """
     return __checkCodeStyle(filename, source, args)
 
@@ -187,9 +198,10 @@ def codeStyleBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
         taskQueue.put(task)
 
     # Start worker processes
-    for i in range(NumberOfProcesses):
-        multiprocessing.Process(target=worker, args=(taskQueue, doneQueue))\
-            .start()
+    for _ in range(NumberOfProcesses):
+        multiprocessing.Process(
+            target=worker, args=(taskQueue, doneQueue)
+        ).start()
 
     # Get and send results
     endIndex = len(argumentsList) - initialTasks
@@ -217,7 +229,7 @@ def codeStyleBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
             taskQueue.put(argumentsList[i + initialTasks])
 
     # Tell child processes to stop
-    for i in range(NumberOfProcesses):
+    for _ in range(NumberOfProcesses):
         taskQueue.put('STOP')
 
 
@@ -238,22 +250,27 @@ def __checkCodeStyle(filename, source, args):
     Private module function to perform the code style check and/or fix
     found errors.
     
-    @param filename source filename (string)
-    @param source string containing the code to check (string)
+    @param filename source filename
+    @type str
+    @param source string containing the code to check
+    @type str
     @param args arguments used by the codeStyleCheck function (list of
-        excludeMessages (str), includeMessages (str), repeatMessages
-        (bool), fixCodes (str), noFixCodes (str), fixIssues (bool),
-        maxLineLength (int), hangClosing (bool), docType (str), dictionary
-        with arguments for the code complexity checker (dict), dictionary
-        with arguments for the miscellaneous checker (dict), errors (list
-        of str), eol (str), encoding (str), backup (bool))
-    @return tuple of statistics (dict) and results (tuple for each found
-        violation of style (tuple of lineno (int), position (int), text (str),
-        ignored (bool), fixed (bool), autofixing (bool), fixedMsg (str)))
+        excludeMessages, includeMessages, repeatMessages, fixCodes,
+        noFixCodes, fixIssues, maxLineLength, maxDocLineLength, blankLines,
+        hangClosing, docType, codeComplexityArgs, miscellaneousArgs,
+        annotationArgs, errors, eol, encoding, backup)
+    @type list of (str, str, bool, str, str, bool, int, list of (int, int),
+        bool, str, dict, dict, list of str, str, str, bool)
+    @return tuple of statistics (dict) and list of results (tuple for each
+        found violation of style (lineno, position, text, ignored, fixed,
+        autofixing, fixedMsg))
+    @rtype tuple of (dict, list of tuples of (int, int, str, bool, bool, bool,
+        str))
     """
     (excludeMessages, includeMessages, repeatMessages, fixCodes, noFixCodes,
-     fixIssues, maxLineLength, hangClosing, docType, codeComplexityArgs,
-     miscellaneousArgs, errors, eol, encoding, backup) = args
+     fixIssues, maxLineLength, maxDocLineLength, blankLines, hangClosing,
+     docType, codeComplexityArgs, miscellaneousArgs, annotationArgs, errors,
+     eol, encoding, backup) = args
     
     stats = {}
 
@@ -261,7 +278,8 @@ def __checkCodeStyle(filename, source, args):
         from CodeStyleFixer import CodeStyleFixer
         fixer = CodeStyleFixer(
             filename, source, fixCodes, noFixCodes,
-            maxLineLength, True, eol, backup)  # always fix in place
+            maxLineLength, blankLines, True, eol, backup)
+        # always fix in place
     else:
         fixer = None
     
@@ -286,12 +304,19 @@ def __checkCodeStyle(filename, source, args):
             ignore = []
         
         # check coding style
+        pycodestyle.BLANK_LINES_CONFIG = {
+            # Top level class and function.
+            'top_level': blankLines[0],
+            # Methods and nested class and function.
+            'method': blankLines[1],
+        }
         styleGuide = pycodestyle.StyleGuide(
             reporter=CodeStyleCheckerReport,
             repeat=repeatMessages,
             select=select,
             ignore=ignore,
             max_line_length=maxLineLength,
+            max_doc_length=maxDocLineLength,
             hang_closing=hangClosing,
         )
         report = styleGuide.check_files([filename])
@@ -301,7 +326,7 @@ def __checkCodeStyle(filename, source, args):
         # check documentation style
         docStyleChecker = DocStyleChecker(
             source, filename, select, ignore, [], repeatMessages,
-            maxLineLength=maxLineLength, docType=docType)
+            maxLineLength=maxDocLineLength, docType=docType)
         docStyleChecker.run()
         stats.update(docStyleChecker.counters)
         errors += docStyleChecker.errors
@@ -320,9 +345,20 @@ def __checkCodeStyle(filename, source, args):
         complexityChecker.run()
         stats.update(complexityChecker.counters)
         errors += complexityChecker.errors
+        
+        # check function annotations
+        if sys.version_info >= (3, 5, 0):
+            # annotations are supported from Python 3.5 on
+            from AnnotationsChecker import AnnotationsChecker
+            annotationsChecker = AnnotationsChecker(
+                source, filename, select, ignore, [], repeatMessages,
+                annotationArgs)
+            annotationsChecker.run()
+            stats.update(annotationsChecker.counters)
+            errors += annotationsChecker.errors
     
     errorsDict = {}
-    for fname, lineno, position, text in errors:
+    for _fname, lineno, position, text in errors:
         if lineno > len(source):
             lineno = len(source)
         # inverse processing of messages and fixes
