@@ -7,15 +7,16 @@
 Module implementing a dialog to show the results of the code style check.
 """
 
-from __future__ import unicode_literals
 
 import os
 import fnmatch
 
 from PyQt5.QtCore import pyqtSlot, Qt, QTimer
 from PyQt5.QtGui import QIcon
-from PyQt5.QtWidgets import QDialog, QTreeWidgetItem, QAbstractButton, \
-    QDialogButtonBox, QApplication, QHeaderView, QListWidgetItem
+from PyQt5.QtWidgets import (
+    QDialog, QTreeWidgetItem, QAbstractButton, QDialogButtonBox, QApplication,
+    QHeaderView, QListWidgetItem
+)
 
 from E5Gui.E5Application import e5App
 
@@ -200,8 +201,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             itm.setIcon(1, UI.PixmapCache.getIcon("syntaxError.png"))
         if fixed:
             itm.setIcon(0, UI.PixmapCache.getIcon("issueFixed.png"))
-        elif code in FixableCodeStyleIssues and not autofixing and \
-                code not in self.__noFixCodesList:
+        elif (
+            code in FixableCodeStyleIssues and not autofixing and
+            code not in self.__noFixCodesList
+        ):
             itm.setIcon(0, UI.PixmapCache.getIcon("issueFixable.png"))
             fixable = True
         
@@ -302,8 +305,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
         self.__data = self.__project.getData("CHECKERSPARMS", "Pep8Checker")
-        if self.__data is None or \
-           len(self.__data) < 6:
+        if (
+            self.__data is None or
+            len(self.__data) < 6
+        ):
             # initialize the data structure
             self.__data = {
                 "ExcludeFiles": "",
@@ -337,8 +342,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             self.__data["LineComplexityScore"] = 10
         if "ValidEncodings" not in self.__data:
             self.__data["ValidEncodings"] = "latin-1, utf-8"
-        if "CopyrightMinFileSize" not in self.__data or \
-                "CopyrightAuthor" not in self.__data:
+        if (
+            "CopyrightMinFileSize" not in self.__data or
+            "CopyrightAuthor" not in self.__data
+        ):
             self.__data["CopyrightMinFileSize"] = 0
             self.__data["CopyrightAuthor"] = ""
         if "FutureChecker" not in self.__data:
@@ -348,6 +355,15 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "str": ["unicode", ],
                 "chr": ["unichr", ],
             }
+        if "CommentedCodeChecker" not in self.__data:
+            self.__data["CommentedCodeChecker"] = {
+                "Aggressive": False,
+            }
+        if "AnnotationsChecker" not in self.__data:
+            self.__data["AnnotationsChecker"] = {
+                "MinimumCoverage": 75,
+                "MaximumComplexity": 3,
+            }
         
         self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
         self.excludeMessagesEdit.setText(self.__data["ExcludeMessages"])
@@ -374,6 +390,12 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.copyrightAuthorEdit.setText(self.__data["CopyrightAuthor"])
         self.__initFuturesList(self.__data["FutureChecker"])
         self.__initBuiltinsIgnoreList(self.__data["BuiltinsChecker"])
+        self.aggressiveCheckBox.setChecked(
+            self.__data["CommentedCodeChecker"]["Aggressive"])
+        self.minAnnotationsCoverageSpinBox.setValue(
+            self.__data["AnnotationsChecker"]["MinimumCoverage"])
+        self.maxAnnotationsComplexitySpinBox.setValue(
+            self.__data["AnnotationsChecker"]["MaximumComplexity"])
     
     def start(self, fn, save=False, repeat=None):
         """
@@ -423,9 +445,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             filterList = [f.strip() for f in filterString.split(",")
                           if f.strip()]
             for fileFilter in filterList:
-                self.files = \
-                    [f for f in self.files
-                     if not fnmatch.fnmatch(f, fileFilter.strip())]
+                self.files = [
+                    f for f in self.files
+                    if not fnmatch.fnmatch(f, fileFilter.strip())
+                ]
 
         self.__errorItem = None
         self.__resetStatistics()
@@ -443,11 +466,13 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             repeatMessages = self.repeatCheckBox.isChecked()
             fixCodes = self.fixIssuesEdit.text()
             noFixCodes = self.noFixIssuesEdit.text()
-            self.__noFixCodesList = \
-                [c.strip() for c in noFixCodes.split(",") if c.strip()]
+            self.__noFixCodesList = [
+                c.strip() for c in noFixCodes.split(",") if c.strip()
+            ]
             fixIssues = self.fixIssuesCheckBox.isChecked() and repeatMessages
-            self.showIgnored = self.ignoredCheckBox.isChecked() and \
-                repeatMessages
+            self.showIgnored = (
+                self.ignoredCheckBox.isChecked() and repeatMessages
+            )
             maxLineLength = self.lineLengthSpinBox.value()
             maxDocLineLength = self.docLineLengthSpinBox.value()
             blankLines = (
@@ -470,12 +495,22 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 },
                 "FutureChecker": self.__getSelectedFutureImports(),
                 "BuiltinsChecker": self.__getBuiltinsIgnoreList(),
+                "CommentedCodeChecker": {
+                    "Aggressive": self.aggressiveCheckBox.isChecked(),
+                }
+            }
+            annotationArgs = {
+                "MinimumCoverage":
+                    self.minAnnotationsCoverageSpinBox.value(),
+                "MaximumComplexity":
+                    self.maxAnnotationsComplexitySpinBox.value(),
             }
             
             self.__options = [excludeMessages, includeMessages, repeatMessages,
                               fixCodes, noFixCodes, fixIssues, maxLineLength,
                               maxDocLineLength, blankLines, hangClosing,
-                              docType, codeComplexityArgs, miscellaneousArgs]
+                              docType, codeComplexityArgs, miscellaneousArgs,
+                              annotationArgs]
             
             # now go through all the files
             self.progress = 0
@@ -505,8 +540,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         options = self.__options[:]
         flags = Utilities.extractFlags(source)
         if "noqa" in flags and isinstance(flags["noqa"], basestring):
-            excludeMessages = \
-                options[0].strip().rstrip(",")
+            excludeMessages = options[0].strip().rstrip(",")
             if excludeMessages:
                 excludeMessages += ","
             excludeMessages += flags["noqa"]
@@ -803,6 +837,15 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "CopyrightAuthor": self.copyrightAuthorEdit.text(),
                 "FutureChecker": self.__getSelectedFutureImports(),
                 "BuiltinsChecker": self.__getBuiltinsIgnoreList(),
+                "CommentedCodeChecker": {
+                    "Aggressive": self.aggressiveCheckBox.isChecked(),
+                },
+                "AnnotationsChecker": {
+                    "MinimumCoverage":
+                        self.minAnnotationsCoverageSpinBox.value(),
+                    "MaximumComplexity":
+                        self.maxAnnotationsComplexitySpinBox.value(),
+                }
             }
             if data != self.__data:
                 self.__data = data
@@ -1005,6 +1048,14 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "str": ["unicode", ],
                 "chr": ["unichr", ],
             })))
+        self.aggressiveCheckBox.setChecked(Preferences.toBool(
+            Preferences.Prefs.settings.value("PEP8/AggressiveSearch", False)))
+        self.minAnnotationsCoverageSpinBox.setValue(int(
+            Preferences.Prefs.settings.value(
+                "PEP8/MinimumAnnotationsCoverage", 75)))
+        self.maxAnnotationsComplexitySpinBox.setValue(int(
+            Preferences.Prefs.settings.value(
+                "PEP8/MaximumAnnotationComplexity", 3)))
     
     @pyqtSlot()
     def on_storeDefaultButton_clicked(self):
@@ -1060,6 +1111,14 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "PEP8/FutureChecker", self.__getSelectedFutureImports())
         Preferences.Prefs.settings.setValue(
             "PEP8/BuiltinsChecker", self.__getBuiltinsIgnoreList())
+        Preferences.Prefs.settings.setValue(
+            "PEP8/AggressiveSearch", self.aggressiveCheckBox.isChecked())
+        Preferences.Prefs.settings.setValue(
+            "PEP8/MinimumAnnotationsCoverage",
+            self.minAnnotationsCoverageSpinBox.value())
+        Preferences.Prefs.settings.setValue(
+            "PEP8/MaximumAnnotationComplexity",
+            self.maxAnnotationsComplexitySpinBox.value())
     
     @pyqtSlot()
     def on_resetDefaultButton_clicked(self):
@@ -1098,6 +1157,12 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "str": ["unicode", ],
             "chr": ["unichr", ],
         })
+        Preferences.Prefs.settings.setValue("PEP8/AggressiveSearch", False)
+        Preferences.Prefs.settings.setValue(
+            "PEP8/MinimumAnnotationsCoverage", 75)
+        Preferences.Prefs.settings.setValue(
+            "PEP8/MaximumAnnotationComplexity", 3)
+        
         # Update UI with default values
         self.on_loadDefaultButton_clicked()
     
@@ -1280,8 +1345,9 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         """
         Private slot to add a built-in assignment to be ignored.
         """
-        from .CodeStyleAddBuiltinIgnoreDialog import \
+        from .CodeStyleAddBuiltinIgnoreDialog import (
             CodeStyleAddBuiltinIgnoreDialog
+        )
         dlg = CodeStyleAddBuiltinIgnoreDialog(self)
         if dlg.exec_() == QDialog.Accepted:
             left, right = dlg.getData()
