@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to select code style message codes.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem
@@ -60,6 +59,9 @@ class CodeStyleCodeSelectionDialog(QDialog, Ui_CodeStyleCodeSelectionDialog):
                 itm.setIcon(0, UI.PixmapCache.getIcon("namingError.png"))
             elif code.startswith("D"):
                 itm.setIcon(0, UI.PixmapCache.getIcon("docstringError.png"))
+            else:
+                # unknown category prefix => warning
+                itm.setIcon(0, UI.PixmapCache.getIcon("warning.png"))
             itm.setFlags(itm.flags() | Qt.ItemIsUserCheckable)
             if code in codeList:
                 itm.setCheckState(0, Qt.Checked)
