@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -137,7 +137,7 @@ class DocStyleChecker(object):
         "D130", "D131", "D132", "D133", "D134",
         "D141", "D142", "D143", "D144", "D145",
         
-        "D203", "D205",
+        "D203", "D205", "D206",
         "D221", "D222",
         "D231", "D232", "D234", "D235", "D236", "D237", "D238", "D239",
         "D242", "D243", "D244", "D245", "D246", "D247",
@@ -232,7 +232,7 @@ class DocStyleChecker(object):
                 "functionDocstring": [
                 ],
                 "classDocstring": [
-                    (self.__checkClassDocstring, ("D104", "D205")),
+                    (self.__checkClassDocstring, ("D104", "D205", "D206")),
                     (self.__checkEricNoBlankBeforeAndAfterClassOrFunction,
                      ("D242", "D243")),
                     (self.__checkEricSignal, ("D260", "D261", "D262", "D263")),
@@ -483,7 +483,7 @@ class DocStyleChecker(object):
             arguments = []
             arguments.extend([arg.arg for arg in node.args.args])
             if node.args.vararg is not None:
-                if sys.version_info[1] < 4:
+                if sys.version_info < (3, 4, 0):
                     arguments.append(node.args.vararg)
                 else:
                     arguments.append(node.args.vararg.arg)
@@ -491,7 +491,7 @@ class DocStyleChecker(object):
             kwarguments = []
             kwarguments.extend([arg.arg for arg in node.args.kwonlyargs])
             if node.args.kwarg is not None:
-                if sys.version_info[1] < 4:
+                if sys.version_info < (3, 4, 0):
                     kwarguments.append(node.args.kwarg)
                 else:
                     kwarguments.append(node.args.kwarg.arg)
@@ -508,7 +508,7 @@ class DocStyleChecker(object):
         @param source source to parse (list of string)
         @return context of extracted docstring (DocStyleContext)
         """
-        for kind, value, (line, char), _, _ in tokenize.generate_tokens(
+        for kind, value, (line, _char), _, _ in tokenize.generate_tokens(
                 StringIO("".join(source)).readline):
             if kind in [tokenize.COMMENT, tokenize.NEWLINE, tokenize.NL]:
                 continue
@@ -516,6 +516,8 @@ class DocStyleChecker(object):
                 return DocStyleContext(value, line - 1, "docstring")
             else:
                 return None
+        
+        return None
 
     def __parseDocstring(self, context, what=''):
         """
@@ -613,6 +615,8 @@ class DocStyleChecker(object):
                 indent -= 1
             if indent == 0:
                 return kind, value, start, end, raw
+        
+        return None
     
     def __parseMethods(self):
         """
@@ -630,11 +634,13 @@ class DocStyleChecker(object):
                     while True:
                         start, end = None, None
                         while not (kind == tokenize.NAME and value == 'def'):
-                            kind, value, (line, char), _, _ = \
+                            kind, value, (line, char), _, _ = (
                                 next(tokenGenerator)
+                            )
                         start = line - 1, char
-                        kind, value, (line, char), _, _ = \
+                        kind, value, (line, char), _, _ = (
                             self.__skipIndentedBlock(tokenGenerator)
+                        )
                         end = line - 1, char
                         startLine = classContext.start() + start[0]
                         endLine = classContext.start() + end[0]
@@ -642,11 +648,15 @@ class DocStyleChecker(object):
                             self.__source[startLine:endLine],
                             startLine, "def")
                         if startLine > 0:
-                            if self.__source[startLine - 1].strip() == \
-                                    "@staticmethod":
+                            if (
+                                self.__source[startLine - 1].strip() ==
+                                "@staticmethod"
+                            ):
                                 context.setSpecial("staticmethod")
-                            elif self.__source[startLine - 1].strip() == \
-                                    "@classmethod":
+                            elif (
+                                self.__source[startLine - 1].strip() ==
+                                "@classmethod"
+                            ):
                                 context.setSpecial("classmethod")
                         contexts.append(context)
                 except StopIteration:
@@ -698,6 +708,14 @@ class DocStyleChecker(object):
         if (not docstring or not docstring.strip() or
                 not docstring.strip('\'"')):
             self.__error(context.start(), 0, "D101")
+        
+        if (
+            self.__docType == "eric" and
+            docstring.strip('\'"').strip() ==
+            "Module documentation goes here."
+        ):
+            self.__error(docstringContext.end(), 0, "D201")
+            return
     
     def __checkFunctionDocstring(self, docstringContext, context):
         """
@@ -724,6 +742,14 @@ class DocStyleChecker(object):
         if (not docstring or not docstring.strip() or
                 not docstring.strip('\'"')):
             self.__error(context.start(), 0, code)
+        
+        if (
+            self.__docType == "eric" and
+            docstring.strip('\'"').strip() ==
+            "Function documentation goes here."
+        ):
+            self.__error(docstringContext.end(), 0, "D202")
+            return
     
     def __checkClassDocstring(self, docstringContext, context):
         """
@@ -750,6 +776,14 @@ class DocStyleChecker(object):
         if (not docstring or not docstring.strip() or
                 not docstring.strip('\'"')):
             self.__error(context.start(), 0, code)
+            return
+        
+        if (
+            self.__docType == "eric" and
+            docstring.strip('\'"').strip() == "Class documentation goes here."
+        ):
+            self.__error(docstringContext.end(), 0, "D206")
+            return
     
     def __checkTripleDoubleQuotes(self, docstringContext, context):
         """
@@ -793,8 +827,10 @@ class DocStyleChecker(object):
             return
         
         docstring = docstringContext.ssource().strip()
-        if not docstring.startswith('u"""') and \
-                any(ord(char) > 127 for char in docstring):
+        if (
+            not docstring.startswith('u"""') and
+            any(ord(char) > 127 for char in docstring)
+        ):
             self.__error(docstringContext.start(), 0, "D113")
     
     def __checkOneLiner(self, docstringContext, context):
@@ -906,8 +942,10 @@ class DocStyleChecker(object):
         
         functionName = context.source()[0].lstrip().split()[1].split("(")[0]
         summary, lineNumber = self.__getSummaryLine(docstringContext)
-        if functionName + "(" in summary.replace(" ", "") and \
-                not functionName + "()" in summary.replace(" ", ""):
+        if (
+            functionName + "(" in summary.replace(" ", "") and
+            not functionName + "()" in summary.replace(" ", "")
+        ):
             # report only, if it is not an abbreviated form (i.e. function() )
             self.__error(docstringContext.start() + lineNumber, 0, "D133")
     
@@ -944,9 +982,11 @@ class DocStyleChecker(object):
         
         contextLines = context.source()
         cti = 0
-        while cti < len(contextLines) and \
-                not contextLines[cti].strip().startswith(
-                ('"""', 'r"""', 'u"""', "'''", "r'''", "u'''")):
+        while (
+            cti < len(contextLines) and
+            not contextLines[cti].strip().startswith(
+                ('"""', 'r"""', 'u"""', "'''", "r'''", "u'''"))
+        ):
             cti += 1
         if cti == len(contextLines):
             return
@@ -967,9 +1007,11 @@ class DocStyleChecker(object):
         
         contextLines = context.source()
         cti = 0
-        while cti < len(contextLines) and \
+        while (
+            cti < len(contextLines) and
             not contextLines[cti].strip().startswith(
-                ('"""', 'r"""', 'u"""', "'''", "r'''", "u'''")):
+                ('"""', 'r"""', 'u"""', "'''", "r'''", "u'''"))
+        ):
             cti += 1
         if cti == len(contextLines):
             return
@@ -980,8 +1022,10 @@ class DocStyleChecker(object):
             # it is a multi line docstring
             cti += 1
         
-        while cti < len(contextLines) and \
-                not contextLines[cti].strip().endswith(('"""', "'''")):
+        while (
+            cti < len(contextLines) and
+            not contextLines[cti].strip().endswith(('"""', "'''"))
+        ):
             cti += 1
         end = cti
         if cti >= len(contextLines) - 1:
@@ -1068,8 +1112,11 @@ class DocStyleChecker(object):
             if summaryLines[-1].lstrip().startswith("@"):
                 summaryLines.pop(-1)
             summary = " ".join([s.strip() for s in summaryLines if s])
-            if summary and not summary.endswith(".") and \
-                    not summary.split(None, 1)[0].lower() == "constructor":
+            if (
+                summary and
+                not summary.endswith(".") and
+                not summary.split(None, 1)[0].lower() == "constructor"
+            ):
                 self.__error(
                     docstringContext.start() + lineNumber +
                     len(summaryLines) - 1,
@@ -1139,10 +1186,12 @@ class DocStyleChecker(object):
                 kwargs = []
                 for line in docstringContext.source():
                     if line.strip().startswith(("@param", "@keyparam")):
-                        at, name = line.strip().split(None, 2)[:2]
-                        if at == "@keyparam":
-                            kwargs.append(name.lstrip("*"))
-                        args.append(name.lstrip("*"))
+                        paramParts = line.strip().split(None, 2)
+                        if len(paramParts) >= 2:
+                            at, name = paramParts[:2]
+                            if at == "@keyparam":
+                                kwargs.append(name.lstrip("*"))
+                            args.append(name.lstrip("*"))
                 
                 # do the checks
                 for name in kwNames:
@@ -1176,16 +1225,20 @@ class DocStyleChecker(object):
             if token[1] == "raise":
                 exceptions.add(tokens[i + 1][0])
                 if tokens[i + 1][0] == tokenize.NAME:
-                    if tokensLen > (i + 2) and \
-                       tokens[i + 2][1] == ".":
+                    if (
+                        tokensLen > (i + 2) and
+                        tokens[i + 2][1] == "."
+                    ):
                         raisedExceptions.add("{0}.{1}".format(
                             tokens[i + 1][1], tokens[i + 3][1]))
                     else:
                         raisedExceptions.add(tokens[i + 1][1])
         
-        if "@exception" not in docstringContext.ssource() and \
-                "@throws" not in docstringContext.ssource() and \
-                "@raise" not in docstringContext.ssource():
+        if (
+            "@exception" not in docstringContext.ssource() and
+            "@throws" not in docstringContext.ssource() and
+            "@raise" not in docstringContext.ssource()
+        ):
             if (exceptions -
                     {tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE} !=
                     set()):
@@ -1306,9 +1359,11 @@ class DocStyleChecker(object):
         contextLines = context.source()
         isClassContext = contextLines[0].lstrip().startswith("class ")
         cti = 0
-        while cti < len(contextLines) and \
+        while (
+            cti < len(contextLines) and
             not contextLines[cti].strip().startswith(
-                ('"""', 'r"""', 'u"""', "'''", "r'''", "u'''")):
+                ('"""', 'r"""', 'u"""', "'''", "r'''", "u'''"))
+        ):
             cti += 1
         if cti == len(contextLines):
             return
@@ -1319,8 +1374,10 @@ class DocStyleChecker(object):
             # it is a multi line docstring
             cti += 1
         
-        while cti < len(contextLines) and \
-                not contextLines[cti].strip().endswith(('"""', "'''")):
+        while (
+            cti < len(contextLines) and
+            not contextLines[cti].strip().endswith(('"""', "'''"))
+        ):
             cti += 1
         end = cti
         if cti >= len(contextLines) - 1:
@@ -1371,15 +1428,18 @@ class DocStyleChecker(object):
         if summary:
             # check, if the first word is 'Constructor', 'Public',
             # 'Protected' or 'Private'
-            functionName, arguments = context.source()[0].lstrip()\
-                .split()[1].split("(", 1)
+            functionName, arguments = (
+                context.source()[0].lstrip().split()[1].split("(", 1)
+            )
             firstWord = summary.strip().split(None, 1)[0].lower()
             if functionName == '__init__':
                 if firstWord != 'constructor':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'constructor')
-            elif functionName.startswith('__') and \
-                    functionName.endswith('__'):
+            elif (
+                functionName.startswith('__') and
+                functionName.endswith('__')
+            ):
                 if firstWord != 'special':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'special')
@@ -1393,8 +1453,10 @@ class DocStyleChecker(object):
                         if firstWord != 'private':
                             self.__error(docstringContext.start() + lineNumber,
                                          0, "D232", 'private static')
-                    elif functionName.startswith('_') or \
-                            functionName.endswith('Event'):
+                    elif (
+                        functionName.startswith('_') or
+                        functionName.endswith('Event')
+                    ):
                         if firstWord != 'protected':
                             self.__error(docstringContext.start() + lineNumber,
                                          0, "D232", 'protected static')
@@ -1402,8 +1464,10 @@ class DocStyleChecker(object):
                         if firstWord != 'public':
                             self.__error(docstringContext.start() + lineNumber,
                                          0, "D232", 'public static')
-            elif arguments.startswith(('cls,', 'cls)')) or \
-                    context.special() == "classmethod":
+            elif (
+                arguments.startswith(('cls,', 'cls)')) or
+                context.special() == "classmethod"
+            ):
                 secondWord = summary.strip().split(None, 2)[1].lower()
                 if firstWord != 'class' and secondWord != 'class':
                     self.__error(docstringContext.start() + lineNumber, 0,
@@ -1413,8 +1477,10 @@ class DocStyleChecker(object):
                         if firstWord != 'private':
                             self.__error(docstringContext.start() + lineNumber,
                                          0, "D232", 'private class')
-                    elif functionName.startswith('_') or \
-                            functionName.endswith('Event'):
+                    elif (
+                        functionName.startswith('_') or
+                        functionName.endswith('Event')
+                    ):
                         if firstWord != 'protected':
                             self.__error(docstringContext.start() + lineNumber,
                                          0, "D232", 'protected class')
@@ -1426,8 +1492,10 @@ class DocStyleChecker(object):
                 if firstWord != 'private':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'private')
-            elif functionName.startswith('_') or \
-                    functionName.endswith('Event'):
+            elif (
+                functionName.startswith('_') or
+                functionName.endswith('Event')
+            ):
                 if firstWord != 'protected':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'protected')
