@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing message translations for the code style plugin messages.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import QCoreApplication
 
@@ -16,6 +15,9 @@ from Globals import translate
 __all__ = ["getTranslatedMessage"]
 
 _messages = {
+    ##################################################################
+    ## pycodestyle messages
+    ##################################################################
     "E101": QCoreApplication.translate(
         "pycodestyle",
         "indentation contains mixed spaces and tabs"),
@@ -37,6 +39,9 @@ _messages = {
     "E116": QCoreApplication.translate(
         "pycodestyle",
         "unexpected indentation (comment)"),
+    "E117": QCoreApplication.translate(
+        "pycodestyle",
+        "over-indented"),
     "E121": QCoreApplication.translate(
         "pycodestyle",
         "continuation line indentation is not a multiple of four"),
@@ -122,6 +127,9 @@ _messages = {
     "E251": QCoreApplication.translate(
         "pycodestyle",
         "unexpected spaces around keyword / parameter equals"),
+    "E252": QCoreApplication.translate(
+        "pycodestyle",
+        "missing whitespace around parameter equals"),
     "E261": QCoreApplication.translate(
         "pycodestyle",
         "at least two spaces before inline comment"),
@@ -160,23 +168,29 @@ _messages = {
         "blank line contains whitespace"),
     "E301": QCoreApplication.translate(
         "pycodestyle",
-        "expected 1 blank line, found 0"),
+        "expected {0} blank lines, found {1}"),
     "E302": QCoreApplication.translate(
         "pycodestyle",
-        "expected 2 blank lines, found {0}"),
+        "expected {0} blank lines, found {1}"),
     "E303": QCoreApplication.translate(
         "pycodestyle",
-        "too many blank lines ({0})"),
+        "too many blank lines ({0}), expected {1}"),
     "E304": QCoreApplication.translate(
         "pycodestyle",
         "blank lines found after function decorator"),
     "E305": QCoreApplication.translate(
         "pycodestyle",
-        "expected 2 blank lines after class or function definition,"
-        " found {0}"),
+        "expected {0} blank lines after class or function definition,"
+        " found {1}"),
     "E306": QCoreApplication.translate(
         "pycodestyle",
-        "expected 1 blank line before a nested definition, found 0"),
+        "expected {0} blank lines before a nested definition, found {1}"),
+    "E307": QCoreApplication.translate(
+        "pycodestyle",
+        "too many blank lines ({0}) before a nested definition, expected {1}"),
+    "E308": QCoreApplication.translate(
+        "pycodestyle",
+        "too many blank lines ({0})"),
     "W391": QCoreApplication.translate(
         "pycodestyle",
         "blank line at end of file"),
@@ -195,6 +209,12 @@ _messages = {
     "W503": QCoreApplication.translate(
         "pycodestyle",
         "line break before binary operator"),
+    "W504": QCoreApplication.translate(
+        "pycodestyle",
+        "line break after binary operator"),
+    "W505": QCoreApplication.translate(
+        "pycodestyle",
+        "doc line too long ({0} > {1} characters)"),
     "W601": QCoreApplication.translate(
         "pycodestyle",
         ".has_key() is deprecated, use 'in'"),
@@ -207,6 +227,12 @@ _messages = {
     "W604": QCoreApplication.translate(
         "pycodestyle",
         "backticks are deprecated, use 'repr()'"),
+    "W605": QCoreApplication.translate(
+        "pycodestyle",
+        "invalid escape sequence '\\{0}'"),
+    "W606": QCoreApplication.translate(
+        "pycodestyle",
+        "'async' and 'await' are reserved keywords starting with Python 3.7"),
     "E701": QCoreApplication.translate(
         "pycodestyle",
         "multiple statements on one line (colon)"),
@@ -255,8 +281,10 @@ _messages = {
     "E902": QCoreApplication.translate(
         "pycodestyle",
         "{0}"),
-
-    # DocStyleChecker messages
+    
+    ##################################################################
+    ## DocStyleChecker messages
+    ##################################################################
     "D101": QCoreApplication.translate(
         "DocStyleChecker", "module is missing a docstring"),
     "D102": QCoreApplication.translate(
@@ -311,11 +339,17 @@ _messages = {
         "DocStyleChecker",
         "last paragraph of docstring is not followed by a blank line"),
     
+    "D201": QCoreApplication.translate(
+        "DocStyleChecker", "module docstring is still a default string"),
+    "D202": QCoreApplication.translate(
+        "DocStyleChecker", "function docstring is still a default string"),
     "D203": QCoreApplication.translate(
         "DocStyleChecker",
         "private function/method is missing a docstring"),
     "D205": QCoreApplication.translate(
         "DocStyleChecker", "private class is missing a docstring"),
+    "D206": QCoreApplication.translate(
+        "DocStyleChecker", "class docstring is still a default string"),
     "D221": QCoreApplication.translate(
         "DocStyleChecker",
         "leading quotes of docstring not on separate line"),
@@ -391,8 +425,10 @@ _messages = {
     
     "D901": QCoreApplication.translate(
         "DocStyleChecker", "{0}: {1}"),
-
-    # NamingStyleChecker messages
+    
+    ##################################################################
+    ## NamingStyleChecker messages
+    ##################################################################
     "N801": QCoreApplication.translate(
         "NamingStyleChecker",
         "class names should use CapWords convention"),
@@ -436,8 +472,10 @@ _messages = {
     "N831": QCoreApplication.translate(
         "NamingStyleChecker",
         "names 'l', 'O' and 'I' should be avoided"),
-
-    # Code complexity messages
+    
+    ##################################################################
+    ## Code complexity messages
+    ##################################################################
     "C101": QCoreApplication.translate(
         "ComplexityChecker", "'{0}' is too complex ({1})"),
     "C111": QCoreApplication.translate(
@@ -448,7 +486,9 @@ _messages = {
     "C901": QCoreApplication.translate(
         "ComplexityChecker", "{0}: {1}"),
     
-    # Messages of the Miscellaneous Checker
+    ##################################################################
+    ## Messages of the Miscellaneous Checker
+    ##################################################################
     "M101": QCoreApplication.translate(
         "MiscellaneousChecker",
         "coding magic comment not found"),
@@ -469,30 +509,196 @@ _messages = {
         "MiscellaneousChecker",
         '"{0}" is used as an argument and thus shadows a '
         'Python builtin; consider renaming the argument'),
-    "M191": QCoreApplication.translate(
+    "M181": QCoreApplication.translate(
         "MiscellaneousChecker",
         'unnecessary generator - rewrite as a list comprehension'),
-    "M192": QCoreApplication.translate(
+    "M182": QCoreApplication.translate(
         "MiscellaneousChecker",
         'unnecessary generator - rewrite as a set comprehension'),
-    "M193": QCoreApplication.translate(
+    "M183": QCoreApplication.translate(
         "MiscellaneousChecker",
         'unnecessary generator - rewrite as a dict comprehension'),
-    "M194": QCoreApplication.translate(
+    "M184": QCoreApplication.translate(
         "MiscellaneousChecker",
         'unnecessary list comprehension - rewrite as a set comprehension'),
-    "M195": QCoreApplication.translate(
+    "M185": QCoreApplication.translate(
         "MiscellaneousChecker",
         'unnecessary list comprehension - rewrite as a dict comprehension'),
-    "M196": QCoreApplication.translate(
+    "M186": QCoreApplication.translate(
         "MiscellaneousChecker",
-        'unnecessary list literal - rewrite as a set literal'),
-    "M197": QCoreApplication.translate(
-        "MiscellaneousChecker",
-        'unnecessary list literal - rewrite as a dict literal'),
-    "M198": QCoreApplication.translate(
+        'unnecessary {0} call - rewrite as a literal'),
+    "M187": QCoreApplication.translate(
         "MiscellaneousChecker",
         'unnecessary list comprehension - "{0}" can take a generator'),
+    "M191": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary {0} literal - rewrite as a {1} literal'),
+    "M192": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary {0} passed to tuple() - rewrite as a {1} literal'),
+    "M193": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary {0} passed to list() - rewrite as a {1} literal'),
+    "M195": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list call - remove the outer call to list()'),
+    "M196": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list comprehension - "in" can take a generator'),
+    "M197": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary {0} passed to tuple() - remove the outer call to {1}()'),
+    "M198": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary {0} passed to list() - remove the outer call to {1}()'),
+    
+    "M201": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "sort keys - '{0}' should be before '{1}'"),
+    
+    "M301": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime()' without 'tzinfo' argument should be"
+        " avoided"),
+    "M302": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime.today()' should be avoided.\n"
+        "Use 'datetime.datetime.now(tz=)' instead."),
+    "M303": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime.utcnow()' should be avoided.\n"
+        "Use 'datetime.datetime.now(tz=)' instead."),
+    "M304": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime.utcfromtimestamp()' should be avoided.\n"
+        "Use 'datetime.datetime.fromtimestamp(, tz=)' instead."),
+    "M305": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime.now()' without 'tz' argument should be"
+        " avoided"),
+    "M306": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime.fromtimestamp()' without 'tz' argument"
+        " should be avoided"),
+    "M307": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime.strptime()' should be followed by"
+        " '.replace(tzinfo=)'"),
+    "M308": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.datetime.fromordinal()' should be avoided"),
+    "M311": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.date()' should be avoided.\n"
+        "Use 'datetime.datetime(, tzinfo=).date()' instead."),
+    "M312": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.date.today()' should be avoided.\n"
+        "Use 'datetime.datetime.now(tz=).date()' instead."),
+    "M313": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.date.fromtimestamp()' should be avoided.\n"
+        "Use 'datetime.datetime.fromtimestamp(tz=).date()' instead."),
+    "M314": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.date.fromordinal()' should be avoided"),
+    "M315": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.date.fromisoformat()' should be avoided"),
+    "M321": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "use of 'datetime.time()' without 'tzinfo' argument should be"
+        " avoided"),
+    
+    "M401": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version[:3]' referenced (Python 3.10), use 'sys.version_info'"),
+    "M402": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version[2]' referenced (Python 3.10), use 'sys.version_info'"),
+    "M403": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version' compared to string (Python 3.10), use"
+        " 'sys.version_info'"),
+    "M411": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version_info[0] == 3' referenced (Python 4), use '>='"),
+    "M412": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'six.PY3' referenced (Python 4), use 'not six.PY2'"),
+    "M413": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version_info[1]' compared to integer (Python 4),"
+        " compare 'sys.version_info' to tuple"),
+    "M414": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version_info.minor' compared to integer (Python 4),"
+        " compare 'sys.version_info' to tuple"),
+    "M421": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version[0]' referenced (Python 10), use 'sys.version_info'"),
+    "M422": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version' compared to string (Python 10),"
+        " use 'sys.version_info'"),
+    "M423": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.version[:1]' referenced (Python 10), use 'sys.version_info'"),
+    
+    "M501": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "Python does not support the unary prefix increment"),
+    "M502": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "using .strip() with multi-character strings is misleading"),
+    "M503": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "do not call assert False since python -O removes these calls"),
+    "M504": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'sys.maxint' is not defined in Python 3 - use 'sys.maxsize'"),
+    "M505": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'BaseException.message' has been deprecated as of Python 2.6 and is"
+        " removed in Python 3 - use 'str(e)'"),
+    "M506": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "assigning to 'os.environ' does not clear the environment -"
+        " use 'os.environ.clear()'"),
+    "M507": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "loop control variable {0} not used within the loop body -"
+        " start the name with an underscore"),
+    "M508": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "unncessary f-string"),
+    "M509": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "cannot use 'self.__class__' as first argument of 'super()' call"),
+    "M511": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        """using 'hasattr(x, "__call__")' to test if 'x' is callable is"""
+        """ unreliable"""),
+    "M512": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "do not call getattr with a constant attribute value"),
+    "M513": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "do not call setattr with a constant attribute value"),
+    "M521": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "Python 3 does not include '.iter*' methods on dictionaries"),
+    "M522": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "Python 3 does not include '.view*' methods on dictionaries"),
+    "M523": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'.next()' does not exist in Python 3"),
+    "M524": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "'__metaclass__' does nothing on Python 3 -"
+        " use 'class MyClass(BaseClass, metaclass=...)'"),
+    
     "M601": QCoreApplication.translate(
         "MiscellaneousChecker",
         "found {0} formatter"),
@@ -526,12 +732,32 @@ _messages = {
     "M632": QCoreApplication.translate(
         "MiscellaneousChecker",
         "format call provides unused keyword ({0})"),
+    "M651": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "logging statement uses string.format()"),
+    "M652": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "logging statement uses '%'"),          # __IGNORE_WARNING_M601__
+    "M653": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "logging statement uses '+'"),
+    "M654": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "logging statement uses f-string"),
+    "M655": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "logging statement uses 'warn' instead of 'warning'"),
+    
     "M701": QCoreApplication.translate(
         "MiscellaneousChecker",
         "expected these __future__ imports: {0}; but only got: {1}"),
     "M702": QCoreApplication.translate(
         "MiscellaneousChecker",
         "expected these __future__ imports: {0}; but got none"),
+    "M711": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "gettext import with alias _ found: {0}"),
+    
     "M801": QCoreApplication.translate(
         "MiscellaneousChecker",
         "print statement found"),
@@ -544,11 +770,90 @@ _messages = {
     "M822": QCoreApplication.translate(
         "MiscellaneousChecker",
         "mutable default argument of type {0}"),
+    "M823": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "mutable default argument of function call '{0}'"),
+    "M831": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "None should not be added at any return if function has no return"
+        " value except None"),
+    "M832": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "an explicit value at every return should be added if function has"
+        " a return value except None"),
+    "M833": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "an explicit return at the end of the function should be added if"
+        " it has a return value except None"),
+    "M834": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "a value should not be assigned to a variable if it will be used as a"
+        " return value only"),
+    "M841": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "prefer implied line continuation inside parentheses, "
+        "brackets and braces as opposed to a backslash"),
+    "M891": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "commented code lines should be removed"),
+    
     "M901": QCoreApplication.translate(
         "MiscellaneousChecker",
         "{0}: {1}"),
     
-    # CodeStyleFixer messages
+    
+    ##################################################################
+    ## Messages of the Annotations Checker
+    ##################################################################
+    "A001": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing type annotation for function argument '{0}'"),
+    "A002": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing type annotation for '*{0}'"),
+    "A003": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing type annotation for '**{0}'"),
+    "A101": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing type annotation for 'self' in method"),
+    "A102": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing type annotation for 'cls' in classmethod"),
+    "A201": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing return type annotation for public function"),
+    "A202": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing return type annotation for protected function"),
+    "A203": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing return type annotation for private function"),
+    "A204": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing return type annotation for special method"),
+    "A205": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing return type annotation for staticmethod"),
+    "A206": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "missing return type annotation for classmethod"),
+    
+    "A881": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "type annotation coverage of {0}% is too low"),
+    
+    "A891": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "type annotation is too complex ({0} > {1})"),
+    
+    "A999": QCoreApplication.translate(
+        "AnnotationsChecker",
+        "{0}: {1}"),
+    
+    ##################################################################
+    ## CodeStyleFixer messages
+    ##################################################################
     "FD111": QCoreApplication.translate(
         'CodeStyleFixer',
         "Triple single quotes converted to triple double quotes."),
@@ -642,9 +947,6 @@ _messages = {
     "FE261": QCoreApplication.translate(
         'CodeStyleFixer',
         "Whitespace around comment sign corrected."),
-    "FE301": QCoreApplication.translate(
-        'CodeStyleFixer',
-        "One blank line inserted."),
     
     "FE302+": lambda n=1: translate(
         'CodeStyleFixer',
@@ -709,10 +1011,16 @@ _messages_sample_args = {
     "E231": [",;:"],
     "E241": [",;:"],
     "E242": [",;:"],
-    "E302": [1],
-    "E303": [3],
-    "E305": [1],
+    "E301": [1, 0],
+    "E302": [2, 1],
+    "E303": [3, 2],
+    "E305": [2, 1],
+    "E306": [1, 0],
+    "E307": [3, 1],
+    "E308": [3],
     "E501": [85, 79],
+    "W505": [80, 72],
+    "E605": ["A"],
     "E711": ["None", "'if cond is None:'"],
     "E712": ["True", "'if cond is True:' or 'if cond:'"],
     "E741": ["l"],
@@ -720,20 +1028,31 @@ _messages_sample_args = {
     "E743": ["l"],
     "E901": ["SyntaxError", "Invalid Syntax"],
     "E902": ["IOError"],
+    
     "D232": ["public"],
     "D252": ["RuntimeError"],
     "D253": ["RuntimeError"],
     "D262": ["buttonClicked"],
     "D263": ["buttonClicked"],
     "D901": ["SyntaxError", "Invalid Syntax"],
+    
     "C101": ["foo.bar", "42"],
     "C111": [42],
     "C112": [12.0],
     "C901": ["SyntaxError", "Invalid Syntax"],
+    
     "M102": ["enc42"],
     "M131": ["list"],
     "M132": ["list"],
-    "M198": ["sorted"],
+    "M188": ["sorted"],
+    "M186": ["list"],
+    "M191": ["list", "set"],
+    "M192": ["list", "tuple"],
+    "M193": ["tuple", "list"],
+    "M197": ["tuple", "tuple"],
+    "M198": ["list", "list"],
+    "M201": ["bar", "foo"],
+    "M507": ["x"],
     "M601": ["%s"],
     "M621": [5],
     "M622": ["foo"],
@@ -741,9 +1060,19 @@ _messages_sample_args = {
     "M632": ["foo"],
     "M701": ["print_function, unicode_literals", "print_function"],
     "M702": ["print_function, unicode_literals"],
+    "M711": ["lgettext"],
     "M821": ["Dict"],
     "M822": ["Call"],
+    "M823": ["dict"],
     "M901": ["SyntaxError", "Invalid Syntax"],
+    
+    "A001": ["arg1"],
+    "A002": ["args"],
+    "A003": ["kwargs"],
+    "A881": [60],
+    "A891": [5, 3],
+    "A999": ["SyntaxError", "Invalid Syntax"],
+    
     "FWRITE_ERROR": ["IOError"],
 }
 
@@ -776,5 +1105,8 @@ def getTranslatedMessage(message):
         return message
     else:
         return QCoreApplication.translate(
-            "CodeStyleFixer", " no message defined for code '{0}'")\
-            .format(message)
+            "CodeStyleFixer", " no message defined for code '{0}'"
+        ).format(message)
+
+#
+# eflag: noqa = M201
