@@ -166,8 +166,9 @@ def syntaxAndPyflakesBatchCheck(argumentsList, send, fx, cancelled,
 
     # Start worker processes
     for _ in range(NumberOfProcesses):
-        multiprocessing.Process(target=worker, args=(taskQueue, doneQueue))\
-            .start()
+        multiprocessing.Process(
+            target=worker, args=(taskQueue, doneQueue)
+        ).start()
 
     # Get and send results
     endIndex = len(argumentsList) - initialTasks
@@ -333,8 +334,10 @@ def __syntaxAndPyflakesCheck(filename, codestring, checkFlakes=True,
                                               flagsLine=True)
             except IndexError:
                 pass
-            if "__IGNORE_WARNING__" not in lineFlags and \
-               "noqa" not in lineFlags:
+            if (
+                "__IGNORE_WARNING__" not in lineFlags and
+                "noqa" not in lineFlags
+            ):
                 results.append((_fn, lineno, col, "", message, msg_args))
     except SyntaxError as err:
         if err.text.strip():
