@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # pylint: disable=C0103
 
@@ -57,8 +57,9 @@ class SyntaxCheckService(QObject):
         if pyVer:
             return 'Python{0}'.format(pyVer)
         
-        for lang, (_env, _getArgs, getExt) in \
-                self.__supportedLanguages.items():
+        for lang, (_env, _getArgs, getExt) in (
+                self.__supportedLanguages.items()
+        ):
             if filename.endswith(tuple(getExt())):
                 return lang
         
@@ -93,7 +94,7 @@ class SyntaxCheckService(QObject):
         
         @return list of languanges supported (list of str)
         """
-        return list(self.__supportedLanguages.keys())
+        return list(self.__supportedLanguages.keys()) + ["MicroPython"]
 
     def removeLanguage(self, lang):
         """
@@ -131,6 +132,9 @@ class SyntaxCheckService(QObject):
             lang = self.__determineLanguage(filename, source)
         if lang not in self.getLanguages():
             return
+        if lang == "MicroPython":
+            lang = "Python3"
+        
         data = [source]
         # Call the getArgs function to get the required arguments
         env, args, getExt = self.__supportedLanguages[lang]
