@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # pylint: disable=C0103
 
@@ -53,13 +53,6 @@ def normalizeCode(codestring):
 
     if codestring and codestring[-1] != '\n':
         codestring = codestring + '\n'
-
-    # Check type for py2: if not str it's unicode
-#    if sys.version_info[0] == 2:
-#        try:
-#            codestring = codestring.encode('utf-8')
-#        except UnicodeError:
-#            pass
     
     return codestring
 
@@ -115,8 +108,9 @@ def jsSyntaxBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
 
     # Start worker processes
     for _ in range(NumberOfProcesses):
-        multiprocessing.Process(target=worker, args=(taskQueue, doneQueue))\
-            .start()
+        multiprocessing.Process(
+            target=worker, args=(taskQueue, doneQueue)
+        ).start()
 
     # Get and send results
     endIndex = len(argumentsList) - initialTasks
@@ -172,8 +166,8 @@ def __jsSyntaxCheck(file, codestring):
             (file name, line number, column, codestring (only at syntax
             errors), the message, a list with arguments for the message)
     """
-    import jasy.js.parse.Parser as jsParser
-    import jasy.js.tokenize.Tokenizer as jsTokenizer
+    import jasy.script.parse.Parser as jsParser
+    import jasy.script.tokenize.Tokenizer as jsTokenizer
     
     codestring = normalizeCode(codestring)
     
