@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing message translations for pyflakes warning messages.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import QCoreApplication
 
@@ -32,10 +31,14 @@ _messages = {
     'F06': QCoreApplication.translate(
         'pyFlakes',
         'Undefined name {0!r} in __all__.'),
-    'F07': QCoreApplication.translate(
+    'F07A': QCoreApplication.translate(
         'pyFlakes',
         "Local variable {0!r} (defined in enclosing scope on line {1!r})"
         " referenced before assignment."),
+    'F07B': QCoreApplication.translate(
+        'pyFlakes',
+        "Local variable {0!r} (defined as a builtin)"
+        " referenced before assignment."),
     'F08': QCoreApplication.translate(
         'pyFlakes',
         'Duplicate argument {0!r} in function definition.'),
@@ -89,7 +92,7 @@ _messages = {
         "'continue' not supported inside 'finally' clause"),
     'F25': QCoreApplication.translate(
         'pyFlakes',
-        "Default 'except:' must be last"),  # __IGNORE_WARNING__
+        "Default 'except:' must be last"),
     'F26': QCoreApplication.translate(
         'pyFlakes',
         "Two starred expressions in assignment"),
@@ -99,6 +102,21 @@ _messages = {
     'F28': QCoreApplication.translate(
         'pyFlakes',
         "Assertion is always true, perhaps remove parentheses?"),
+    'F29': QCoreApplication.translate(
+        'pyFlakes',
+        "syntax error in forward annotation {0!r}"),
+    'F30': QCoreApplication.translate(
+        'pyFlakes',
+        "'raise NotImplemented' should be 'raise NotImplementedError'"),
+    'F31': QCoreApplication.translate(
+        'pyFlakes',
+        "syntax error in type comment {0!r}"),
+    'F32': QCoreApplication.translate(
+        'pyFlakes',
+        "use of >> is invalid with print function"),
+    'F33': QCoreApplication.translate(
+        'pyFlakes',
+        "use ==/!= to compare str, bytes, and int literals"),
 }
 
 
@@ -118,5 +136,5 @@ def getTranslatedFlakesMessage(message_id, message_args):
         return msg.format(*message_args)
     else:
         return QCoreApplication.translate(
-            "pyFlakes", "no message defined for code '{0}'")\
-            .format(message_id)
+            "pyFlakes", "no message defined for code '{0}'"
+        ).format(message_id)
