@@ -37,7 +37,7 @@ from __future__ import unicode_literals
 #   linenumber and the error message (boolean, string, string, string). The
 #   values are only valid, if the status equals 1.
 #
-# Mofifications Copyright (c) 2003-2018 Detlev Offenbach
+# Mofifications Copyright (c) 2003-2019 Detlev Offenbach
 # <detlev@die-offenbachs.de>
 #
 
@@ -171,9 +171,10 @@ def batchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
         taskQueue.put(task)
 
     # Start worker processes
-    for i in range(NumberOfProcesses):
-        multiprocessing.Process(target=worker, args=(taskQueue, doneQueue))\
-            .start()
+    for _ in range(NumberOfProcesses):
+        multiprocessing.Process(
+            target=worker, args=(taskQueue, doneQueue)
+        ).start()
 
     # Get and send results
     endIndex = len(argumentsList) - initialTasks
@@ -201,7 +202,7 @@ def batchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
             taskQueue.put(argumentsList[i + initialTasks])
 
     # Tell child processes to stop
-    for i in range(NumberOfProcesses):
+    for _ in range(NumberOfProcesses):
         taskQueue.put('STOP')
 
 
@@ -331,19 +332,19 @@ class Whitespace(object):
         @param tabsize The length of a tab stop. (integer)
         @return indentation level (integer)
         """
-        # count, il = self.norm
-        # for i in range(len(count)):
-        #    if count[i]:
-        #        il = il + (i/tabsize + 1)*tabsize * count[i]
-        # return il
+        ## count, il = self.norm
+        ## for i in range(len(count)):
+        ##    if count[i]:
+        ##        il = il + (i/tabsize + 1)*tabsize * count[i]
+        ## return il
 
-        # quicker:
-        # il = trailing + sum (i/ts + 1)*ts*count[i] =
-        # trailing + ts * sum (i/ts + 1)*count[i] =
-        # trailing + ts * sum i/ts*count[i] + count[i] =
-        # trailing + ts * [(sum i/ts*count[i]) + (sum count[i])] =
-        # trailing + ts * [(sum i/ts*count[i]) + num_tabs]
-        # and note that i/ts*count[i] is 0 when i < ts
+        ## quicker:
+        ## il = trailing + sum (i/ts + 1)*ts*count[i] =
+        ## trailing + ts * sum (i/ts + 1)*count[i] =
+        ## trailing + ts * sum i/ts*count[i] + count[i] =
+        ## trailing + ts * [(sum i/ts*count[i]) + (sum count[i])] =
+        ## trailing + ts * [(sum i/ts*count[i]) + num_tabs]
+        ## and note that i/ts*count[i] is 0 when i < ts
 
         count, trailing = self.norm
         il = 0
@@ -475,7 +476,7 @@ def process_tokens(tokens):
     indents = [Whitespace("")]
     check_equal = 0
     
-    for (tokenType, token, start, end, line) in tokens:
+    for (tokenType, token, start, _end, line) in tokens:
         if tokenType == NEWLINE:
             # a program statement, or ENDMARKER, will eventually follow,
             # after some (possibly empty) run of tokens of the form
