@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the parameters for eric6_doc.
 """
 
-from __future__ import unicode_literals
 
 import sys
 import os
@@ -20,8 +19,9 @@ from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QColorDialog
 from E5Gui.E5PathPicker import E5PathPickerModes
 
 from .Ui_EricdocConfigDialog import Ui_EricdocConfigDialog
-from DocumentationTools.Config import eric6docDefaultColors, \
-    eric6docColorParameterNames
+from DocumentationTools.Config import (
+    eric6docDefaultColors, eric6docColorParameterNames
+)
 import Utilities
 
 from eric6config import getConfig
@@ -93,13 +93,16 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
                     self.colors[key] = parms[key]
                 else:
                     self.parameters[key] = parms[key]
-        self.parameters['outputDirectory'] = \
-            Utilities.toNativeSeparators(self.parameters['outputDirectory'])
-        self.parameters['qtHelpOutputDirectory'] = \
+        self.parameters['outputDirectory'] = Utilities.toNativeSeparators(
+            self.parameters['outputDirectory']
+        )
+        self.parameters['qtHelpOutputDirectory'] = (
             Utilities.toNativeSeparators(
                 self.parameters['qtHelpOutputDirectory'])
-        self.parameters['cssFile'] = \
-            Utilities.toNativeSeparators(self.parameters['cssFile'])
+        )
+        self.parameters['cssFile'] = Utilities.toNativeSeparators(
+            self.parameters['cssFile']
+        )
         if self.parameters['cssFile'].startswith("%PYTHON%"):
             self.parameters['cssFile'] = self.parameters['cssFile'].replace(
                 "%PYTHON%", Utilities.getPythonModulesDirectory())
@@ -182,8 +185,10 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         
         # 2. the commandline options
         # 2a. general commandline options
-        if self.parameters['outputDirectory'] != \
-                self.defaults['outputDirectory']:
+        if (
+            self.parameters['outputDirectory'] !=
+            self.defaults['outputDirectory']
+        ):
             parms['outputDirectory'] = Utilities.fromNativeSeparators(
                 self.project.getRelativePath(
                     self.parameters['outputDirectory']))
@@ -194,20 +199,27 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
                 args.append(os.path.join(
                     self.ppath, self.parameters['outputDirectory']))
         else:
-            self.parameters['outputDirectory'] = \
+            self.parameters['outputDirectory'] = (
                 self.defaults['outputDirectory']
+            )
             parms['outputDirectory'] = self.parameters['outputDirectory']
-        if self.parameters['ignoreDirectories'] != \
-                self.defaults['ignoreDirectories']:
-            parms['ignoreDirectories'] = \
+        if (
+            self.parameters['ignoreDirectories'] !=
+            self.defaults['ignoreDirectories']
+        ):
+            parms['ignoreDirectories'] = (
                 self.parameters['ignoreDirectories'][:]
+            )
             for d in self.parameters['ignoreDirectories']:
                 args.append('-x')
                 args.append(d)
-        if self.parameters['ignoreFilePatterns'] != \
-                self.defaults['ignoreFilePatterns']:
-            parms['ignoreFilePatterns'] = \
+        if (
+            self.parameters['ignoreFilePatterns'] !=
+            self.defaults['ignoreFilePatterns']
+        ):
+            parms['ignoreFilePatterns'] = (
                 self.parameters['ignoreFilePatterns'][:]
+            )
             for pattern in self.parameters['ignoreFilePatterns']:
                 if pattern.strip():
                     args.append("--exclude-file={0}".format(pattern.strip()))
@@ -220,8 +232,10 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         if self.parameters['noempty'] != self.defaults['noempty']:
             parms['noempty'] = self.parameters['noempty']
             args.append('-e')
-        if self.parameters['sourceExtensions'] != \
-                self.defaults['sourceExtensions']:
+        if (
+            self.parameters['sourceExtensions'] !=
+            self.defaults['sourceExtensions']
+        ):
             parms['sourceExtensions'] = self.parameters['sourceExtensions'][:]
             for ext in self.parameters['sourceExtensions']:
                 if ext.strip():
@@ -250,8 +264,10 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         parms['qtHelpEnabled'] = self.parameters['qtHelpEnabled']
         if self.parameters['qtHelpEnabled']:
             args.append('--create-qhp')
-        if self.parameters['qtHelpOutputDirectory'] != \
-           self.defaults['qtHelpOutputDirectory']:
+        if (
+            self.parameters['qtHelpOutputDirectory'] !=
+            self.defaults['qtHelpOutputDirectory']
+        ):
             parms['qtHelpOutputDirectory'] = Utilities.fromNativeSeparators(
                 self.project.getRelativePath(
                     self.parameters['qtHelpOutputDirectory']))
@@ -262,36 +278,49 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
                 args.append("--qhp-outdir={0}".format(
                     os.path.join(self.ppath,
                                  self.parameters['qtHelpOutputDirectory'])))
-        if self.parameters['qtHelpNamespace'] != \
-                self.defaults['qtHelpNamespace']:
+        if (
+            self.parameters['qtHelpNamespace'] !=
+            self.defaults['qtHelpNamespace']
+        ):
             parms['qtHelpNamespace'] = self.parameters['qtHelpNamespace']
             args.append("--qhp-namespace={0}".format(
                 self.parameters['qtHelpNamespace']))
-        if self.parameters['qtHelpVirtualFolder'] != \
-                self.defaults['qtHelpVirtualFolder']:
-            parms['qtHelpVirtualFolder'] = \
+        if (
+            self.parameters['qtHelpVirtualFolder'] !=
+            self.defaults['qtHelpVirtualFolder']
+        ):
+            parms['qtHelpVirtualFolder'] = (
                 self.parameters['qtHelpVirtualFolder']
+            )
             args.append("--qhp-virtualfolder={0}".format(
                 self.parameters['qtHelpVirtualFolder']))
-        if self.parameters['qtHelpFilterName'] != \
-                self.defaults['qtHelpFilterName']:
+        if (
+            self.parameters['qtHelpFilterName'] !=
+            self.defaults['qtHelpFilterName']
+        ):
             parms['qtHelpFilterName'] = self.parameters['qtHelpFilterName']
             args.append("--qhp-filtername={0}".format(
                 self.parameters['qtHelpFilterName']))
-        if self.parameters['qtHelpFilterAttributes'] != \
-           self.defaults['qtHelpFilterAttributes']:
-            parms['qtHelpFilterAttributes'] = \
+        if (
+            self.parameters['qtHelpFilterAttributes'] !=
+            self.defaults['qtHelpFilterAttributes']
+        ):
+            parms['qtHelpFilterAttributes'] = (
                 self.parameters['qtHelpFilterAttributes']
+            )
             args.append("--qhp-filterattribs={0}".format(
                 self.parameters['qtHelpFilterAttributes']))
         if self.parameters['qtHelpTitle'] != self.defaults['qtHelpTitle']:
             parms['qtHelpTitle'] = self.parameters['qtHelpTitle']
             args.append("--qhp-title={0}".format(
                 self.parameters['qtHelpTitle']))
-        if self.parameters['qtHelpCreateCollection'] != \
-           self.defaults['qtHelpCreateCollection']:
-            parms['qtHelpCreateCollection'] = \
+        if (
+            self.parameters['qtHelpCreateCollection'] !=
+            self.defaults['qtHelpCreateCollection']
+        ):
+            parms['qtHelpCreateCollection'] = (
                 self.parameters['qtHelpCreateCollection']
+            )
             args.append('--create-qhc')
         
         return (args, parms)
@@ -526,22 +555,26 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
             cssFile = os.path.normpath(cssFile)
         self.parameters['cssFile'] = cssFile
         extensions = self.sourceExtEdit.text().split(',')
-        self.parameters['sourceExtensions'] = \
-            [ext.strip() for ext in extensions if ext.strip()]
+        self.parameters['sourceExtensions'] = [
+            ext.strip() for ext in extensions if ext.strip()
+        ]
         patterns = self.excludeFilesEdit.text().split(',')
-        self.parameters['ignoreFilePatterns'] = \
-            [pattern.strip() for pattern in patterns if pattern.strip()]
+        self.parameters['ignoreFilePatterns'] = [
+            pattern.strip() for pattern in patterns if pattern.strip()
+        ]
         
         self.parameters['qtHelpEnabled'] = self.qtHelpGroup.isChecked()
         self.parameters['qtHelpOutputDirectory'] = self.qtHelpDirPicker.text()
         self.parameters['qtHelpNamespace'] = self.qtHelpNamespaceEdit.text()
         self.parameters['qtHelpVirtualFolder'] = self.qtHelpFolderEdit.text()
         self.parameters['qtHelpFilterName'] = self.qtHelpFilterNameEdit.text()
-        self.parameters['qtHelpFilterAttributes'] = \
+        self.parameters['qtHelpFilterAttributes'] = (
             self.qtHelpFilterAttributesEdit.text()
+        )
         self.parameters['qtHelpTitle'] = self.qtHelpTitleEdit.text()
-        self.parameters['qtHelpCreateCollection'] = \
+        self.parameters['qtHelpCreateCollection'] = (
             self.qtHelpGenerateCollectionCheckBox.isChecked()
+        )
         
         # call the accept slot of the base class
         super(EricdocConfigDialog, self).accept()
