@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the code style checker plug-in.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -19,24 +18,26 @@ from Project.ProjectBrowserModel import ProjectBrowserFileItem
 from Utilities import determinePythonVersion
 
 import Preferences
+import UI.Info
 
 # Start-Of-Header
 name = "Code Style Checker Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "6.1.0"
+version = UI.Info.VersionOnly
 className = "CodeStyleCheckerPlugin"
 packageName = "__core__"
 shortDescription = "Show the Python Code Style Checker dialog."
-longDescription = """This plugin implements the Python Code Style""" \
-    """ Checker dialog. A PEP-8 checker is used to check Python source""" \
-    """ files for compliance to the code style conventions given in PEP-8.""" \
-    """ A PEP-257 checker is used to check Python source files for""" \
-    """ compliance to docstring conventions given in PEP-257 and an""" \
+longDescription = (
+    """This plugin implements the Python Code Style"""
+    """ Checker dialog. A PEP-8 checker is used to check Python source"""
+    """ files for compliance to the code style conventions given in PEP-8."""
+    """ A PEP-257 checker is used to check Python source files for"""
+    """ compliance to docstring conventions given in PEP-257 and an"""
     """ eric6 variant is used to check against eric conventions."""
+)
 pyqtApi = 2
-python2Compatible = True
 # End-Of-Header
 
 
@@ -160,14 +161,19 @@ class CodeStyleCheckerPlugin(QObject):
         Public method to prepare a style check on one Python source file.
 
         @param lang language of the file or None to determine by internal
-            algorithm (str or None)
-        @param filename source filename (string)
-        @param source string containing the code to check (string)
+            algorithm
+        @type str or None
+        @param filename source filename
+        @type str
+        @param source string containing the code to check
+        @type str
         @param args arguments used by the codeStyleCheck function (list of
-            excludeMessages (str), includeMessages (str), repeatMessages
-            (bool), fixCodes (str), noFixCodes (str), fixIssues (bool),
-            maxLineLength (int), hangClosing (bool), docType (str), errors
-            (list of str), eol (str), encoding (str))
+            excludeMessages, includeMessages, repeatMessages, fixCodes,
+            noFixCodes, fixIssues, maxLineLength, blankLines, hangClosing,
+            docType, codeComplexityArgs, miscellaneousArgs, errors, eol,
+            encoding, backup)
+        @type list of (str, str, bool, str, str, bool, int, list of (int, int),
+            bool, str, dict, dict, list of str, str, str, bool)
         """
         if lang is None:
             lang = 'Python{0}'.format(determinePythonVersion(filename, source))
@@ -184,6 +190,7 @@ class CodeStyleCheckerPlugin(QObject):
         @param argumentsList list of arguments tuples with each tuple
             containing filename, source and args as given in styleCheck()
             method
+        @type list of tuple of (str, str, list)
         """
         data = {
             "Python2": [],
@@ -221,8 +228,9 @@ class CodeStyleCheckerPlugin(QObject):
             lineno (int), position (int), text (str), fixed (bool),
             autofixing (bool), fixedMsg (str))
         """
-        from CheckerPlugins.CodeStyleChecker.translations import \
+        from CheckerPlugins.CodeStyleChecker.translations import (
             getTranslatedMessage
+        )
         
         fixes = 0
         for result in results:
@@ -275,8 +283,8 @@ class CodeStyleCheckerPlugin(QObject):
         self.__editorAct.triggered.connect(self.__editorCodeStyleCheck)
         
         e5App().getObject("Project").showMenu.connect(self.__projectShowMenu)
-        e5App().getObject("ProjectBrowser").getProjectBrowser("sources")\
-            .showMenu.connect(self.__projectBrowserShowMenu)
+        e5App().getObject("ProjectBrowser").getProjectBrowser(
+            "sources").showMenu.connect(self.__projectBrowserShowMenu)
         e5App().getObject("ViewManager").editorOpenedEd.connect(
             self.__editorOpened)
         e5App().getObject("ViewManager").editorClosedEd.connect(
@@ -293,8 +301,8 @@ class CodeStyleCheckerPlugin(QObject):
         """
         e5App().getObject("Project").showMenu.disconnect(
             self.__projectShowMenu)
-        e5App().getObject("ProjectBrowser").getProjectBrowser("sources")\
-            .showMenu.disconnect(self.__projectBrowserShowMenu)
+        e5App().getObject("ProjectBrowser").getProjectBrowser(
+            "sources").showMenu.disconnect(self.__projectBrowserShowMenu)
         e5App().getObject("ViewManager").editorOpenedEd.disconnect(
             self.__editorOpened)
         e5App().getObject("ViewManager").editorClosedEd.disconnect(
@@ -328,7 +336,7 @@ class CodeStyleCheckerPlugin(QObject):
         if menuName == "Checks" and self.__projectAct is not None:
             self.__projectAct.setEnabled(
                 e5App().getObject("Project").getProjectLanguage() in
-                ["Python3", "Python2", "Python"])
+                ["Python3", "Python2", "Python", "MicroPython"])
     
     def __projectBrowserShowMenu(self, menuName, menu):
         """
@@ -338,9 +346,11 @@ class CodeStyleCheckerPlugin(QObject):
         @param menuName name of the menu to be shown (string)
         @param menu reference to the menu (QMenu)
         """
-        if menuName == "Checks" and \
-           e5App().getObject("Project").getProjectLanguage() in \
-                ["Python3", "Python2", "Python"]:
+        if (
+            menuName == "Checks" and
+            e5App().getObject("Project").getProjectLanguage() in
+                ["Python3", "Python2", "Python", "MicroPython"]
+        ):
             self.__projectBrowserMenu = menu
             if self.__projectBrowserAct is None:
                 self.__projectBrowserAct = E5Action(
@@ -370,9 +380,10 @@ class CodeStyleCheckerPlugin(QObject):
                      tuple(Preferences.getPython("Python3Extensions")) +
                      tuple(Preferences.getPython("PythonExtensions")))]
         
-        from CheckerPlugins.CodeStyleChecker.CodeStyleCheckerDialog import \
-            CodeStyleCheckerDialog
-        self.__projectCodeStyleCheckerDialog = CodeStyleCheckerDialog(self)
+        from CheckerPlugins.CodeStyleChecker import CodeStyleCheckerDialog
+        self.__projectCodeStyleCheckerDialog = (
+            CodeStyleCheckerDialog.CodeStyleCheckerDialog(self)
+        )
         self.__projectCodeStyleCheckerDialog.show()
         self.__projectCodeStyleCheckerDialog.prepare(files, project)
     
@@ -381,8 +392,9 @@ class CodeStyleCheckerPlugin(QObject):
         Private method to handle the code style check context menu action of
         the project sources browser.
         """
-        browser = e5App().getObject("ProjectBrowser")\
-            .getProjectBrowser("sources")
+        browser = (
+            e5App().getObject("ProjectBrowser").getProjectBrowser("sources")
+        )
         if browser.getSelectedItemsCount([ProjectBrowserFileItem]) > 1:
             fn = []
             for itm in browser.getSelectedItems([ProjectBrowserFileItem]):
@@ -397,10 +409,10 @@ class CodeStyleCheckerPlugin(QObject):
                 fn = itm.dirName()
                 isDir = True
         
-        from CheckerPlugins.CodeStyleChecker.CodeStyleCheckerDialog import \
-            CodeStyleCheckerDialog
-        self.__projectBrowserCodeStyleCheckerDialog = CodeStyleCheckerDialog(
-            self)
+        from CheckerPlugins.CodeStyleChecker import CodeStyleCheckerDialog
+        self.__projectBrowserCodeStyleCheckerDialog = (
+            CodeStyleCheckerDialog.CodeStyleCheckerDialog(self)
+        )
         self.__projectBrowserCodeStyleCheckerDialog.show()
         if isDir:
             self.__projectBrowserCodeStyleCheckerDialog.start(
@@ -454,10 +466,12 @@ class CodeStyleCheckerPlugin(QObject):
         editor = e5App().getObject("ViewManager").activeWindow()
         if editor is not None:
             if editor.checkDirty() and editor.getFileName() is not None:
-                from CheckerPlugins.CodeStyleChecker.CodeStyleCheckerDialog \
-                    import CodeStyleCheckerDialog
-                self.__editorCodeStyleCheckerDialog = CodeStyleCheckerDialog(
-                    self)
+                from CheckerPlugins.CodeStyleChecker import (
+                    CodeStyleCheckerDialog
+                )
+                self.__editorCodeStyleCheckerDialog = (
+                    CodeStyleCheckerDialog.CodeStyleCheckerDialog(self)
+                )
                 self.__editorCodeStyleCheckerDialog.show()
                 self.__editorCodeStyleCheckerDialog.start(
                     editor.getFileName(),
