@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Translator plugin.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -30,12 +29,12 @@ version = UI.Info.VersionOnly
 className = "TranslatorPlugin"
 packageName = "__core__"
 shortDescription = "Translation utility using various translators."
-longDescription = \
-    """This plug-in implements a utility to translate text using""" \
+longDescription = (
+    """This plug-in implements a utility to translate text using"""
     """ various online translation services."""
+)
 needsRestart = False
 pyqtApi = 2
-python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -50,9 +49,8 @@ def createTranslatorPage(configDlg):
     @param configDlg reference to the configuration dialog
     @return reference to the configuration page
     """
-    from UiExtensionPlugins.Translator.ConfigurationPage.TranslatorPage \
-        import TranslatorPage
-    page = TranslatorPage(translatorPluginObject)
+    from UiExtensionPlugins.Translator.ConfigurationPage import TranslatorPage
+    page = TranslatorPage.TranslatorPage(translatorPluginObject)
     return page
     
 
