@@ -7,7 +7,6 @@
 Module implementing the Git version control plugin.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -34,10 +33,10 @@ pluginTypename = "Git"
 className = "VcsGitPlugin"
 packageName = "__core__"
 shortDescription = "Implements the Git version control interface."
-longDescription = \
+longDescription = (
     """This plugin provides the Git version control interface."""
+)
 pyqtApi = 2
-python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -113,8 +112,9 @@ def createConfigurationPage(configDlg):
     @return reference to the configuration page
     """
     global gitCfgPluginObject
-    from VcsPlugins.vcsGit.ConfigurationPage.GitPage import \
+    from VcsPlugins.vcsGit.ConfigurationPage.GitPage import (
         GitPage
+    )
     if gitCfgPluginObject is None:
         gitCfgPluginObject = VcsGitPlugin(None)
     page = GitPage(gitCfgPluginObject)
