@@ -7,7 +7,6 @@
 Module implementing the PySvn version control plugin.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -32,10 +31,10 @@ pluginTypename = "PySvn"
 className = "VcsPySvnPlugin"
 packageName = "__core__"
 shortDescription = "Implements the PySvn version control interface."
-longDescription = \
+longDescription = (
     """This plugin provides the PySvn version control interface."""
+)
 pyqtApi = 2
-python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -107,8 +106,9 @@ def createConfigurationPage(configDlg):
     @return reference to the configuration page
     """
     global subversionCfgPluginObject
-    from VcsPlugins.vcsPySvn.ConfigurationPage.SubversionPage import \
+    from VcsPlugins.vcsPySvn.ConfigurationPage.SubversionPage import (
         SubversionPage
+    )
     if subversionCfgPluginObject is None:
         subversionCfgPluginObject = VcsPySvnPlugin(None)
     page = SubversionPage(subversionCfgPluginObject)
