@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Tabview view manager plugin.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -30,7 +29,6 @@ packageName = "__core__"
 shortDescription = "Implements the Tabview view manager."
 longDescription = """This plugin provides the tabbed view view manager."""
 pyqtApi = 2
-python2Compatible = True
 # End-Of-Header
 
 error = ""
