@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the QRegExp wizard plugin.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import QObject
 from PyQt5.QtWidgets import QDialog
@@ -29,7 +28,6 @@ packageName = "__core__"
 shortDescription = "Show the QRegExp wizard."
 longDescription = """This plugin shows the QRegExp wizard."""
 pyqtApi = 2
-python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -102,8 +100,9 @@ class QRegExpWizard(QObject):
         @param editor reference to the current editor
         @return the generated code (string)
         """
-        from WizardPlugins.QRegExpWizard.QRegExpWizardDialog import \
+        from WizardPlugins.QRegExpWizard.QRegExpWizardDialog import (
             QRegExpWizardDialog
+        )
         dlg = QRegExpWizardDialog(None, True)
         if dlg.exec_() == QDialog.Accepted:
             line, index = editor.getCursorPosition()
