@@ -7,7 +7,6 @@
 Module implementing the Google V1 translation engine.
 """
 
-from __future__ import unicode_literals
 
 import json
 import re
@@ -84,8 +83,10 @@ class GoogleV1Engine(TranslationEngine):
         params = QByteArray(
             "client=gtx&sl={0}&tl={1}&dt=t&dt=bd&ie=utf-8&oe=utf-8&q=".format(
                 originalLanguage, translationLanguage).encode("utf-8"))
-        encodedText = QByteArray(Utilities.html_encode(text).encode("utf-8"))\
+        encodedText = (
+            QByteArray(Utilities.html_encode(text).encode("utf-8"))
             .toPercentEncoding()
+        )
         request = params + encodedText
         response, ok = requestObject.post(QUrl(self.TranslatorUrl), request)
         if ok:
@@ -102,8 +103,10 @@ class GoogleV1Engine(TranslationEngine):
                 for sentence in sentences:
                     result += sentence["trans"].replace("\n", "<br/>")
                 
-                if self.plugin.getPreferences("GoogleEnableDictionary") and \
-                        "dict" in responseDict:
+                if (
+                    self.plugin.getPreferences("GoogleEnableDictionary") and
+                    "dict" in responseDict
+                ):
                     dictionary = responseDict["dict"]
                     for value in dictionary:
                         result += "<hr/><u><b>{0}</b> - {1}</u><br/>".format(
@@ -121,10 +124,13 @@ class GoogleV1Engine(TranslationEngine):
                             result += "<br/>"
             elif isinstance(responseDict, list):
                 sentences = responseDict[0]
-                result = "".join([s[0] for s in sentences])\
-                    .replace("\n", "<br/>")
-                if self.plugin.getPreferences("GoogleEnableDictionary") and \
-                        len(responseDict) > 2:
+                result = (
+                    "".join([s[0] for s in sentences]).replace("\n", "<br/>")
+                )
+                if (
+                    self.plugin.getPreferences("GoogleEnableDictionary") and
+                    len(responseDict) > 2
+                ):
                     if not responseDict[1]:
                         result = self.tr("No translation found.")
                         ok = False
