@@ -8,20 +8,14 @@ Module implementing a synchronous network request handler for translation
 requests.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 from PyQt5.QtCore import QObject, QEventLoop, QByteArray
-from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
-    QNetworkReply
+from PyQt5.QtNetwork import (
+    QNetworkAccessManager, QNetworkRequest, QNetworkReply
+)
 
 from E5Network.E5NetworkProxyFactory import proxyAuthenticationRequired
 
-from Globals import qVersionTuple
-
 
 class TranslatorRequest(QObject):
     """
@@ -58,9 +52,7 @@ class TranslatorRequest(QObject):
         @return server response (QByteArray) or error message (string)
         """
         request = QNetworkRequest(requestUrl)
-        if qVersionTuple() >= (5, 6, 0):
-            request.setAttribute(QNetworkRequest.FollowRedirectsAttribute,
-                                 True)
+        request.setAttribute(QNetworkRequest.FollowRedirectsAttribute, True)
         if extraHeaders:
             for name, value in extraHeaders:
                 request.setRawHeader(name, value)
@@ -92,9 +84,7 @@ class TranslatorRequest(QObject):
                              self.__contentTypes[dataType])
         request.setRawHeader(b"Content-Length",
                              QByteArray.number(requestData.size()))
-        if qVersionTuple() >= (5, 6, 0):
-            request.setAttribute(QNetworkRequest.FollowRedirectsAttribute,
-                                 True)
+        request.setAttribute(QNetworkRequest.FollowRedirectsAttribute, True)
         if extraHeaders:
             for name, value in extraHeaders:
                 request.setRawHeader(name, value)
