@@ -7,7 +7,6 @@
 Module implementing a dialog to enter data for a Fetch operation.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox
@@ -106,8 +105,10 @@ class GitFetchDialog(QDialog, Ui_GitFetchDialog):
         """
         self.__updateButtonEnable()
         
-        if self.remotesComboBox.currentText() == self.__custom and \
-                txt != "":
+        if (
+            self.remotesComboBox.currentText() == self.__custom and
+            txt != ""
+        ):
             remoteBranches = self.__vcs.gitGetRemoteBranchesList(
                 self.__repodir, txt)
             self.remoteBranchesList.clear()
