@@ -1,36 +1,36 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to browse the log history.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import os
 import collections
 
-from PyQt5.QtCore import pyqtSlot, qVersion, Qt, QDate, QProcess, QTimer, \
-    QRegExp, QSize, QPoint, QFileInfo
-from PyQt5.QtGui import QCursor, QColor, QPixmap, QPainter, QPen, QIcon, \
-    QTextCursor
-from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QHeaderView, \
-    QTreeWidgetItem, QApplication, QLineEdit, QMenu, QInputDialog, QToolTip
+from PyQt5.QtCore import (
+    pyqtSlot, Qt, QDate, QProcess, QTimer, QRegExp, QSize, QPoint, QFileInfo
+)
+from PyQt5.QtGui import (
+    QCursor, QColor, QPixmap, QPainter, QPen, QIcon, QTextCursor
+)
+from PyQt5.QtWidgets import (
+    QWidget, QDialogButtonBox, QHeaderView, QTreeWidgetItem, QApplication,
+    QLineEdit, QMenu, QInputDialog
+)
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox, E5FileDialog
 
+from Globals import strToQByteArray
+
 from .Ui_GitLogBrowserDialog import Ui_GitLogBrowserDialog
 
 from .GitDiffHighlighter import GitDiffHighlighter
 from .GitDiffGenerator import GitDiffGenerator
-from .GitUtilities import strToQByteArray
 
 import UI.PixmapCache
 import Preferences
@@ -304,10 +304,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         """
         self.__actionsMenu = QMenu()
         self.__actionsMenu.setTearOffEnabled(True)
-        if qVersion() >= "5.1.0":
-            self.__actionsMenu.setToolTipsVisible(True)
-        else:
-            self.__actionsMenu.hovered.connect(self.__actionsMenuHovered)
+        self.__actionsMenu.setToolTipsVisible(True)
         
         self.__cherryAct = self.__actionsMenu.addAction(
             self.tr("Copy Commits"), self.__cherryActTriggered)
@@ -350,17 +347,6 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             UI.PixmapCache.getIcon("actionsToolButton.png"))
         self.actionsButton.setMenu(self.__actionsMenu)
     
-    def __actionsMenuHovered(self, action):
-        """
-        Private slot to show the tooltip for an action menu entry.
-        
-        @param action action to show tooltip for
-        @type QAction
-        """
-        QToolTip.showText(
-            QCursor.pos(), action.toolTip(),
-            self.__actionsMenu, self.__actionsMenu.actionGeometry(action))
-    
     def __initData(self):
         """
         Private method to (re-)initialize some data.
@@ -390,8 +376,10 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         
         @param e close event (QCloseEvent)
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -733,10 +721,11 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
                 self.__childrenInfo[parent].append(commitId)
         
         if self.logTree.topLevelItemCount() > 1:
-            topedges = \
+            topedges = (
                 self.logTree.topLevelItem(
-                    self.logTree.indexOfTopLevelItem(itm) - 1)\
+                    self.logTree.indexOfTopLevelItem(itm) - 1)
                 .data(0, self.__edgesRole)
+            )
         else:
             topedges = None
         
@@ -889,8 +878,10 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -924,8 +915,10 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         )
         for date in [logEntry["authordate"], logEntry["committerdate"]]:
             dt = QDate.fromString(date, Qt.ISODate)
-            if not self.__maxDate.isValid() and \
-               not self.__minDate.isValid():
+            if (
+                not self.__maxDate.isValid() and
+                not self.__minDate.isValid()
+            ):
                 self.__maxDate = dt
                 self.__minDate = dt
             else:
@@ -1195,7 +1188,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             fieldIndex = self.CommitIdColumn
             txt = self.rxEdit.text()
             if txt.startswith("^"):
-                searchRx = QRegExp("^\s*{0}".format(txt[1:]),
+                searchRx = QRegExp(r"^\s*{0}".format(txt[1:]),
                                    Qt.CaseInsensitive)
             else:
                 searchRx = QRegExp(txt, Qt.CaseInsensitive)
@@ -1235,9 +1228,11 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
                         txt = topItem.data(0, self.__subjectRole)
                 else:
                     txt = topItem.text(fieldIndex)
-                if topItem.text(self.DateColumn) <= to_ and \
-                   topItem.text(self.DateColumn) >= from_ and \
-                   searchRx.indexIn(txt) > -1:
+                if (
+                    topItem.text(self.DateColumn) <= to_ and
+                    topItem.text(self.DateColumn) >= from_ and
+                    searchRx.indexIn(txt) > -1
+                ):
                     topItem.setHidden(False)
                     if topItem is currentItem:
                         self.on_logTree_currentItemChanged(topItem, None)
@@ -1326,8 +1321,9 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             index2 = self.logTree.indexOfTopLevelItem(selectedItems[1])
             if index1 > index2:
                 # Swap the entries
-                selectedItems[0], selectedItems[1] = \
+                selectedItems[0], selectedItems[1] = (
                     selectedItems[1], selectedItems[0]
+                )
             html = "{0}<hr/>{1}".format(
                 self.__generateDetailsTableText(selectedItems[0]),
                 self.__generateDetailsTableText(selectedItems[1]),
@@ -1839,8 +1835,10 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             res, shouldReopen = self.vcs.gitBranch(
                 self.repodir, revision=commit, branchName=branch,
                 branchOp=GitBranchDialog.CreateSwitchBranch)
-            shouldReopen = shouldReopen or \
+            shouldReopen = (
+                shouldReopen or
                 QFileInfo(pfile).lastModified().toString() != lastModified
+            )
             if res:
                 if shouldReopen:
                     res = E5MessageBox.yesNo(
