@@ -7,26 +7,22 @@
 Module implementing a dialog to show the stashes.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import os
 
 from PyQt5.QtCore import pyqtSlot, Qt, QPoint, QProcess, QTimer
 from PyQt5.QtGui import QCursor
-from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QTreeWidgetItem, \
-    QAbstractButton, QMenu, QHeaderView, QApplication, QLineEdit
+from PyQt5.QtWidgets import (
+    QWidget, QDialogButtonBox, QTreeWidgetItem, QAbstractButton, QMenu,
+    QHeaderView, QApplication, QLineEdit
+)
 
 from E5Gui import E5MessageBox
 
 from .Ui_GitStashBrowserDialog import Ui_GitStashBrowserDialog
 
-from .GitUtilities import strToQByteArray
-
 import Preferences
+from Globals import strToQByteArray
 
 
 class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
@@ -101,8 +97,10 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         
         @param e close event (QCloseEvent)
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -227,8 +225,10 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -337,8 +337,9 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
                     totals = {"files": 0, "additions": 0, "deletions": 0}
                     fileData = []
                     for line in output.splitlines():
-                        additions, deletions, name = \
+                        additions, deletions, name = (
                             line.strip().split(None, 2)
+                        )
                         totals["files"] += 1
                         if additions != "-":
                             totals["additions"] += int(additions)
