@@ -1,18 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing some common utility functions for the Git package.
 """
 
-from __future__ import unicode_literals
 
 import os
-import sys
 
-from PyQt5.QtCore import QProcessEnvironment, QByteArray
+from PyQt5.QtCore import QProcessEnvironment
 
 import Utilities
 
@@ -45,23 +43,3 @@ def prepareProcess(proc, language=""):
         env.insert("LANGUAGE", language)
     
     proc.setProcessEnvironment(env)
-
-
-try:
-    from Globals import strToQByteArray
-except ImportError:
-    def strToQByteArray(txt):
-        """
-        Module function to convert a Python string into a QByteArray.
-        
-        @param txt Python string to be converted
-        @type str, bytes, bytearray, unicode
-        """
-        if sys.version_info[0] == 2:
-            if isinstance(txt, unicode):    # __IGNORE_WARNING__
-                txt = txt.encode("utf-8")
-        else:
-            if isinstance(txt, str):
-                txt = txt.encode("utf-8")
-        
-        return QByteArray(txt)
