@@ -7,12 +7,12 @@
 Module implementing the Mercurial configuration page.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot
 
-from Preferences.ConfigurationPages.ConfigurationPageBase import \
+from Preferences.ConfigurationPages.ConfigurationPageBase import (
     ConfigurationPageBase
+)
 from .Ui_MercurialPage import Ui_MercurialPage
 
 from Utilities import supportedCodecs
