@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the fetch extension project helper.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtWidgets import QMenu
 
@@ -87,8 +86,8 @@ class FetchProjectHelper(HgExtensionProjectHelper):
         """
         Private slot used to fetch changes from a remote repository.
         """
-        shouldReopen = self.vcs.getExtensionObject("fetch")\
-            .hgFetch(self.project.getProjectPath())
+        shouldReopen = self.vcs.getExtensionObject("fetch").hgFetch(
+            self.project.getProjectPath())
         if shouldReopen:
             res = E5MessageBox.yesNo(
                 None,
