@@ -7,18 +7,15 @@
 Module implementing a dialog showing signed changesets.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import os
 
-from PyQt5.QtCore import pyqtSlot, QProcess, QTimer, Qt, QRegExp, \
-    QCoreApplication
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QHeaderView, \
-    QTreeWidgetItem, QLineEdit
+from PyQt5.QtCore import (
+    pyqtSlot, QProcess, QTimer, Qt, QRegExp, QCoreApplication
+)
+from PyQt5.QtWidgets import (
+    QDialog, QDialogButtonBox, QHeaderView, QTreeWidgetItem, QLineEdit
+)
 
 from E5Gui import E5MessageBox
 
@@ -66,8 +63,10 @@ class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
             if self.__hgClient.isExecuting():
                 self.__hgClient.cancel()
         else:
-            if self.process is not None and \
-               self.process.state() != QProcess.NotRunning:
+            if (
+                self.process is not None and
+                self.process.state() != QProcess.NotRunning
+            ):
                 self.process.terminate()
                 QTimer.singleShot(2000, self.process.kill)
                 self.process.waitForFinished(3000)
@@ -135,8 +134,10 @@ class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -277,8 +278,10 @@ class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
         Private slot handling changes of the selection.
         """
         selectedItems = self.signaturesList.selectedItems()
-        if len(selectedItems) == 1 and \
-           self.signaturesList.indexOfTopLevelItem(selectedItems[0]) != -1:
+        if (
+            len(selectedItems) == 1 and
+            self.signaturesList.indexOfTopLevelItem(selectedItems[0]) != -1
+        ):
             self.verifyButton.setEnabled(True)
         else:
             self.verifyButton.setEnabled(False)
@@ -288,10 +291,12 @@ class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
         """
         Private slot to verify the signatures of the selected revision.
         """
-        rev = self.signaturesList.selectedItems()[0].text(0)\
+        rev = (
+            self.signaturesList.selectedItems()[0].text(0)
             .split(":")[0].strip()
-        self.vcs.getExtensionObject("gpg")\
-            .hgGpgVerifySignatures(self.__path, rev)
+        )
+        self.vcs.getExtensionObject("gpg").hgGpgVerifySignatures(
+            self.__path, rev)
     
     @pyqtSlot(str)
     def on_categoryCombo_activated(self, txt):
