@@ -7,7 +7,6 @@
 Module implementing the gpg extension interface.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -105,8 +104,9 @@ class Gpg(HgExtension):
                                   self.vcs.hgGetBranchesList(repodir),
                                   self.vcs.hgGetBookmarksList(repodir))
             if dlg.exec_() == QDialog.Accepted:
-                revision, noCommit, message, keyId, local, force = \
+                revision, noCommit, message, keyId, local, force = (
                     dlg.getData()
+                )
                 if revision:
                     revisions = [revision]
                 else:
