@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the commit message.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QDateTime
 from PyQt5.QtWidgets import QWidget, QDialogButtonBox
@@ -25,13 +24,14 @@ class HgCommitDialog(QWidget, Ui_HgCommitDialog):
     accepted = pyqtSignal()
     rejected = pyqtSignal()
     
-    def __init__(self, vcs, msg, mq, parent=None):
+    def __init__(self, vcs, msg, mq, merge, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param msg initial message (string)
         @param mq flag indicating a queue commit (boolean)
+        @param merge flag indicating a merge commit (boolean)
         @param parent parent widget (QWidget)
         """
         super(HgCommitDialog, self).__init__(parent, Qt.WindowFlags(Qt.Window))
@@ -41,7 +41,7 @@ class HgCommitDialog(QWidget, Ui_HgCommitDialog):
         
         self.logEdit.setPlainText(msg)
         
-        if mq:
+        if mq or merge:
             self.amendCheckBox.setVisible(False)
             self.subrepoCheckBox.setVisible(False)
         else:
@@ -68,6 +68,8 @@ class HgCommitDialog(QWidget, Ui_HgCommitDialog):
         self.authorComboBox.addItems(commitAuthors)
         
         self.dateTimeEdit.setDateTime(QDateTime.currentDateTime())
+        
+        self.logEdit.setFocus(Qt.OtherFocusReason)
     
     def on_buttonBox_clicked(self, button):
         """
@@ -124,8 +126,8 @@ class HgCommitDialog(QWidget, Ui_HgCommitDialog):
         
         author = self.authorComboBox.currentText()
         if author:
-            commitAuthors = \
-                self.__vcs.getPlugin().getPreferences('CommitAuthors')
+            commitAuthors = self.__vcs.getPlugin().getPreferences(
+                'CommitAuthors')
             if author in commitAuthors:
                 commitAuthors.remove(author)
             commitAuthors.insert(0, author)
@@ -135,8 +137,8 @@ class HgCommitDialog(QWidget, Ui_HgCommitDialog):
                 'CommitAuthors', commitAuthors)
         
         if self.dateTimeGroup.isChecked():
-            dateTime = \
-                self.dateTimeEdit.dateTime().toString("yyyy-MM-dd hh:mm")
+            dateTime = self.dateTimeEdit.dateTime().toString(
+                "yyyy-MM-dd hh:mm")
         else:
             dateTime = ""
         
