@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,13 +8,14 @@ Module implementing a dialog to show a list of files which had or still have
 conflicts.
 """
 
-from __future__ import unicode_literals
 
 import os
 
 from PyQt5.QtCore import pyqtSlot, Qt, QPoint, QProcess, QTimer
-from PyQt5.QtWidgets import QAbstractButton, QDialogButtonBox, QHeaderView, \
-    QTreeWidgetItem, QLineEdit, QApplication, QWidget
+from PyQt5.QtWidgets import (
+    QAbstractButton, QDialogButtonBox, QHeaderView, QTreeWidgetItem, QLineEdit,
+    QApplication, QWidget
+)
 
 from E5Gui import E5MessageBox
 from E5Gui.E5Application import e5App
@@ -22,6 +23,7 @@ from E5Gui.E5Application import e5App
 from .Ui_HgConflictsListDialog import Ui_HgConflictsListDialog
 
 import Utilities.MimeTypes
+from Globals import strToQByteArray
 
 
 class HgConflictsListDialog(QWidget, Ui_HgConflictsListDialog):
@@ -79,8 +81,10 @@ class HgConflictsListDialog(QWidget, Ui_HgConflictsListDialog):
             if self.__hgClient.isExecuting():
                 self.__hgClient.cancel()
         else:
-            if self.process is not None and \
-               self.process.state() != QProcess.NotRunning:
+            if (
+                self.process is not None and
+                self.process.state() != QProcess.NotRunning
+            ):
                 self.process.terminate()
                 QTimer.singleShot(2000, self.process.kill)
                 self.process.waitForFinished(3000)
@@ -170,8 +174,10 @@ class HgConflictsListDialog(QWidget, Ui_HgConflictsListDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -326,17 +332,17 @@ class HgConflictsListDialog(QWidget, Ui_HgConflictsListDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
