@@ -1,22 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog starting a process and showing its output.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import os
 
-from PyQt5.QtCore import QProcess, QTimer, pyqtSlot, Qt, QCoreApplication, \
-    QProcessEnvironment
+from PyQt5.QtCore import (
+    QProcess, QTimer, pyqtSlot, Qt, QCoreApplication, QProcessEnvironment
+)
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QLineEdit
 
 from E5Gui import E5MessageBox
@@ -72,8 +68,10 @@ class HgDialog(QDialog, Ui_HgDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -89,9 +87,11 @@ class HgDialog(QDialog, Ui_HgDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setFocus(
             Qt.OtherFocusReason)
         
-        if Preferences.getVCS("AutoClose") and \
-           self.normal and \
-           self.errors.toPlainText() == "":
+        if (
+            Preferences.getVCS("AutoClose") and
+            self.normal and
+            self.errors.toPlainText() == ""
+        ):
             self.accept()
     
     def on_buttonBox_clicked(self, button):
@@ -135,11 +135,13 @@ class HgDialog(QDialog, Ui_HgDialog):
         self.intercept = False
         
         self.__hasAddOrDelete = False
-        if args[0] in ["fetch", "qpush", "qpop", "qgoto", "rebase",
-                       "update", "import", "revert", "graft", "shelve",
-                       "unshelve", "strip", "histedit"] or \
-           (args[0] in ["pull", "unbundle"] and
-                ("--update" in args[1:] or "--rebase" in args[1:])):
+        if (
+            args[0] in ["fetch", "qpush", "qpop", "qgoto", "rebase",
+                        "update", "import", "revert", "graft", "shelve",
+                        "unshelve", "strip", "histedit"] or
+            (args[0] in ["pull", "unbundle"] and
+             ("--update" in args[1:] or "--rebase" in args[1:]))
+        ):
             self.__updateCommand = True
         else:
             self.__updateCommand = False
