@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,18 +8,14 @@ Module implementing a dialog to show the output of the hg status command
 process.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import os
 
-from PyQt5.QtCore import pyqtSlot, qVersion, Qt, QProcess, QTimer, QSize
-from PyQt5.QtGui import QTextCursor, QCursor
-from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QMenu, QHeaderView, \
-    QTreeWidgetItem, QLineEdit, QToolTip
+from PyQt5.QtCore import pyqtSlot, Qt, QProcess, QTimer, QSize
+from PyQt5.QtGui import QTextCursor
+from PyQt5.QtWidgets import (
+    QWidget, QDialogButtonBox, QMenu, QHeaderView, QTreeWidgetItem, QLineEdit
+)
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -31,6 +27,7 @@ from .HgDiffGenerator import HgDiffGenerator
 
 import Preferences
 import UI.PixmapCache
+from Globals import strToQByteArray
 
 
 class HgStatusDialog(QWidget, Ui_HgStatusDialog):
@@ -129,10 +126,7 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         """
         self.__actionsMenu = QMenu()
         self.__actionsMenu.setTearOffEnabled(True)
-        if qVersion() >= "5.1.0":
-            self.__actionsMenu.setToolTipsVisible(True)
-        else:
-            self.__actionsMenu.hovered.connect(self.__actionsMenuHovered)
+        self.__actionsMenu.setToolTipsVisible(True)
         self.__actionsMenu.aboutToShow.connect(self.__showActionsMenu)
         
         self.__commitAct = self.__actionsMenu.addAction(
@@ -191,6 +185,17 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             "Restores the selected missing files"))
         
         self.__actionsMenu.addSeparator()
+
+        self.__commitMergeAct = self.__actionsMenu.addAction(
+            self.tr("Commit Merge"), self.__commitMerge)
+        self.__commitMergeAct.setToolTip(self.tr("Commit all the merged"
+                                                 " changes."))
+        self.__abortMergeAct = self.__actionsMenu.addAction(
+            self.tr("Abort Merge"), self.__abortMerge)
+        self.__commitMergeAct.setToolTip(self.tr("Abort an uncommitted merge "
+                                                 "and lose all changes"))
+
+        self.__actionsMenu.addSeparator()
         
         act = self.__actionsMenu.addAction(
             self.tr("Adjust column sizes"), self.__resizeColumns)
@@ -201,17 +206,6 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             UI.PixmapCache.getIcon("actionsToolButton.png"))
         self.actionsButton.setMenu(self.__actionsMenu)
     
-    def __actionsMenuHovered(self, action):
-        """
-        Private slot to show the tooltip for an action menu entry.
-        
-        @param action action to show tooltip for
-        @type QAction
-        """
-        QToolTip.showText(
-            QCursor.pos(), action.toolTip(),
-            self.__actionsMenu, self.__actionsMenu.actionGeometry(action))
-    
     def closeEvent(self, e):
         """
         Protected slot implementing a close event handler.
@@ -222,8 +216,10 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             if self.__hgClient.isExecuting():
                 self.__hgClient.cancel()
         else:
-            if self.process is not None and \
-               self.process.state() != QProcess.NotRunning:
+            if (
+                self.process is not None and
+                self.process.state() != QProcess.NotRunning
+            ):
                 self.process.terminate()
                 QTimer.singleShot(2000, self.process.kill)
                 self.process.waitForFinished(3000)
@@ -401,8 +397,10 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -532,7 +530,7 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(inputTxt)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -600,28 +598,49 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         """
         Private slot to prepare the actions button menu before it is shown.
         """
-        modified = len(self.__getModifiedItems())
-        unversioned = len(self.__getUnversionedItems())
-        missing = len(self.__getMissingItems())
-        commitable = len(self.__getCommitableItems())
-        commitableUnselected = len(self.__getCommitableUnselectedItems())
+        if self.vcs.canCommitMerge(self.dname):
+            self.__commitMergeAct.setEnabled(True)
+            self.__abortMergeAct.setEnabled(True)
+
+            self.__addAct.setEnabled(False)
+            self.__diffAct.setEnabled(False)
+            self.__sbsDiffAct.setEnabled(False)
+            self.__revertAct.setEnabled(False)
+            self.__forgetAct.setEnabled(False)
+            self.__restoreAct.setEnabled(False)
+            self.__commitAct.setEnabled(False)
+            self.__commitSelectAct.setEnabled(False)
+            self.__commitDeselectAct.setEnabled(False)
+
+            self.__lfAddLargeAct.setEnabled(False)
+            self.__lfAddNormalAct.setEnabled(False)
 
-        self.__addAct.setEnabled(unversioned)
-        self.__diffAct.setEnabled(modified)
-        self.__sbsDiffAct.setEnabled(modified == 1)
-        self.__revertAct.setEnabled(modified)
-        self.__forgetAct.setEnabled(missing)
-        self.__restoreAct.setEnabled(missing)
-        self.__commitAct.setEnabled(commitable)
-        self.__commitSelectAct.setEnabled(commitableUnselected)
-        self.__commitDeselectAct.setEnabled(commitable)
-        
-        if self.vcs.isExtensionActive("largefiles"):
-            enable = bool(unversioned)
         else:
-            enable = False
-        self.__lfAddLargeAct.setEnabled(enable)
-        self.__lfAddNormalAct.setEnabled(enable)
+            self.__commitMergeAct.setEnabled(False)
+            self.__abortMergeAct.setEnabled(False)
+
+            modified = len(self.__getModifiedItems())
+            unversioned = len(self.__getUnversionedItems())
+            missing = len(self.__getMissingItems())
+            commitable = len(self.__getCommitableItems())
+            commitableUnselected = len(self.__getCommitableUnselectedItems())
+    
+            self.__addAct.setEnabled(unversioned)
+            self.__diffAct.setEnabled(modified)
+            self.__sbsDiffAct.setEnabled(modified == 1)
+            self.__revertAct.setEnabled(modified)
+            self.__forgetAct.setEnabled(missing)
+            self.__restoreAct.setEnabled(missing)
+            self.__commitAct.setEnabled(commitable)
+            self.__commitSelectAct.setEnabled(commitableUnselected)
+            self.__commitDeselectAct.setEnabled(commitable)
+            
+            if self.vcs.isExtensionActive("largefiles"):
+                enable = bool(unversioned)
+            else:
+                enable = False
+            self.__lfAddLargeAct.setEnabled(enable)
+            self.__lfAddNormalAct.setEnabled(enable)
     
     def __commit(self):
         """
@@ -838,8 +857,10 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         items = []
         for index in range(self.statusList.topLevelItemCount()):
             itm = self.statusList.topLevelItem(index)
-            if itm.flags() & Qt.ItemIsUserCheckable and \
-               itm.checkState(self.__toBeCommittedColumn) == Qt.Unchecked:
+            if (
+                itm.flags() & Qt.ItemIsUserCheckable and
+                itm.checkState(self.__toBeCommittedColumn) == Qt.Unchecked
+            ):
                 items.append(itm)
         return items
     
@@ -894,6 +915,20 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
                 else:
                     itm.setCheckState(self.__toBeCommittedColumn, Qt.Unchecked)
     
+    def __commitMerge(self):
+        """
+        Private slot to handle the Commit Merge context menu entry.
+        """
+        self.vcs.vcsCommit(self.dname, self.tr('Merge'), merge=True)
+        self.__committed()
+
+    def __abortMerge(self):
+        """
+        Private slot used to abort an uncommitted merge.
+        """
+        self.vcs.hgAbortMerge(self.dname)
+        self.__committed()
+
     ###########################################################################
     ## Diff handling methods below
     ###########################################################################
@@ -903,6 +938,7 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         Private slot to generate diff outputs for the selected item.
         """
         self.diffEdit.clear()
+        self.diffHighlighter.regenerateRules()
         
         if not self.__mq:
             selectedItems = self.statusList.selectedItems()
