@@ -1,17 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS status monitor thread class for Mercurial.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 from PyQt5.QtCore import QProcess
 
@@ -140,8 +135,10 @@ class HgStatusMonitorThread(VcsStatusMonitorThread):
                 self.statusList.append("  {0}".format(name))
         self.reportedStates = states
         
-        return True, \
+        return (
+            True,
             self.tr("Mercurial status checked successfully")
+        )
     
     def _getInfo(self):
         """
@@ -188,7 +185,7 @@ class HgStatusMonitorThread(VcsStatusMonitorThread):
             # ignore errors
             return ""
         
-        globalRev, localRev, branch = output.splitlines()[0].split()
+        globalRev, localRev, branch = output.splitlines()[0].split(None, 2)
         if globalRev.endswith("+"):
             globalRev = globalRev[:-1]
         if localRev.endswith("+"):
