@@ -7,18 +7,16 @@
 Module implementing a dialog to show a list of tags or branches.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import os
 
-from PyQt5.QtCore import pyqtSlot, QProcess, Qt, QTimer, QCoreApplication, \
-    QPoint
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QHeaderView, \
-    QTreeWidgetItem, QLineEdit, QMenu, QAbstractItemView
+from PyQt5.QtCore import (
+    pyqtSlot, QProcess, Qt, QTimer, QCoreApplication, QPoint
+)
+from PyQt5.QtWidgets import (
+    QDialog, QDialogButtonBox, QHeaderView, QTreeWidgetItem, QLineEdit, QMenu,
+    QAbstractItemView
+)
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -84,8 +82,10 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
             if self.__hgClient.isExecuting():
                 self.__hgClient.cancel()
         else:
-            if self.process is not None and \
-               self.process.state() != QProcess.NotRunning:
+            if (
+                self.process is not None and
+                self.process.state() != QProcess.NotRunning
+            ):
                 self.process.terminate()
                 QTimer.singleShot(2000, self.process.kill)
                 self.process.waitForFinished(3000)
@@ -173,8 +173,10 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -516,8 +518,9 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
         branches = [itm.text(3) for itm in self.tagsList.selectedItems()
                     if itm.text(3) != "default"]
         
-        from UI.DeleteFilesConfirmationDialog import \
+        from UI.DeleteFilesConfirmationDialog import (
             DeleteFilesConfirmationDialog
+        )
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
             self.tr("Close Branches"),
