@@ -7,9 +7,9 @@
 Module implementing a dialog to enter some user data.
 """
 
-from __future__ import unicode_literals
 
 import os
+from configparser import ConfigParser
 
 from PyQt5.QtCore import pyqtSlot, Qt, QEvent
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem
@@ -18,13 +18,14 @@ from E5Gui.E5PathPicker import E5PathPickerModes
 from E5Gui import E5MessageBox
 
 import Globals
-from Globals.E5ConfigParser import E5ConfigParser
 
 from .HgUtilities import getConfigPath
-from .HgUserConfigHostFingerprintDialog import \
+from .HgUserConfigHostFingerprintDialog import (
     HgUserConfigHostFingerprintDialog
-from .HgUserConfigHostMinimumProtocolDialog import \
+)
+from .HgUserConfigHostMinimumProtocolDialog import (
     HgUserConfigHostMinimumProtocolDialog
+)
 
 from .Ui_HgUserConfigDialog import Ui_HgUserConfigDialog
 
@@ -104,7 +105,7 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
         Public method to write the user configuration file.
         """
         if self.__config is None:
-            self.__config = E5ConfigParser()
+            self.__config = ConfigParser()
         
         ###################################################################
         ## ui section
@@ -183,8 +184,9 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
             ###############################################################
             if "largefiles" not in self.__config:
                 self.__config["largefiles"] = {}
-            self.__config["largefiles"]["minsize"] = \
+            self.__config["largefiles"]["minsize"] = (
                 str(self.lfFileSizeSpinBox.value())
+            )
             lfFilePatterns = self.lfFilePatternsEdit.text()
             if lfFilePatterns:
                 self.__config["largefiles"]["patterns"] = lfFilePatterns
@@ -216,8 +218,9 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
                 "passwd": self.proxyPasswordEdit.text()
             }
             if self.proxyBypassEdit.text():
-                self.__config["http_proxy"]["no"] = \
+                self.__config["http_proxy"]["no"] = (
                     self.proxyBypassEdit.text()
+                )
         else:
             if "http_proxy" in self.__config:
                 del self.__config["http_proxy"]
@@ -241,8 +244,9 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
                     fingerprint = itm.text(1)
                     if fingerprint.startswith("sha1:"):
                         fingerprint = fingerprint[5:]
-                    self.__config["hostfingerprints"][itm.text(0)] = \
+                    self.__config["hostfingerprints"][itm.text(0)] = (
                         fingerprint
+                    )
             else:
                 if "hostfingerprints" in self.__config:
                     del self.__config["hostfingerprints"]
@@ -264,8 +268,9 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
                 fingerprints = self.__assembleFingerprints()
                 for host in fingerprints:
                     key = "{0}:fingerprints".format(host)
-                    self.__config["hostsecurity"][key] = \
+                    self.__config["hostsecurity"][key] = (
                         ", ".join(fingerprints[host])
+                    )
             else:
                 self.__clearFingerprints()
             
@@ -273,16 +278,18 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
                 disabletls10warning = "true"
             else:
                 disabletls10warning = "false"
-            self.__config["hostsecurity"]["disabletls10warning"] = \
+            self.__config["hostsecurity"]["disabletls10warning"] = (
                 disabletls10warning
+            )
             
             if self.minimumProtocolComboBox.currentIndex() == 0:
                 self.__config.remove_option("hostsecurity", "minimumprotocol")
             else:
                 minimumProtocol = self.minimumProtocolComboBox.itemData(
                     self.minimumProtocolComboBox.currentIndex())
-                self.__config["hostsecurity"]["minimumprotocol"] = \
+                self.__config["hostsecurity"]["minimumprotocol"] = (
                     minimumProtocol
+                )
             
             if self.protocolsList.topLevelItemCount() > 0:
                 self.__clearMinimumProtocols()
@@ -307,7 +314,7 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
         """
         cfgFile = getConfigPath()
         
-        self.__config = E5ConfigParser(delimiters=("=",))
+        self.__config = ConfigParser(delimiters=("=",))
         if self.__config.read(cfgFile):
             # step 1: extract user name and email
             try:
@@ -393,8 +400,9 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
                 for key in self.__config.options("hostsecurity"):
                     if key.endswith(":fingerprints"):
                         host = key.replace(":fingerprints", "")
-                        fingerprints = \
+                        fingerprints = (
                             self.__config["hostsecurity"][key].split(",")
+                        )
                         for fingerprint in fingerprints:
                             if self.__version < (3, 9, 0):
                                 # downgrade from a newer version
