@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to edit a host fingerprint.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
-from .Ui_HgUserConfigHostFingerprintDialog import \
+from .Ui_HgUserConfigHostFingerprintDialog import (
     Ui_HgUserConfigHostFingerprintDialog
+)
 
 
 class HgUserConfigHostFingerprintDialog(
