@@ -11,7 +11,6 @@ Depending on the file name given by the Mercurial histedit command one
 of two possible dialogs will be shown.
 """
 
-from __future__ import unicode_literals
 
 import sys
 import os
@@ -20,13 +19,6 @@ sys.path.insert(1, os.path.join(
     os.path.dirname(__file__), "..", "..", "..", ".."))
 # four times up is the eric6 package directory
 
-import Toolbox.PyQt4ImportHook  # __IGNORE_WARNING__
-
-try:  # Only for Py2
-    import Globals.compatibility_fixes     # __IGNORE_WARNING__
-except (ImportError):
-    pass
-
 for arg in sys.argv[:]:
     if arg.startswith("--config="):
         import Globals
