@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the purge extension project helper.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtWidgets import QMenu
 
@@ -137,26 +136,26 @@ class PurgeProjectHelper(HgExtensionProjectHelper):
         """
         Private slot used to remove files not tracked by Mercurial.
         """
-        self.vcs.getExtensionObject("purge")\
-            .hgPurge(self.project.getProjectPath(), deleteAll=False)
+        self.vcs.getExtensionObject("purge").hgPurge(
+            self.project.getProjectPath(), deleteAll=False)
     
     def __hgPurgeAll(self):
         """
         Private slot used to remove all files not tracked by Mercurial.
         """
-        self.vcs.getExtensionObject("purge")\
-            .hgPurge(self.project.getProjectPath(), deleteAll=True)
+        self.vcs.getExtensionObject("purge").hgPurge(
+            self.project.getProjectPath(), deleteAll=True)
     
     def __hgPurgeList(self):
         """
         Private slot used to list files not tracked by Mercurial.
         """
-        self.vcs.getExtensionObject("purge")\
-            .hgPurgeList(self.project.getProjectPath(), deleteAll=False)
+        self.vcs.getExtensionObject("purge").hgPurgeList(
+            self.project.getProjectPath(), deleteAll=False)
     
     def __hgPurgeAllList(self):
         """
         Private slot used to list all files not tracked by Mercurial.
         """
-        self.vcs.getExtensionObject("purge")\
-            .hgPurgeList(self.project.getProjectPath(), deleteAll=True)
+        self.vcs.getExtensionObject("purge").hgPurgeList(
+            self.project.getProjectPath(), deleteAll=True)
