@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to select a list of guards.
 """
 
-from __future__ import unicode_literals
 
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QListWidgetItem, \
-    QAbstractItemView
+from PyQt5.QtWidgets import (
+    QDialog, QDialogButtonBox, QListWidgetItem, QAbstractItemView
+)
 
 from .Ui_HgQueuesGuardsSelectionDialog import Ui_HgQueuesGuardsSelectionDialog
 
