@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the queues extension project helper.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtWidgets import QMenu
 
@@ -782,37 +781,36 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         Private slot used to create a new named patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueNewPatch(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueNewPatch(
+            self.project.getProjectPath())
     
     def __hgQueueRefreshPatch(self):
         """
         Private slot used to refresh the current patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueRefreshPatch(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueRefreshPatch(
+            self.project.getProjectPath())
     
     def __hgQueueRefreshPatchMessage(self):
         """
         Private slot used to refresh the current patch and its commit message.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueRefreshPatch(self.project.getProjectPath(),
-                                 editMessage=True)
+        self.vcs.getExtensionObject("mq").hgQueueRefreshPatch(
+            self.project.getProjectPath(), editMessage=True)
     
     def __hgQueueShowPatch(self):
         """
         Private slot used to show the contents of the current patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueShowPatch(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueShowPatch(
+            self.project.getProjectPath())
     
     def __hgQueueShowHeader(self):
         """
         Private slot used to show the commit message of the current patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueShowHeader(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueShowHeader(
+            self.project.getProjectPath())
     
     def __hgQueuePushPopPatches(self, name, operation, doAll=False,
                                 named=False, force=False):
@@ -828,9 +826,8 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
             is at the top of the stack (boolean)
         @keyparam force flag indicating a forceful pop (boolean)
         """
-        shouldReopen = self.vcs.getExtensionObject("mq")\
-            .hgQueuePushPopPatches(name, operation=operation, doAll=doAll,
-                                   named=named, force=force)
+        shouldReopen = self.vcs.getExtensionObject("mq").hgQueuePushPopPatches(
+            name, operation=operation, doAll=doAll, named=named, force=force)
         if shouldReopen:
             res = E5MessageBox.yesNo(
                 None,
@@ -966,138 +963,135 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         Private slot used to show a list of applied and unapplied patches.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueListPatches(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueListPatches(
+            self.project.getProjectPath())
     
     def __hgQueueFinishAppliedPatches(self):
         """
         Private slot used to finish all applied patches.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueFinishAppliedPatches(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueFinishAppliedPatches(
+            self.project.getProjectPath())
     
     def __hgQueueRenamePatch(self):
         """
         Private slot used to rename a patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueRenamePatch(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueRenamePatch(
+            self.project.getProjectPath())
     
     def __hgQueueDeletePatch(self):
         """
         Private slot used to delete a patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueDeletePatch(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueDeletePatch(
+            self.project.getProjectPath())
     
     def __hgQueueFoldUnappliedPatches(self):
         """
         Private slot used to fold patches into the current patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueFoldUnappliedPatches(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueFoldUnappliedPatches(
+            self.project.getProjectPath())
     
     def __hgQueueGuardsDefine(self):
         """
         Private slot used to define guards for the current or a named patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueGuardsDefine(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueGuardsDefine(
+            self.project.getProjectPath())
     
     def __hgQueueGuardsDropAll(self):
         """
         Private slot used to drop all guards of the current or a named patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueGuardsDropAll(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueGuardsDropAll(
+            self.project.getProjectPath())
     
     def __hgQueueGuardsList(self):
         """
         Private slot used to list the guards for the current or a named patch.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueGuardsList(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueGuardsList(
+            self.project.getProjectPath())
     
     def __hgQueueGuardsListAll(self):
         """
         Private slot used to list all guards of all patches.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueGuardsListAll(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueGuardsListAll(
+            self.project.getProjectPath())
     
     def __hgQueueGuardsSetActive(self):
         """
         Private slot used to set the active guards.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueGuardsSetActive(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueGuardsSetActive(
+            self.project.getProjectPath())
     
     def __hgQueueGuardsDeactivate(self):
         """
         Private slot used to deactivate all active guards.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueGuardsDeactivate(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueGuardsDeactivate(
+            self.project.getProjectPath())
     
     def __hgQueueGuardsIdentifyActive(self):
         """
         Private slot used to list all active guards.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueGuardsIdentifyActive(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueGuardsIdentifyActive(
+            self.project.getProjectPath())
     
     def __hgQueueCreateQueue(self):
         """
         Private slot used to create a new queue.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueCreateRenameQueue(self.project.getProjectPath(), True)
+        self.vcs.getExtensionObject("mq").hgQueueCreateRenameQueue(
+            self.project.getProjectPath(), True)
     
     def __hgQueueRenameQueue(self):
         """
         Private slot used to rename the active queue.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueCreateRenameQueue(self.project.getProjectPath(), False)
+        self.vcs.getExtensionObject("mq").hgQueueCreateRenameQueue(
+            self.project.getProjectPath(), False)
     
     def __hgQueueDeleteQueue(self):
         """
         Private slot used to delete the reference to a queue.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueDeletePurgeActivateQueue(self.project.getProjectPath(),
-                                             Queues.QUEUE_DELETE)
+        self.vcs.getExtensionObject("mq").hgQueueDeletePurgeActivateQueue(
+            self.project.getProjectPath(), Queues.QUEUE_DELETE)
     
     def __hgQueuePurgeQueue(self):
         """
         Private slot used to delete the reference to a queue and remove
         the patch directory.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueDeletePurgeActivateQueue(self.project.getProjectPath(),
-                                             Queues.QUEUE_PURGE)
+        self.vcs.getExtensionObject("mq").hgQueueDeletePurgeActivateQueue(
+            self.project.getProjectPath(), Queues.QUEUE_PURGE)
     
     def __hgQueueActivateQueue(self):
         """
         Private slot used to set the active queue.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueDeletePurgeActivateQueue(self.project.getProjectPath(),
-                                             Queues.QUEUE_ACTIVATE)
+        self.vcs.getExtensionObject("mq").hgQueueDeletePurgeActivateQueue(
+            self.project.getProjectPath(), Queues.QUEUE_ACTIVATE)
     
     def __hgQueueListQueues(self):
         """
         Private slot used to list available queues.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueListQueues(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueListQueues(
+            self.project.getProjectPath())
     
     def __hgQueueInit(self):
         """
         Private slot to initialize a new queue repository.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueInit(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueInit(
+            self.project.getProjectPath())
     
     def __hgQueueCommit(self):
         """
@@ -1109,8 +1103,8 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         Private slot to show the status of the queue repository.
         """
-        self.vcs.getExtensionObject("mq")\
-            .hgQueueStatus(self.project.getProjectPath())
+        self.vcs.getExtensionObject("mq").hgQueueStatus(
+            self.project.getProjectPath())
     
     def __hgQueueSummary(self):
         """
