@@ -1,24 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing Mercurial shelve browser dialog.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
 
 import os
 
 from PyQt5.QtCore import pyqtSlot, Qt, QPoint, QProcess, QTimer
 from PyQt5.QtGui import QCursor
-from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QTreeWidgetItem, \
-    QAbstractButton, QMenu, QHeaderView, QApplication, QLineEdit
+from PyQt5.QtWidgets import (
+    QWidget, QDialogButtonBox, QTreeWidgetItem, QAbstractButton, QMenu,
+    QHeaderView, QApplication, QLineEdit
+)
 
 from E5Gui import E5MessageBox
 
@@ -91,8 +88,10 @@ class HgShelveBrowserDialog(QWidget, Ui_HgShelveBrowserDialog):
             if self.__hgClient.isExecuting():
                 self.__hgClient.cancel()
         else:
-            if self.process is not None and \
-               self.process.state() != QProcess.NotRunning:
+            if (
+                self.process is not None and
+                self.process.state() != QProcess.NotRunning
+            ):
                 self.process.terminate()
                 QTimer.singleShot(2000, self.process.kill)
                 self.process.waitForFinished(3000)
@@ -234,8 +233,10 @@ class HgShelveBrowserDialog(QWidget, Ui_HgShelveBrowserDialog):
         Private slot called when the process finished or the user pressed
         the button.
         """
-        if self.process is not None and \
-           self.process.state() != QProcess.NotRunning:
+        if (
+            self.process is not None and
+            self.process.state() != QProcess.NotRunning
+        ):
             self.process.terminate()
             QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
@@ -469,8 +470,8 @@ class HgShelveBrowserDialog(QWidget, Ui_HgShelveBrowserDialog):
         itm = self.shelveList.selectedItems()[0]
         if itm is not None:
             name = itm.text(self.NameColumn)
-            self.vcs.getExtensionObject("shelve")\
-                .hgUnshelve(self.__projectDir, shelveName=name)
+            self.vcs.getExtensionObject("shelve").hgUnshelve(
+                self.__projectDir, shelveName=name)
             self.on_refreshButton_clicked()
     
     def __deleteShelves(self):
@@ -481,14 +482,14 @@ class HgShelveBrowserDialog(QWidget, Ui_HgShelveBrowserDialog):
         for itm in self.shelveList.selectedItems():
             shelveNames.append(itm.text(self.NameColumn))
         if shelveNames:
-            self.vcs.getExtensionObject("shelve")\
-                .hgDeleteShelves(self.__projectDir, shelveNames=shelveNames)
+            self.vcs.getExtensionObject("shelve").hgDeleteShelves(
+                self.__projectDir, shelveNames=shelveNames)
             self.on_refreshButton_clicked()
     
     def __cleanupShelves(self):
         """
         Private slot to delete all shelves.
         """
-        self.vcs.getExtensionObject("shelve")\
-            .hgCleanupShelves(self.__projectDir)
+        self.vcs.getExtensionObject("shelve").hgCleanupShelves(
+            self.__projectDir)
         self.on_refreshButton_clicked()
