@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a shelve operation.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import QDateTime
 from PyQt5.QtWidgets import QDialog
@@ -19,11 +18,14 @@ class HgShelveDataDialog(QDialog, Ui_HgShelveDataDialog):
     """
     Class implementing a dialog to enter the data for a shelve operation.
     """
-    def __init__(self, parent=None):
+    def __init__(self, version, parent=None):
         """
         Constructor
         
-        @param parent reference to the parent widget (QWidget)
+        @param version Mercurial version
+        @type tuple of three int
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super(HgShelveDataDialog, self).__init__(parent)
         self.setupUi(self)
@@ -31,6 +33,10 @@ class HgShelveDataDialog(QDialog, Ui_HgShelveDataDialog):
         self.__initialDateTime = QDateTime.currentDateTime()
         self.dateTimeEdit.setDateTime(self.__initialDateTime)
         
+        if version < (5, 0, 0):
+            self.keepCheckBox.setChecked(False)
+            self.keepCheckBox.hide()
+        
         msh = self.minimumSizeHint()
         self.resize(max(self.width(), msh.width()), msh.height())
     
@@ -38,9 +44,10 @@ class HgShelveDataDialog(QDialog, Ui_HgShelveDataDialog):
         """
         Public method to get the user data.
         
-        @return tuple containing the name (string), date (QDateTime),
-            message (string) and a flag indicating to add/remove
-            new/missing files (boolean)
+        @return tuple containing the name, date, message, a flag indicating
+            to add/remove new/missing files and a flag indicating to keep the
+            shelved changes in the working directory
+        @rtype tuple of (str, QDateTime, str, bool, bool)
         """
         if self.dateTimeEdit.dateTime() != self.__initialDateTime:
             dateTime = self.dateTimeEdit.dateTime()
@@ -51,4 +58,5 @@ class HgShelveDataDialog(QDialog, Ui_HgShelveDataDialog):
             dateTime,
             self.messageEdit.text(),
             self.addRemoveCheckBox.isChecked(),
+            self.keepCheckBox.isChecked(),
         )
