@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the shelve extension project browser helper.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtWidgets import QMenu
 
@@ -112,6 +111,5 @@ class ShelveProjectBrowserHelper(HgExtensionProjectBrowserHelper):
             except AttributeError:
                 name = itm.dirName()
             names.append(name)
-        shouldReopen = self.vcs.getExtensionObject("shelve")\
-            .hgShelve(names)
+        shouldReopen = self.vcs.getExtensionObject("shelve").hgShelve(names)
         self.__reopenProject(shouldReopen, self.tr("Shelve"))
