@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS project helper for Subversion.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -679,8 +678,8 @@ class PySvnProjectHelper(VcsProjectHelper):
         """
         Private slot to open the configuration dialog.
         """
-        e5App().getObject("UserInterface")\
-            .showPreferences("zzz_subversionPage")
+        e5App().getObject("UserInterface").showPreferences(
+            "zzz_subversionPage")
     
     def __svnChangeLists(self):
         """
