@@ -1,22 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the output of the svn blame command.
 """
 
-from __future__ import unicode_literals
 
 import os
-import sys
 
 import pysvn
 
 from PyQt5.QtCore import QMutexLocker, Qt
-from PyQt5.QtWidgets import QHeaderView, QDialog, QDialogButtonBox, \
-    QTreeWidgetItem
+from PyQt5.QtWidgets import (
+    QHeaderView, QDialog, QDialogButtonBox, QTreeWidgetItem
+)
 
 from .SvnDialogMixin import SvnDialogMixin
 from .Ui_SvnBlameDialog import Ui_SvnBlameDialog
@@ -50,12 +49,11 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
         self.blameList.setFont(font)
         
         self.client = self.vcs.getClient()
-        self.client.callback_cancel = \
-            self._clientCancelCallback
-        self.client.callback_get_login = \
-            self._clientLoginCallback
-        self.client.callback_ssl_server_trust_prompt = \
+        self.client.callback_cancel = self._clientCancelCallback
+        self.client.callback_get_login = self._clientLoginCallback
+        self.client.callback_ssl_server_trust_prompt = (
             self._clientSslServerTrustPromptCallback
+        )
         
     def start(self, fn):
         """
@@ -78,9 +76,6 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
             for annotation in annotations:
                 author = annotation["author"]
                 line = annotation["line"]
-                if sys.version_info[0] == 2:
-                    author = author.decode('utf-8')
-                    line = line.decode('utf-8')
                 self.__generateItem(
                     annotation["revision"].number, author,
                     annotation["number"] + 1, line)
