@@ -8,10 +8,8 @@ Module implementing a dialog to show the output of the svn diff command
 process.
 """
 
-from __future__ import unicode_literals
 
 import os
-import sys
 
 import pysvn
 
@@ -65,12 +63,11 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         self.highlighter = SvnDiffHighlighter(self.contents.document())
         
         self.client = self.vcs.getClient()
-        self.client.callback_cancel = \
-            self._clientCancelCallback
-        self.client.callback_get_login = \
-            self._clientLoginCallback
-        self.client.callback_ssl_server_trust_prompt = \
+        self.client.callback_cancel = self._clientCancelCallback
+        self.client.callback_get_login = self._clientLoginCallback
+        self.client.callback_ssl_server_trust_prompt = (
             self._clientSslServerTrustPromptCallback
+        )
         
     def __getVersionArg(self, version):
         """
@@ -224,8 +221,6 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                         diff_list = []
                         for diff_sum in diff_summary:
                             path = diff_sum['path']
-                            if sys.version_info[0] == 2:
-                                path = path.decode('utf-8')
                             diff_list.append("{0} {1}".format(
                                 self.__getDiffSummaryKind(
                                     diff_sum['summarize_kind']),
@@ -237,8 +232,6 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                             url1, revision1=rev1,
                             url_or_path2=url2, revision2=rev2,
                             recurse=recurse)
-                        if sys.version_info[0] == 2:
-                            diffText = diffText.decode('utf-8')
                 else:
                     if pegRev is not None:
                         diffText = self.client.diff_peg(
@@ -250,12 +243,9 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                         diffText = self.client.diff(
                             tmpdir, name,
                             revision1=rev1, revision2=rev2, recurse=recurse)
-                    if sys.version_info[0] == 2:
-                        diffText = diffText.decode('utf-8')
                 counter = 0
                 for line in diffText.splitlines():
-                    if line.startswith("--- ") or \
-                       line.startswith("+++ "):
+                    if line.startswith("--- ") or line.startswith("+++ "):
                         self.__processFileLine(line)
                     
                     self.__appendText("{0}{1}".format(line, os.linesep))
