@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to browse the log history.
 """
 
-from __future__ import unicode_literals
 
 import os
-import sys
 
 import pysvn
 
 from PyQt5.QtCore import QMutexLocker, QDate, QRegExp, Qt, pyqtSlot, QPoint
 from PyQt5.QtGui import QCursor
-from PyQt5.QtWidgets import QHeaderView, QWidget, QApplication, \
-    QDialogButtonBox, QTreeWidgetItem
+from PyQt5.QtWidgets import (
+    QHeaderView, QWidget, QApplication, QDialogButtonBox, QTreeWidgetItem
+)
 
 from E5Gui import E5MessageBox
 
@@ -79,12 +78,11 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         self.__logTreeBoldFont.setBold(True)
         
         self.client = self.vcs.getClient()
-        self.client.callback_cancel = \
-            self._clientCancelCallback
-        self.client.callback_get_login = \
-            self._clientLoginCallback
-        self.client.callback_ssl_server_trust_prompt = \
+        self.client.callback_cancel = self._clientCancelCallback
+        self.client.callback_get_login = self._clientLoginCallback
+        self.client.callback_ssl_server_trust_prompt = (
             self._clientSslServerTrustPromptCallback
+        )
     
     def __initData(self):
         """
@@ -309,15 +307,14 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             for log in logs:
                 author = log["author"]
                 message = log["message"]
-                if sys.version_info[0] == 2:
-                    author = author.decode('utf-8')
-                    message = message.decode('utf-8')
                 self.__generateLogItem(
                     author, log["date"], message,
                     log["revision"], log['changed_paths'])
                 dt = dateFromTime_t(log["date"])
-                if not self.__maxDate.isValid() and \
-                        not self.__minDate.isValid():
+                if (
+                    not self.__maxDate.isValid() and
+                    not self.__minDate.isValid()
+                ):
                     self.__maxDate = dt
                     self.__minDate = dt
                 else:
@@ -587,8 +584,11 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             currentItem = self.logTree.currentItem()
             for topIndex in range(self.logTree.topLevelItemCount()):
                 topItem = self.logTree.topLevelItem(topIndex)
-                if topItem.text(2) <= to_ and topItem.text(2) >= from_ and \
-                   searchRx.indexIn(topItem.text(fieldIndex)) > -1:
+                if (
+                    topItem.text(2) <= to_ and
+                    topItem.text(2) >= from_ and
+                    searchRx.indexIn(topItem.text(fieldIndex)) > -1
+                ):
                     topItem.setHidden(False)
                     if topItem is currentItem:
                         self.on_logTree_currentItemChanged(topItem, None)
