@@ -8,16 +8,15 @@ Module implementing a dialog to show the output of the svn proplist command
 process.
 """
 
-from __future__ import unicode_literals
 
 import os
-import sys
 
 import pysvn
 
 from PyQt5.QtCore import pyqtSlot, QMutexLocker, Qt
-from PyQt5.QtWidgets import QWidget, QHeaderView, QApplication, \
-    QDialogButtonBox, QTreeWidgetItem
+from PyQt5.QtWidgets import (
+    QWidget, QHeaderView, QApplication, QDialogButtonBox, QTreeWidgetItem
+)
 
 from .SvnDialogMixin import SvnDialogMixin
 from .Ui_SvnPropListDialog import Ui_SvnPropListDialog
@@ -39,9 +38,8 @@ class SvnPropListDialog(QWidget, SvnDialogMixin, Ui_SvnPropListDialog):
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
         
-        self.refreshButton = \
-            self.buttonBox.addButton(self.tr("Refresh"),
-                                     QDialogButtonBox.ActionRole)
+        self.refreshButton = self.buttonBox.addButton(
+            self.tr("Refresh"), QDialogButtonBox.ActionRole)
         self.refreshButton.setToolTip(
             self.tr("Press to refresh the properties display"))
         self.refreshButton.setEnabled(False)
@@ -54,12 +52,11 @@ class SvnPropListDialog(QWidget, SvnDialogMixin, Ui_SvnPropListDialog):
         self.propsList.header().setSortIndicator(0, Qt.AscendingOrder)
         
         self.client = self.vcs.getClient()
-        self.client.callback_cancel = \
-            self._clientCancelCallback
-        self.client.callback_get_login = \
-            self._clientLoginCallback
-        self.client.callback_ssl_server_trust_prompt = \
+        self.client.callback_cancel = self._clientCancelCallback
+        self.client.callback_get_login = self._clientLoginCallback
+        self.client.callback_ssl_server_trust_prompt = (
             self._clientSslServerTrustPromptCallback
+        )
         
     def __resort(self):
         """
@@ -121,12 +118,7 @@ class SvnPropListDialog(QWidget, SvnDialogMixin, Ui_SvnPropListDialog):
                 proplist = self.client.proplist(name, recurse=recursive)
                 counter = 0
                 for path, prop in proplist:
-                    if sys.version_info[0] == 2:
-                        path = path.decode('utf-8')
                     for propName, propVal in list(prop.items()):
-                        if sys.version_info[0] == 2:
-                            propName = propName.decode('utf-8')
-                            propVal = propVal.decode('utf-8')
                         self.__generateItem(path, propName, propVal)
                         self.propsFound = True
                     counter += 1
