@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the subversion repository browser dialog.
 """
 
-from __future__ import unicode_literals
 
 import pysvn
 
 from PyQt5.QtCore import QMutexLocker, Qt, pyqtSlot
 from PyQt5.QtGui import QCursor
-from PyQt5.QtWidgets import QHeaderView, QDialog, QApplication, \
-    QDialogButtonBox, QTreeWidgetItem
+from PyQt5.QtWidgets import (
+    QHeaderView, QDialog, QApplication, QDialogButtonBox, QTreeWidgetItem
+)
 
 from E5Gui import E5MessageBox
 
@@ -63,12 +63,11 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
         self.__ignoreExpand = False
         
         self.client = self.vcs.getClient()
-        self.client.callback_cancel = \
-            self._clientCancelCallback
-        self.client.callback_get_login = \
-            self._clientLoginCallback
-        self.client.callback_ssl_server_trust_prompt = \
+        self.client.callback_cancel = self._clientCancelCallback
+        self.client.callback_get_login = self._clientLoginCallback
+        self.client.callback_ssl_server_trust_prompt = (
             self._clientSslServerTrustPromptCallback
+        )
         
         self.show()
         QApplication.processEvents()
@@ -164,9 +163,11 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
                 entries = self.client.list(url, recurse=False)
                 firstTime = parent == self.repoTree
                 # dirent elements are all unicode in Python 2
-                for dirent, lock in entries:
-                    if (firstTime and dirent["path"] != url) or \
-                       (parent != self.repoTree and dirent["path"] == url):
+                for dirent, _lock in entries:
+                    if (
+                        (firstTime and dirent["path"] != url) or
+                        (parent != self.repoTree and dirent["path"] == url)
+                    ):
                         continue
                     if firstTime:
                         if dirent["repos_path"] != "/":
@@ -182,8 +183,9 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
                             itm.setExpanded(True)
                             parent = itm
                             urlPart = repoUrl
-                            for element in \
-                                    dirent["repos_path"].split("/")[:-1]:
+                            for element in (
+                                dirent["repos_path"].split("/")[:-1]
+                            ):
                                 if element:
                                     urlPart = "{0}/{1}".format(urlPart,
                                                                element)
