@@ -1,21 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show a list of tags or branches.
 """
 
-from __future__ import unicode_literals
 
 import os
 
 import pysvn
 
 from PyQt5.QtCore import QMutexLocker, QRegExp, Qt
-from PyQt5.QtWidgets import QHeaderView, QLineEdit, QDialog, QInputDialog, \
-    QApplication, QDialogButtonBox, QTreeWidgetItem
+from PyQt5.QtWidgets import (
+    QHeaderView, QLineEdit, QDialog, QInputDialog, QApplication,
+    QDialogButtonBox, QTreeWidgetItem
+)
 
 from E5Gui import E5MessageBox
 
@@ -51,12 +52,11 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
         self.tagList.header().setSortIndicator(3, Qt.AscendingOrder)
         
         self.client = self.vcs.getClient()
-        self.client.callback_cancel = \
-            self._clientCancelCallback
-        self.client.callback_get_login = \
-            self._clientLoginCallback
-        self.client.callback_ssl_server_trust_prompt = \
+        self.client.callback_cancel = self._clientCancelCallback
+        self.client.callback_get_login = self._clientLoginCallback
+        self.client.callback_ssl_server_trust_prompt = (
             self._clientSslServerTrustPromptCallback
+        )
         
     def start(self, path, tags=True):
         """
